@@ -9,8 +9,8 @@
  *     Christian Schulte, 2001
  *
  *  Last modified:
- *     $Date: 2009-10-07 11:13:58 +0200 (Wed, 07 Oct 2009) $ by $Author: tack $
- *     $Revision: 9848 $
+ *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
+ *     $Revision: 10684 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -42,12 +42,16 @@
 #include <gecode/minimodel.hh>
 #include <gecode/graph.hh>
 
+#ifdef GECODE_HAS_GIST
+#include <QtGui>
+#endif
+
 using namespace Gecode;
 
 
-/** \brief Custom brancher for knights tours using Warnsdorff's rule
+/** \brief Custom brancher for knight's tours using Warnsdorff's rule
  *
- * This class implements Warnsdorff's rule for finding Knights
+ * This class implements Warnsdorff's rule for finding knight's
  * tours. The next position is choosen by taking the jump that
  * minimizes the number of alternatives in the next step.
  *
@@ -59,7 +63,7 @@ protected:
   ViewArray<Int::IntView> x;
   /// Next variable to branch on
   mutable int start;
-  /// Choice
+  /// %Choice
   class Choice : public Gecode::Choice {
   public:
     /// Position of variable
@@ -78,7 +82,7 @@ protected:
   };
  
   /// Construct brancher
-  Warnsdorff(Space& home, ViewArray<Int::IntView>& xv) 
+  Warnsdorff(Home home, ViewArray<Int::IntView>& xv) 
     : Brancher(home), x(xv), start(0) {}
   /// Copy constructor
   Warnsdorff(Space& home, bool share, Warnsdorff& b) 
@@ -88,14 +92,14 @@ protected:
 public:
   /// Check status of brancher, return true if alternatives left
   virtual bool status(const Space&) const {
-    // Follow path of assigned variables
-    while (true) {
+    // A path to follow can be at most x.size() long
+    for (int n=x.size(); n--; ) {
       if (!x[start].assigned()) 
         return true;
+      // Follow path of assigned variables
       start = x[start].val();
-      if (start == 0) 
-        return false;
     }
+    return false;
   }
   /// Return choice
   virtual Gecode::Choice* choice(Space&) {
@@ -103,7 +107,7 @@ public:
     int n = iv.val();
     unsigned int min = x[n].size();
     ++iv;
-    // Choose the value with the fewest neighbours
+    // Choose the value with the fewest neighbors
     while (iv()) {
       if (x[iv.val()].size() < min) {
         n = iv.val();
@@ -127,7 +131,7 @@ public:
     return new (home) Warnsdorff(home, share, *this);
   }
   /// Post brancher
-  static void post(Space& home, const IntVarArgs& x) {
+  static void post(Home home, const IntVarArgs& x) {
     ViewArray<Int::IntView> xv(home, x);
     (void) new (home) Warnsdorff(home, xv);
   }
@@ -138,14 +142,13 @@ public:
 };
 
 
-/// Base-class for Knights tour example
+/// Base-class for knight's tour example
 class Knights : public Script {
-protected:
+public:
   /// Size of board
   const int n;
   /// Maps board field to successor field
   IntVarArray succ;
-public:
   /// Propagation to use for model
   enum {
     PROP_REIFIED, ///< Use reified constraints
@@ -157,25 +160,29 @@ public:
     BRANCH_WARNSDORFF, ///< Use Warnsdorff's rule
   };
   /// Return field at position \a x, \a y
-  int
-  field(int x, int y) const {
-    return x*n+y;
+  int f(int x, int y) const {
+    return x + y*n;
   }
-  /// Compute array of neighbours
-  void
-  neighbours(int f, int nbs[8], int& n_nbs) {
-    n_nbs=0;
-    int x = f / n;
-    int y = f % n;
-    for (int i=0;i<8;i++) {
-      static const int moves[8][2] = {
-        {-2,-1}, {-2,1}, {-1,-2}, {-1,2}, {1,-2}, {1,2}, {2,-1}, {2,1}
-      };
-      int nx=x+moves[i][0];
-      int ny=y+moves[i][1];
+  /// Return x coordinate at field \a f
+  int x(int f) const {
+    return f % n;
+  }
+  /// Return y coordinate at field \a f
+  int y(int f) const {
+    return f / n;
+  }
+  /// Compute set of neighbour fields
+  IntSet neighbors(int i) {
+    static const int moves[8][2] = {
+      {-2,-1}, {-2,1}, {-1,-2}, {-1,2}, {1,-2}, {1,2}, {2,-1}, {2,1}
+    };
+    int nbs[8]; int n_nbs = 0;
+    for (int m=0; m<8; m++) {
+      int nx = x(i) + moves[m][0], ny = y(i) + moves[m][1];
       if ((nx >= 0) && (nx < n) && (ny >= 0) && (ny < n))
-        nbs[n_nbs++]=field(nx,ny);
+        nbs[n_nbs++] = f(nx,ny);
     }
+    return IntSet(nbs,n_nbs);
   }
   /// Constructor
   Knights(const SizeOptions& opt)
@@ -207,7 +214,7 @@ public:
     for (int i = 0; i < n; i++) {
       for (int j = 0; j < n; j++) {
         os.width(3);
-        os << jump[field(i,j)] << " ";
+        os << jump[f(i,j)] << " ";
         }
         os << std::endl << "\t";
     }
@@ -217,11 +224,11 @@ public:
 };
 
 /**
- * \brief %Example: n-%Knights tour (simple model)
+ * \brief %Example: n-knight's tour (simple model)
  *
- * Fill an n times n chess board with knights such that the
- * knights do a full tour by knights move (last knight reaches
- * first knight again). The formulation is due to Gert Smolka.
+ * Fill an n times n chess board with knight's moves such that
+ * the knight does a full tour (last move reaches first move
+ * again). The formulation is due to Gert Smolka.
  *
  * \ingroup ExProblem
  *
@@ -241,24 +248,20 @@ public:
     }
 
     // Place the first two knights
-    rel(*this, jump[field(0,0)], IRT_EQ, 0);
-    rel(*this, jump[field(1,2)], IRT_EQ, 1);
+    rel(*this, jump[f(0,0)], IRT_EQ, 0);
+    rel(*this, jump[f(1,2)], IRT_EQ, 1);
 
     distinct(*this, jump, opt.icl());
     channel(*this, succ, pred, opt.icl());
 
     for (int f = 0; f < nn; f++) {
-      // Array of neighbours
-      int nbs[8]; int n_nbs = 0;
-      neighbours(f, nbs, n_nbs);
-      for (int i=n_nbs; i--; )
+      IntSet ds = neighbors(f);
+      for (IntSetValues i(ds); i(); ++i)
         rel(*this,
-            post(*this, ~(jump[nbs[i]]-jump[f] == 1)),
+            post(*this, ~(jump[i.val()]-jump[f] == 1)),
             BOT_XOR,
-            post(*this, ~(jump[nbs[i]]-jump[f] == 1-nn)),
-            post(*this, ~(succ[f] == nbs[i])));
-
-      IntSet ds(nbs, n_nbs);
+            post(*this, ~(jump[i.val()]-jump[f] == 1-nn)),
+            post(*this, ~(succ[f] == i.val())));
       dom(*this, pred[f], ds);
       dom(*this, succ[f], ds);
       rel(*this, succ[f], IRT_NQ, pred[f]);
@@ -287,17 +290,12 @@ class KnightsCircuit : public Knights {
 public:
   KnightsCircuit(const SizeOptions& opt) : Knights(opt) {
     // Fix the first move
-    rel(*this, succ[0], IRT_EQ, field(1,2));
+    rel(*this, succ[0], IRT_EQ, f(1,2));
 
     circuit(*this, succ, opt.icl());
 
-    for (int f = 0; f < n*n; f++) {
-      // Array of neighbours
-      int nbs[8]; int n_nbs = 0;
-      neighbours(f, nbs, n_nbs);
-      IntSet ds(nbs, n_nbs);
-      dom(*this, succ[f], ds);
-    }
+    for (int f = 0; f < n*n; f++)
+      dom(*this, succ[f], neighbors(f));
   }
   /// Constructor for cloning \a s
   KnightsCircuit(bool share, KnightsCircuit& s) : Knights(share,s) {}
@@ -308,6 +306,80 @@ public:
   }
 };
 
+#ifdef GECODE_HAS_GIST
+/// Inspector showing knight moves on a chess board
+class KnightsInspector : public Gist::Inspector {
+protected:
+  /// The graphics scene displaying the board
+  QGraphicsScene* scene;
+  /// The window containing the graphics scene
+  QMainWindow* mw;
+  /// The size of a field on the board
+  static const int unit = 30;
+public:
+  /// Constructor
+  KnightsInspector(void) : scene(NULL), mw(NULL) {}
+  /// Inspect space \a s
+  virtual void inspect(const Space& s) {
+    const Knights& k = static_cast<const Knights&>(s);
+    
+    if (!scene)
+      initialize();
+    QList <QGraphicsItem*> itemList = scene->items();
+    foreach (QGraphicsItem* i, scene->items()) {
+      scene->removeItem(i);
+      delete i;
+    }
+
+    for (int i=0; i<k.n; i++) {
+      for (int j=0; j<k.n; j++) {
+        scene->addRect(i*unit,j*unit,unit,unit);
+        
+        QPen pen(Qt::black, 2);
+        if (!k.succ[i*k.n+j].assigned()) {
+          pen.setColor(Qt::red);
+          pen.setStyle(Qt::DotLine);
+          pen.setWidth(0);
+        }
+        for (IntVarValues xv(k.succ[i*k.n+j]); xv(); ++xv) {
+          int ky = xv.val() % k.n;
+          int kx = xv.val() / k.n;
+          scene->addLine(i*unit+unit/2,j*unit+unit/2,
+                         kx*unit+unit/2,ky*unit+unit/2,
+                         pen);
+        }
+        
+      }
+    }
+    mw->show();    
+  }
+  
+  /// Set up main window
+  void initialize(void) {
+    mw = new QMainWindow();
+    scene = new QGraphicsScene();
+    QGraphicsView* view = new QGraphicsView(scene);
+    view->setRenderHints(QPainter::Antialiasing);
+    mw->setCentralWidget(view);
+    mw->setAttribute(Qt::WA_QuitOnClose, false);
+    mw->setAttribute(Qt::WA_DeleteOnClose, false);
+    QAction* closeWindow = new QAction("Close window", mw);
+    closeWindow->setShortcut(QKeySequence("Ctrl+W"));
+    mw->connect(closeWindow, SIGNAL(triggered()),
+                mw, SLOT(close()));
+    mw->addAction(closeWindow);
+  }
+  
+  /// Name of the inspector
+  virtual std::string name(void) { return "Board"; }
+  /// Finalize inspector
+  virtual void finalize(void) {
+    delete mw;
+    mw = NULL;
+  }
+};
+#endif GECODE_HAS_GIST
+
 /** \brief Main-function
  *  \relates Knights
  */
@@ -322,7 +394,14 @@ main(int argc, char* argv[]) {
   opt.branching(Knights::BRANCH_NAIVE);
   opt.branching(Knights::BRANCH_NAIVE, "reified");
   opt.branching(Knights::BRANCH_WARNSDORFF, "warnsdorff");
+
+#ifdef GECODE_HAS_GIST
+  KnightsInspector ki;
+  opt.inspect.click(&ki);
+#endif
+
   opt.parse(argc,argv);
+
   if (opt.propagation() == Knights::PROP_REIFIED) {
     Script::run<KnightsReified,DFS,SizeOptions>(opt);
   } else {
