@@ -11,8 +11,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2009-04-02 20:58:46 +0200 (Thu, 02 Apr 2009) $ by $Author: schulte $
- *     $Revision: 8649 $
+ *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
+ *     $Revision: 9692 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -98,28 +98,28 @@ namespace {
   /// Type for board symmetry functions
   typedef void (*bsymmfunc)(const IntVarArgs, int, int, IntVarArgs&, int&, int&);
   /// Identity symmetry
-  template <class CArray, class Array>
+  template<class CArray, class Array>
   void id(CArray t1, int w1, int h1, Array t2, int& w2, int&h2);
   /// Rotate 90 degrees
-  template <class CArray, class Array>
+  template<class CArray, class Array>
   void rot90(CArray t1, int w1, int h1, Array t2, int& w2, int& h2);
   /// Rotate 180 degrees
-  template <class CArray, class Array>
+  template<class CArray, class Array>
   void rot180(CArray t1, int w1, int h1, Array t2, int& w2, int& h2);
   /// Rotate 270 degrees
-  template <class CArray, class Array>
+  template<class CArray, class Array>
   void rot270(CArray t1, int w1, int h1, Array t2, int& w2, int& h2);
   /// Flip x-wise
-  template <class CArray, class Array>
+  template<class CArray, class Array>
   void flipx(CArray t1, int w1, int h1, Array t2, int& w2, int& h2);
   /// Flip y-wise
-  template <class CArray, class Array>
+  template<class CArray, class Array>
   void flipy(CArray t1, int w1, int h1, Array t2, int& w2, int& h2);
   /// Flip diagonal 1
-  template <class CArray, class Array>
+  template<class CArray, class Array>
   void flipd1(CArray t1, int w1, int h1, Array t2, int& w2, int& h2);
   /// Flip diagonal 2
-  template <class CArray, class Array>
+  template<class CArray, class Array>
   void flipd2(CArray t1, int w1, int h1, Array t2, int& w2, int& h2);
   //@}
 }
@@ -269,8 +269,8 @@ public:
   };
   /// Choice of symmetry breaking
   enum {
-    MODEL_NONE, ///< Do not remove symmetric solutions
-    MODEL_SYMMETRY, ///< Remove symmetric solutions
+    SYMMETRY_NONE, ///< Do not remove symmetric solutions
+    SYMMETRY_FULL, ///< Remove symmetric solutions
   };
 private:
   /// Specification of the tiles to place.
@@ -417,7 +417,7 @@ public:
       }
     }
 
-    if (opt.model() == MODEL_SYMMETRY) {
+    if (opt.symmetry() == SYMMETRY_FULL) {
       // Remove symmetrical boards
       IntVarArgs orig(board.size()-height), symm(board.size()-height);
       int pos = 0;
@@ -477,11 +477,11 @@ int
 main(int argc, char* argv[]) {
   SizeOptions opt("Pentominoes");
   opt.size(1);
-  opt.model(Pentominoes::MODEL_SYMMETRY);
-  opt.model(Pentominoes::MODEL_NONE,
+  opt.symmetry(Pentominoes::SYMMETRY_FULL);
+  opt.symmetry(Pentominoes::SYMMETRY_NONE,
             "none", "do not remove symmetric solutions");
-  opt.model(Pentominoes::MODEL_SYMMETRY,
-            "sym", "remove symmetric solutions");
+  opt.symmetry(Pentominoes::SYMMETRY_FULL,
+            "full", "remove symmetric solutions");
 
   opt.propagation(Pentominoes::PROPAGATION_BOOLEAN);
   opt.propagation(Pentominoes::PROPAGATION_INT,
@@ -891,56 +891,56 @@ namespace {
     }
     return h * w1 + w;
   }
-  template <class CArray, class Array>
+  template<class CArray, class Array>
   void id(CArray t1, int w1, int h1, Array t2, int& w2, int&h2) {
     w2 = w1; h2 = h1;
     for (int h = 0; h < h1; ++h)
       for (int w = 0; w < w1; ++w)
 	t2[pos(h, w, h2, w2)] = t1[pos(h, w, h1, w1)];
   }
-  template <class CArray, class Array>
+  template<class CArray, class Array>
   void rot90(CArray t1, int w1, int h1, Array t2, int& w2, int& h2) {
     w2 = h1; h2 = w1;
     for (int h = 0; h < h1; ++h)
       for (int w = 0; w < w1; ++w)
 	t2[pos(w, w2-h-1, h2, w2)] = t1[pos(h, w, h1, w1)];
   }
-  template <class CArray, class Array>
+  template<class CArray, class Array>
   void rot180(CArray t1, int w1, int h1, Array t2, int& w2, int& h2) {
     w2 = w1; h2 = h1;
     for (int h = 0; h < h1; ++h)
       for (int w = 0; w < w1; ++w)
 	t2[pos(h2-h-1, w2-w-1, h2, w2)] = t1[pos(h, w, h1, w1)];
   }
-  template <class CArray, class Array>
+  template<class CArray, class Array>
   void rot270(CArray t1, int w1, int h1, Array t2, int& w2, int& h2) {
     w2 = h1; h2 = w1;
     for (int h = 0; h < h1; ++h)
       for (int w = 0; w < w1; ++w)
 	t2[pos(h2-w-1, h, h2, w2)] = t1[pos(h, w, h1, w1)];
   }
-  template <class CArray, class Array>
+  template<class CArray, class Array>
   void flipx(CArray t1, int w1, int h1, Array t2, int& w2, int& h2) {
     w2 = w1; h2 = h1;
     for (int h = 0; h < h1; ++h)
       for (int w = 0; w < w1; ++w)
 	t2[pos(h, w2-w-1, h2, w2)] = t1[pos(h, w, h1, w1)];
   }
-  template <class CArray, class Array>
+  template<class CArray, class Array>
   void flipy(CArray t1, int w1, int h1, Array t2, int& w2, int& h2) {
     w2 = w1; h2 = h1;
     for (int h = 0; h < h1; ++h)
       for (int w = 0; w < w1; ++w)
 	t2[pos(h2-h-1, w, h2, w2)] = t1[pos(h, w, h1, w1)];
   }
-  template <class CArray, class Array>
+  template<class CArray, class Array>
   void flipd1(CArray t1, int w1, int h1, Array t2, int& w2, int& h2) {
     w2 = h1; h2 = w1;
     for (int h = 0; h < h1; ++h)
       for (int w = 0; w < w1; ++w)
 	t2[pos(w, h, h2, w2)] = t1[pos(h, w, h1, w1)];
   }
-  template <class CArray, class Array>
+  template<class CArray, class Array>
   void flipd2(CArray t1, int w1, int h1, Array t2, int& w2, int& h2) {
     w2 = h1; h2 = w1;
     for (int h = 0; h < h1; ++h)
