@@ -7,8 +7,8 @@
  *     Mikael Lagerkvist, 2006
  *
  *  Last modified:
- *     $Date: 2009-09-11 11:32:13 +0200 (Fri, 11 Sep 2009) $ by $Author: zayenz $
- *     $Revision: 9716 $
+ *     $Date: 2010-03-15 17:03:39 +0100 (Mon, 15 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10447 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -188,7 +188,7 @@ public:
     };
 
     /// Construct brancher
-    QueenBranch(Space& home)
+    QueenBranch(Home home)
       : Brancher(home), start(0) {}
     /// Constructor for cloning
     QueenBranch(Space& home, bool share, QueenBranch& b)
