@@ -11,8 +11,8 @@
  *     Mikael Lagerkvist, 2009
  *
  *  Last modified:
- *     $Date: 2009-08-26 20:56:42 +0200 (Wed, 26 Aug 2009) $ by $Author: schulte $
- *     $Revision: 9631 $
+ *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
+ *     $Revision: 10684 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -86,7 +86,7 @@ namespace {
 }
 
 /**
- * \brief %Example: Radiotherapy
+ * \brief %Example: %Radiotherapy
  *
  * Implementation of the model for cancer radiation treatment planning
  * from the paper
@@ -310,7 +310,7 @@ public:
       return new (home) NestedSearch(home, share, *this);
     }
     /// Post brancher
-    static void post(Space& home) {
+    static void post(Home home) {
       (void) new (home) NestedSearch(home);
     }
     /// Dispose member function
