@@ -7,8 +7,8 @@
  *     Mikael Lagerkvist, 2008
  *
  *  Last modified:
- *     $Date: 2009-08-26 20:56:42 +0200 (Wed, 26 Aug 2009) $ by $Author: schulte $
- *     $Revision: 9631 $
+ *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
+ *     $Revision: 10684 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -69,7 +69,7 @@ extern unsigned int csplib_norders;     ///< Number of orders
 //@}
 
 
-/** \brief SteelMillOptions for examples with size option and an additional
+/** \brief %SteelMillOptions for examples with size option and an additional
  * optional file name parameter.
  *
  * Used in the \ref SteelMill example.
@@ -320,7 +320,7 @@ public:
   protected:
     /// Cache of first unassigned value
     mutable int start;
-    /// Choice
+    /// %Choice
     class Choice : public Gecode::Choice {
     public:
       /// Position of variable
@@ -339,7 +339,7 @@ public:
     };
 
     /// Construct brancher
-    SteelMillBranch(Space& home)
+    SteelMillBranch(Home home)
       : Brancher(home), start(0) {}
     /// Copy constructor
     SteelMillBranch(Space& home, bool share, SteelMillBranch& b)
@@ -405,7 +405,7 @@ public:
       return new (home) SteelMillBranch(home, share, *this);
     }
     /// Post brancher
-    static void post(Space& home) {
+    static void post(Home home) {
       (void) new (home) SteelMillBranch(home);
     }
     /// Delete brancher and return its size
