@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-13 15:19:20 +0200 (Tue, 13 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9887 $
+ *     $Date: 2010-04-07 13:52:08 +0200 (Wed, 07 Apr 2010) $ by $Author: zayenz $
+ *     $Revision: 10667 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -76,6 +76,37 @@ namespace Gecode {
       strdel(exp);
     }
 
+
+    bool
+    StringValueOption::parse(int& argc, char* argv[]) {
+      if ((argc < 2) || strcmp(argv[1],opt))
+        return false;
+      if (argc == 2) {
+        std::cerr << "Missing argument for option \"" << opt << "\"" << std::endl;
+        exit(EXIT_FAILURE);
+      }
+      cur = strdup(argv[2]);
+      // Remove options
+      argc -= 2;
+      for (int i=1; i<argc; i++)
+        argv[i] = argv[i+2];
+      return true;
+    }
+    
+    void
+    StringValueOption::help(void) {
+      using namespace std;
+      cerr << '\t' << opt << " (string) default: " 
+           << ((cur == NULL) ? "NONE" : cur) << endl
+           << "\t\t" << exp << endl;
+    }
+  
+    StringValueOption::~StringValueOption(void) {
+      strdel(cur);
+    }
+  
+
+
     void
     StringOption::add(int v, const char* o, const char* h) {
       Value* n = new Value;
@@ -263,7 +294,11 @@ namespace Gecode {
     std::cerr << std::endl
               << " - Thread support: ";
 #ifdef GECODE_HAS_THREADS
-    std::cerr << "enabled (" << Support::Thread::npu() << " processing units)";
+    if (Support::Thread::npu() == 1)
+      std::cerr << "enabled (1 processing unit)";
+    else
+      std::cerr << "enabled (" << Support::Thread::npu() 
+                << " processing units)";
 #else
     std::cerr << "disabled";
 #endif
