@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-06-26 13:15:22 +0200 (Fri, 26 Jun 2009) $ by $Author: zayenz $
- *     $Revision: 9350 $
+ *     $Date: 2010-04-06 14:58:53 +0200 (Tue, 06 Apr 2010) $ by $Author: tack $
+ *     $Revision: 10649 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -41,6 +41,24 @@
 namespace Gecode {
 
   namespace Driver {
+    /*
+     * String option
+     *
+     */
+    inline
+    StringValueOption::StringValueOption(const char* o, const char* e, 
+                                         const char* v)
+      : BaseOption(o,e), cur(strdup(v)) {}
+    inline void
+    StringValueOption::value(const char* v) {
+      strdel(cur);
+      cur = strdup(v);
+    }
+    inline const char*
+    StringValueOption::value(void) const {
+      return cur;
+    }
+
     /*
      * String option
      *
@@ -325,6 +343,46 @@ namespace Gecode {
     return _samples.value();
   }
 
+#ifdef GECODE_HAS_GIST
+  forceinline
+  Options::_I::_I(void) : _click(heap,1), n_click(0),
+    _solution(heap,1), n_solution(0), _move(heap,1), n_move(0),
+    _compare(heap,1), n_compare(0) {}
+
+  forceinline void
+  Options::_I::click(Gist::Inspector* i) {
+    _click[n_click++] = i;
+  }
+  forceinline void
+  Options::_I::solution(Gist::Inspector* i) {
+    _solution[n_solution++] = i;
+  }
+  forceinline void
+  Options::_I::move(Gist::Inspector* i) {
+    _move[n_move++] = i;
+  }
+  forceinline void
+  Options::_I::compare(Gist::Comparator* i) {
+    _compare[n_compare++] = i;
+  }
+  forceinline Gist::Inspector*
+  Options::_I::click(unsigned int i) const {
+    return (i < n_click) ? _click[i] : NULL;
+  }
+  forceinline Gist::Inspector*
+  Options::_I::solution(unsigned int i) const {
+    return (i < n_solution) ? _solution[i] : NULL;
+  }
+  forceinline Gist::Inspector*
+  Options::_I::move(unsigned int i) const {
+    return (i < n_move) ? _move[i] : NULL;
+  }
+  forceinline Gist::Comparator*
+  Options::_I::compare(unsigned int i) const {
+    return (i < n_compare) ? _compare[i] : NULL;
+  }
+#endif
+
   /*
    * Options with additional size argument
    *
