@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-13 15:19:20 +0200 (Tue, 13 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9887 $
+ *     $Date: 2010-04-06 14:58:53 +0200 (Tue, 06 Apr 2010) $ by $Author: tack $
+ *     $Revision: 10649 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -56,6 +56,12 @@ namespace Gecode { namespace Driver {
         fs((fail > 0) ? new Search::FailStop(fail) : NULL),
         ts((time > 0) ? new Search::TimeStop(time) : NULL) {}
   public:
+    /// Reason why search has been stopped
+    enum {
+      SR_NODE = 1 << 0, ///< Node limit reached
+      SR_FAIL = 1 << 1, ///< Fail limit reached
+      SR_TIME = 1 << 2  ///< Time limit reached
+    };
     /// Test whether search must be stopped
     virtual bool stop(const Search::Statistics& s, const Search::Options& o) {
       return
@@ -63,6 +69,13 @@ namespace Gecode { namespace Driver {
         ((fs != NULL) && fs->stop(s,o)) ||
         ((ts != NULL) && ts->stop(s,o));
     }
+    /// Report reason why search has been stopped
+    int reason(const Search::Statistics& s, const Search::Options& o) {
+      return 
+        (((ns != NULL) && ns->stop(s,o)) ? SR_NODE : 0) |
+        (((fs != NULL) && fs->stop(s,o)) ? SR_FAIL : 0) |
+        (((ts != NULL) && ts->stop(s,o)) ? SR_TIME : 0);
+    }
     /// Create appropriate stop-object
     static Search::Stop*
     create(unsigned int node, unsigned int fail, unsigned int time) {
@@ -154,11 +167,21 @@ namespace Gecode { namespace Driver {
 #ifdef GECODE_HAS_GIST
         {
           Gist::Print<Script> pi(o.name());
+          Gist::VarComparator<Script> vc(o.name());
           Gist::Options opt;
           opt.inspect.click(&pi);
+          opt.inspect.compare(&vc);
           opt.clone = false;
           opt.c_d   = o.c_d();
           opt.a_d   = o.a_d();
+          for (int i=0; o.inspect.click(i) != NULL; i++)
+            opt.inspect.click(o.inspect.click(i));
+          for (int i=0; o.inspect.solution(i) != NULL; i++)
+            opt.inspect.solution(o.inspect.solution(i));
+          for (int i=0; o.inspect.move(i) != NULL; i++)
+            opt.inspect.move(o.inspect.move(i));
+          for (int i=0; o.inspect.compare(i) != NULL; i++)
+            opt.inspect.compare(o.inspect.compare(i));
           Script* s = new Script(o);
           (void) GistEngine<Engine<Script> >::explore(s, opt);
         }
@@ -190,6 +213,18 @@ namespace Gecode { namespace Driver {
           } while (--i != 0);
           Search::Statistics stat = e.statistics();
           cout << endl;
+          if (e.stopped()) {
+            cout << "Search engine stopped..." << endl
+                 << "\treason: ";
+            int r = static_cast<Cutoff*>(so.stop)->reason(stat,so);
+            if (r & Cutoff::SR_NODE)
+              cout << "node ";
+            if (r & Cutoff::SR_FAIL)
+              cout << "fail ";
+            if (r & Cutoff::SR_TIME)
+              cout << "time ";
+            cout << "limit reached" << endl << endl;
+          }
           cout << "Initial" << endl
                << "\tpropagators: " << n_p << endl
                << "\tbranchers:   " << n_b << endl
@@ -277,7 +312,7 @@ namespace Gecode { namespace Driver {
           }
           double m = am(ts,o.samples());
           double d = dev(ts,o.samples()) * 100.0;
-          delete[] ts;
+          delete [] ts;
           cout << "\tRuntime: "
                << setw(20) << right
                << showpoint << fixed
