@@ -7,8 +7,8 @@
  *     Guido Tack, 2007
  *
  *  Last modified:
- *     $Date: 2009-10-28 10:31:54 +0100 (Wed, 28 Oct 2009) $ by $Author: tack $
- *     $Revision: 9995 $
+ *     $Date: 2010-04-07 19:54:19 +0200 (Wed, 07 Apr 2010) $ by $Author: tack $
+ *     $Revision: 10678 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -37,6 +37,7 @@
 
 #include <gecode/flatzinc.hh>
 #include <gecode/flatzinc/registry.hh>
+#include <gecode/flatzinc/plugin.hh>
 
 #include <gecode/search.hh>
 
@@ -111,6 +112,14 @@ namespace Gecode { namespace FlatZinc {
           INT_VAR_DEGREE_MAX);
       if (s->id == "random")
         return TieBreakVarBranch<IntVarBranch>(INT_VAR_RND);
+      if (s->id == "afc_min")
+        return TieBreakVarBranch<IntVarBranch>(INT_VAR_AFC_MIN);
+      if (s->id == "afc_max")
+        return TieBreakVarBranch<IntVarBranch>(INT_VAR_AFC_MAX);
+      if (s->id == "size_afc_min")
+        return TieBreakVarBranch<IntVarBranch>(INT_VAR_SIZE_AFC_MIN);
+      if (s->id == "size_afc_max")
+        return TieBreakVarBranch<IntVarBranch>(INT_VAR_SIZE_AFC_MAX);
     }
     std::cerr << "Warning, ignored search annotation: ";
     ann->print(std::cerr);
@@ -141,6 +150,23 @@ namespace Gecode { namespace FlatZinc {
     return INT_VAL_MIN;
   }
 
+  IntAssign ann2asnivalsel(AST::Node* ann) {
+    if (AST::Atom* s = dynamic_cast<AST::Atom*>(ann)) {
+      if (s->id == "indomain_min")
+        return INT_ASSIGN_MIN;
+      if (s->id == "indomain_max")
+        return INT_ASSIGN_MAX;
+      if (s->id == "indomain_median")
+        return INT_ASSIGN_MED;
+      if (s->id == "indomain_random")
+        return INT_ASSIGN_RND;
+    }
+    std::cerr << "Warning, ignored search annotation: ";
+    ann->print(std::cerr);
+    std::cerr << std::endl;
+    return INT_ASSIGN_MIN;
+  }
+
 #ifdef GECODE_HAS_SET_VARS
   SetVarBranch ann2svarsel(AST::Node* ann) {
     if (AST::Atom* s = dynamic_cast<AST::Atom*>(ann)) {
@@ -180,31 +206,43 @@ namespace Gecode { namespace FlatZinc {
 #endif
 
   FlatZincSpace::FlatZincSpace(bool share, FlatZincSpace& f)
-    : Space(share, f) {
+    : Space(share, f), _solveAnnotations(NULL), iv_boolalias(NULL) {
       _optVar = f._optVar;
       _method = f._method;
       iv.update(*this, share, f.iv);
+      intVarCount = f.intVarCount;
       bv.update(*this, share, f.bv);
+      boolVarCount = f.boolVarCount;
 #ifdef GECODE_HAS_SET_VARS
       sv.update(*this, share, f.sv);
+      setVarCount = f.setVarCount;
 #endif
     }
   
-  FlatZincSpace::FlatZincSpace(int intVars,
-                                 int boolVars,
+  FlatZincSpace::FlatZincSpace(void)
+  : intVarCount(-1), boolVarCount(-1), setVarCount(-1), _optVar(-1),
+    _solveAnnotations(NULL) {}
+
+  void
+  FlatZincSpace::init(int intVars, int boolVars,
 #ifdef GECODE_HAS_SET_VARS
-                                 int setVars)
+                                 int setVars) {
 #else
-                                 int)
+                                 int) {
 #endif
-  : intVarCount(0), boolVarCount(0), setVarCount(0),
-    iv(*this, intVars), iv_introduced(intVars),
-    bv(*this, boolVars), bv_introduced(boolVars)
+    intVarCount = 0;
+    iv = IntVarArray(*this, intVars);
+    iv_introduced = std::vector<bool>(intVars);
+    iv_boolalias = alloc<int>(intVars+(intVars==0?1:0));
+    boolVarCount = 0;
+    bv = BoolVarArray(*this, boolVars);
+    bv_introduced = std::vector<bool>(boolVars);
 #ifdef GECODE_HAS_SET_VARS
-    , sv(*this, setVars),
-      sv_introduced(setVars)
+    setVarCount = 0;
+    sv = SetVarArray(*this, setVars);
+    sv_introduced = std::vector<bool>(setVars);
 #endif
-    {}
+  }
 
   void
   FlatZincSpace::newIntVar(IntVarSpec* vs) {
@@ -214,6 +252,16 @@ namespace Gecode { namespace FlatZinc {
       iv[intVarCount++] = IntVar(*this, vs2is(vs));
     }
     iv_introduced[intVarCount-1] = vs->introduced;
+    iv_boolalias[intVarCount-1] = -1;
+  }
+
+  void
+  FlatZincSpace::aliasBool2Int(int iv, int bv) {
+    iv_boolalias[iv] = bv;
+  }
+  int
+  FlatZincSpace::aliasBool2Int(int iv) {
+    return iv_boolalias[iv];
   }
 
   void
@@ -298,31 +346,73 @@ namespace Gecode { namespace FlatZinc {
   }
 
   void
-  FlatZincSpace::parseSolveAnn(AST::Array* ann) {
+  FlatZincSpace::createBranchers(AST::Node* ann, bool ignoreUnknown,
+                                 std::ostream& err) {
     bool hadSearchAnnotation = false;
     if (ann) {
       std::vector<AST::Node*> flatAnn;
-      flattenAnnotations(ann, flatAnn);
+      if (ann->isArray()) {
+        flattenAnnotations(ann->getArray()  , flatAnn);
+      } else {
+        flatAnn.push_back(ann);
+      }
 
       for (unsigned int i=0; i<flatAnn.size(); i++) {
-        try {
+        if (flatAnn[i]->isCall("gecode_search")) {
+          AST::Call* c = flatAnn[i]->getCall();
+          branchWithPlugin(c->args);
+        } else try {
           AST::Call *call = flatAnn[i]->getCall("int_search");
           AST::Array *args = call->getArgs(4);
           AST::Array *vars = args->a[0]->getArray();
-          IntVarArgs va(vars->a.size());
-          for (int i=vars->a.size(); i--; )
-            va[i] = iv[vars->a[i]->getIntVar()];
+          int k=vars->a.size();
+          for (int i=vars->a.size(); i--;)
+            if (vars->a[i]->isInt())
+              k--;
+          IntVarArgs va(k);
+          k=0;
+          for (unsigned int i=0; i<vars->a.size(); i++) {
+            if (vars->a[i]->isInt())
+              continue;
+            va[k++] = iv[vars->a[i]->getIntVar()];
+          }
           branch(*this, va, ann2ivarsel(args->a[1]), ann2ivalsel(args->a[2]));
           hadSearchAnnotation = true;
+        } catch (AST::TypeError& e) {
+        try {
+          AST::Call *call = flatAnn[i]->getCall("int_assign");
+          AST::Array *args = call->getArgs(2);
+          AST::Array *vars = args->a[0]->getArray();
+          int k=vars->a.size();
+          for (int i=vars->a.size(); i--;)
+            if (vars->a[i]->isInt())
+              k--;
+          IntVarArgs va(k);
+          k=0;
+          for (unsigned int i=0; i<vars->a.size(); i++) {
+            if (vars->a[i]->isInt())
+              continue;
+            va[k++] = iv[vars->a[i]->getIntVar()];
+          }
+          assign(*this, va, ann2asnivalsel(args->a[1]));
+          hadSearchAnnotation = true;
         } catch (AST::TypeError& e) {
           (void) e;
           try {
             AST::Call *call = flatAnn[i]->getCall("bool_search");
             AST::Array *args = call->getArgs(4);
             AST::Array *vars = args->a[0]->getArray();
-            BoolVarArgs va(vars->a.size());
-            for (int i=vars->a.size(); i--; )
-              va[i] = bv[vars->a[i]->getBoolVar()];
+            int k=vars->a.size();
+            for (int i=vars->a.size(); i--;)
+              if (vars->a[i]->isBool())
+                k--;
+            BoolVarArgs va(k);
+            k=0;
+            for (unsigned int i=0; i<vars->a.size(); i++) {
+              if (vars->a[i]->isBool())
+                continue;
+              va[k++] = bv[vars->a[i]->getBoolVar()];
+            }
             branch(*this, va, ann2ivarsel(args->a[1]), 
                    ann2ivalsel(args->a[2]));        
             hadSearchAnnotation = true;
@@ -333,25 +423,38 @@ namespace Gecode { namespace FlatZinc {
               AST::Call *call = flatAnn[i]->getCall("set_search");
               AST::Array *args = call->getArgs(4);
               AST::Array *vars = args->a[0]->getArray();
-              SetVarArgs va(vars->a.size());
-              for (int i=vars->a.size(); i--; )
-                va[i] = sv[vars->a[i]->getSetVar()];
+              int k=vars->a.size();
+              for (int i=vars->a.size(); i--;)
+                if (vars->a[i]->isSet())
+                  k--;
+              SetVarArgs va(k);
+              k=0;
+              for (unsigned int i=0; i<vars->a.size(); i++) {
+                if (vars->a[i]->isSet())
+                  continue;
+                va[k++] = sv[vars->a[i]->getSetVar()];
+              }
               branch(*this, va, ann2svarsel(args->a[1]), 
                                ann2svalsel(args->a[2]));        
               hadSearchAnnotation = true;
             } catch (AST::TypeError& e) {
               (void) e;
-              std::cerr << "Warning, ignored search annotation: ";
-              flatAnn[i]->print(std::cerr);
-              std::cerr << std::endl;
+              if (!ignoreUnknown) {
+                err << "Warning, ignored search annotation: ";
+                flatAnn[i]->print(err);
+                err << std::endl;
+              }
             }
 #else
-            std::cerr << "Warning, ignored search annotation: ";
-            flatAnn[i]->print(std::cerr);
-            std::cerr << std::endl;
+            if (!ignoreUnknown) {
+              err << "Warning, ignored search annotation: ";
+              flatAnn[i]->print(err);
+              err << std::endl;
+            }
 #endif
           }
         }
+        }
       }
     }
     if (!hadSearchAnnotation) {
@@ -387,32 +490,55 @@ namespace Gecode { namespace FlatZinc {
     }
   }
 
+  AST::Array*
+  FlatZincSpace::solveAnnotations(void) const {
+    return _solveAnnotations;
+  }
+
   void
   FlatZincSpace::solve(AST::Array* ann) {
     _method = SAT;
-    parseSolveAnn(ann);
+    _solveAnnotations = ann;
   }
 
   void
   FlatZincSpace::minimize(int var, AST::Array* ann) {
     _method = MIN;
     _optVar = var;
-    parseSolveAnn(ann);
+    _solveAnnotations = ann;
     // Branch on optimization variable to ensure that it is given a value.
-    IntVarArgs optVar(1);
-    optVar[0] = iv[_optVar];
-    branch(*this, optVar, INT_VAR_NONE, INT_VAL_MIN);
+    AST::Array* args = new AST::Array(4);
+    args->a[0] = new AST::Array(new AST::IntVar(_optVar));
+    args->a[1] = new AST::Atom("input_order");
+    args->a[2] = new AST::Atom("indomain_min");
+    args->a[3] = new AST::Atom("complete");
+    AST::Call* c = new AST::Call("int_search", args);
+    if (!ann)
+      ann = new AST::Array(c);
+    else
+      ann->a.push_back(c);
   }
 
   void
   FlatZincSpace::maximize(int var, AST::Array* ann) {
     _method = MAX;
     _optVar = var;
-    parseSolveAnn(ann);
+    _solveAnnotations = ann;
     // Branch on optimization variable to ensure that it is given a value.
-    IntVarArgs optVar(1);
-    optVar[0] = iv[_optVar];
-    branch(*this, optVar, INT_VAR_NONE, INT_VAL_MAX);
+    AST::Array* args = new AST::Array(4);
+    args->a[0] = new AST::Array(new AST::IntVar(_optVar));
+    args->a[1] = new AST::Atom("input_order");
+    args->a[2] = new AST::Atom("indomain_min");
+    args->a[3] = new AST::Atom("complete");
+    AST::Call* c = new AST::Call("int_search", args);
+    if (!ann)
+      ann = new AST::Array(c);
+    else
+      ann->a.push_back(c);
+  }
+
+  FlatZincSpace::~FlatZincSpace(void) {
+    delete _solveAnnotations;
   }
 
 #ifdef GECODE_HAS_GIST
@@ -428,8 +554,11 @@ namespace Gecode { namespace FlatZinc {
   template<typename S>
   class GistEngine<DFS<S> > {
   public:
-    static void explore(S* root, Gist::Inspector* i) {
-      Gecode::Gist::Options o; o.inspect.click(i);
+    static void explore(S* root, const FlatZincOptions& opt,
+                        Gist::Inspector* i) {
+      Gecode::Gist::Options o;
+      o.c_d = opt.c_d(); o.a_d = opt.a_d();
+      o.inspect.click(i);
       (void) Gecode::Gist::dfs(root, o);
     }
   };
@@ -438,8 +567,11 @@ namespace Gecode { namespace FlatZinc {
   template<typename S>
   class GistEngine<LDS<S> > {
   public:
-    static void explore(S* root, Gist::Inspector* i) {
-      Gecode::Gist::Options o; o.inspect.click(i);
+    static void explore(S* root, const FlatZincOptions& opt,
+                        Gist::Inspector* i) {
+      Gecode::Gist::Options o;
+      o.c_d = opt.c_d(); o.a_d = opt.a_d();
+      o.inspect.click(i);
       (void) Gecode::Gist::dfs(root, o);
     }
   };
@@ -448,8 +580,11 @@ namespace Gecode { namespace FlatZinc {
   template<typename S>
   class GistEngine<BAB<S> > {
   public:
-    static void explore(S* root, Gist::Inspector* i) {
-      Gecode::Gist::Options o; o.inspect.click(i);
+    static void explore(S* root, const FlatZincOptions& opt,
+                        Gist::Inspector* i) {
+      Gecode::Gist::Options o;
+      o.c_d = opt.c_d(); o.a_d = opt.a_d();
+      o.inspect.click(i);
       (void) Gecode::Gist::bab(root, o);
     }
   };
@@ -458,15 +593,19 @@ namespace Gecode { namespace FlatZinc {
   template<typename S>
   class GistEngine<Restart<S> > {
   public:
-    static void explore(S* root, Gist::Inspector* i) {
-      Gecode::Gist::Options o; o.inspect.click = i;
+    static void explore(S* root, const FlatZincOptions& opt,
+                        Gist::Inspector* i) {
+      Gecode::Gist::Options o;
+      o.c_d = opt.c_d(); o.a_d = opt.a_d();
+      o.inspect.click(i);
       (void) Gecode::Gist::bab(root, o);
     }
   };
 
   /// \brief An inspector for printing simple text output
   template<class S>
-  class FZPrintingInspector : public Gecode::Gist::TextInspector {
+  class FZPrintingInspector
+   : public Gecode::Gist::TextOutput, public Gecode::Gist::Inspector {
   private:
     const Printer& p;
   public:
@@ -474,11 +613,13 @@ namespace Gecode { namespace FlatZinc {
     FZPrintingInspector(const Printer& p0);
     /// Use the print method of the template class S to print a space
     virtual void inspect(const Space& node);
+    /// Finalize when Gist exits
+    virtual void finalize(void);
   };
 
   template<class S>
   FZPrintingInspector<S>::FZPrintingInspector(const Printer& p0)
-  : TextInspector("Gecode/FlatZinc"), p(p0) {}
+  : TextOutput("Gecode/FlatZinc"), p(p0) {}
 
   template<class S>
   void
@@ -488,6 +629,12 @@ namespace Gecode { namespace FlatZinc {
     getStream() << std::endl;
   }
 
+  template<class S>
+  void
+  FZPrintingInspector<S>::finalize(void) {
+    Gecode::Gist::TextOutput::finalize();
+  }
+
 #endif
 
   template<template<class> class Engine>
@@ -497,7 +644,7 @@ namespace Gecode { namespace FlatZinc {
 #ifdef GECODE_HAS_GIST
     if (opt.mode() == SM_GIST) {
       FZPrintingInspector<FlatZincSpace> pi(p);
-      (void) GistEngine<Engine<FlatZincSpace> >::explore(this,&pi);
+      (void) GistEngine<Engine<FlatZincSpace> >::explore(this,opt,&pi);
       return;
     }
 #endif
@@ -516,15 +663,31 @@ namespace Gecode { namespace FlatZinc {
     Engine<FlatZincSpace> se(this,o);
     int noOfSolutions = _method == SAT ? opt.solutions() : 0;
     int findSol = noOfSolutions;
-    while (FlatZincSpace* sol = se.next()) {
-      sol->print(out, p);
-      out << "----------" << std::endl;
+    FlatZincSpace* sol = NULL;
+    while (FlatZincSpace* next_sol = se.next()) {
       delete sol;
+      sol = next_sol;
+      if (opt.print()==0) {
+        sol->print(out, p);
+        out << "----------" << std::endl;
+      }
       if (--findSol==0)
         goto stopped;
     }
-    if (!se.stopped())
-      out << "==========" << endl;
+    if (sol && opt.print()!=0) {
+      sol->print(out, p);
+      out << "----------" << std::endl;
+    }
+    if (!se.stopped()) {
+      if (sol) {
+        out << "==========" << endl;
+      } else {
+        out << "=====UNSATISFIABLE=====" << endl;
+      }
+    } else if (!sol) {
+        out << "=====UNKNOWN=====" << endl;
+    }
+    delete sol;
     stopped:
     if (opt.mode() == SM_STAT) {
       Gecode::Search::Statistics stat = se.statistics();
@@ -550,13 +713,53 @@ namespace Gecode { namespace FlatZinc {
     }
   }
 
+#ifdef GECODE_HAS_QT
+  void
+  FlatZincSpace::branchWithPlugin(AST::Node* ann) {
+    if (AST::Call* c = dynamic_cast<AST::Call*>(ann)) {
+      QString pluginName(c->id.c_str());
+      if (QLibrary::isLibrary(pluginName+".dll")) {
+        pluginName += ".dll";
+      } else if (QLibrary::isLibrary(pluginName+".dylib")) {
+        pluginName = "lib" + pluginName + ".dylib";
+      } else if (QLibrary::isLibrary(pluginName+".so")) {
+        // Must check .so after .dylib so that Mac OS uses .dylib
+        pluginName = "lib" + pluginName + ".so";
+      }
+      QPluginLoader pl(pluginName);
+      QObject* plugin_o = pl.instance();
+      if (!plugin_o) {
+        throw FlatZinc::Error("FlatZinc",
+          "Error loading plugin "+pluginName.toStdString()+
+          ": "+pl.errorString().toStdString());
+      }
+      BranchPlugin* pb = qobject_cast<BranchPlugin*>(plugin_o);
+      if (!pb) {
+        throw FlatZinc::Error("FlatZinc",
+        "Error loading plugin "+pluginName.toStdString()+
+        ": does not contain valid PluginBrancher");
+      }
+      pb->branch(*this, c);
+    }
+  }
+#else
+  void
+  FlatZincSpace::branchWithPlugin(AST::Node* ann) {
+    throw FlatZinc::Error("FlatZinc",
+      "Branching with plugins not supported (requires Qt support)");
+  }
+#endif
+
   void
   FlatZincSpace::run(std::ostream& out, const Printer& p,
                       const FlatZincOptions& opt, Support::Timer& t_total) {
     switch (_method) {
     case MIN:
     case MAX:
-      runEngine<BAB>(out,p,opt,t_total);
+      if (opt.search() == FlatZincOptions::FZ_SEARCH_BAB)
+        runEngine<BAB>(out,p,opt,t_total);
+      else
+        runEngine<Restart>(out,p,opt,t_total);
       break;
     case SAT:
       runEngine<DFS>(out,p,opt,t_total);
@@ -569,7 +772,7 @@ namespace Gecode { namespace FlatZinc {
     if (_method == MIN)
       rel(*this, iv[_optVar], IRT_LE, 
                  static_cast<const FlatZincSpace*>(&s)->iv[_optVar].val());
-    else
+    else if (_method == MAX)
       rel(*this, iv[_optVar], IRT_GR,
                  static_cast<const FlatZincSpace*>(&s)->iv[_optVar].val());
   }
@@ -580,10 +783,15 @@ namespace Gecode { namespace FlatZinc {
   }
 
   FlatZincSpace::Meth
-  FlatZincSpace::method(void) {
+  FlatZincSpace::method(void) const {
     return _method;
   }
 
+  int
+  FlatZincSpace::optVar(void) const {
+    return _optVar;
+  }
+
   void
   FlatZincSpace::print(std::ostream& out, const Printer& p) const {
     p.print(out, iv, bv
@@ -593,6 +801,15 @@ namespace Gecode { namespace FlatZinc {
     );
   }
 
+  void
+  FlatZincSpace::shrinkArrays(Printer& p) {
+    p.shrinkArrays(*this, _optVar, iv, bv
+#ifdef GECODE_HAS_SET_VARS
+    , sv
+#endif
+    );
+  }
+
   void
   Printer::init(AST::Array* output) {
     _output = output;
@@ -703,40 +920,6 @@ namespace Gecode { namespace FlatZinc {
             out << ", ";
         }
         out << "]";
-      } else if (ai->isCall("ifthenelse")) {
-        AST::Array* aia = ai->getCall("ifthenelse")->getArgs(3);
-        if (aia->a[0]->isBool()) {
-          if (aia->a[0]->getBool())
-            printElem(out, aia->a[1], iv,bv
-#ifdef GECODE_HAS_SET_VARS
-            ,sv
-#endif
-            );
-          else
-            printElem(out, aia->a[2], iv,bv
-#ifdef GECODE_HAS_SET_VARS
-            ,sv
-#endif
-            );
-        } else if (aia->a[0]->isBoolVar()) {
-          BoolVar b = bv[aia->a[0]->getBoolVar()];
-          if (b.one())
-            printElem(out, aia->a[1], iv,bv
-#ifdef GECODE_HAS_SET_VARS
-            ,sv
-#endif
-            );
-          else if (b.zero())
-            printElem(out, aia->a[2], iv,bv
-#ifdef GECODE_HAS_SET_VARS
-            ,sv
-#endif
-            );
-          else
-            std::cerr << "Error: Condition not fixed." << std::endl;
-        } else {
-          std::cerr << "Error: Condition not Boolean." << std::endl;        
-        }
       } else {
         printElem(out,ai,iv,bv
 #ifdef GECODE_HAS_SET_VARS
@@ -747,6 +930,104 @@ namespace Gecode { namespace FlatZinc {
     }
   }
 
+  void
+  Printer::shrinkElement(AST::Node* node,
+                         std::map<int,int>& iv, std::map<int,int>& bv, 
+                         std::map<int,int>& sv) {
+    if (node->isIntVar()) {
+      AST::IntVar* x = static_cast<AST::IntVar*>(node);
+      if (iv.find(x->i) == iv.end()) {
+        int newi = iv.size();
+        iv[x->i] = newi;
+      }
+      x->i = iv[x->i];
+    } else if (node->isBoolVar()) {
+      AST::BoolVar* x = static_cast<AST::BoolVar*>(node);
+      if (bv.find(x->i) == bv.end()) {
+        int newi = bv.size();
+        bv[x->i] = newi;
+      }
+      x->i = bv[x->i];
+    } else if (node->isSetVar()) {
+      AST::SetVar* x = static_cast<AST::SetVar*>(node);
+      if (sv.find(x->i) == sv.end()) {
+        int newi = sv.size();
+        sv[x->i] = newi;
+      }
+      x->i = sv[x->i];      
+    }
+  }
+
+  void
+  Printer::shrinkArrays(Space& home,
+                        int& optVar,
+                        Gecode::IntVarArray& iv,
+                        Gecode::BoolVarArray& bv
+#ifdef GECODE_HAS_SET_VARS
+                        ,
+                        Gecode::SetVarArray& sv
+#endif
+                       ) {
+    if (_output == NULL) {
+      iv.resize(home, 0);
+      bv.resize(home, 0);
+#ifdef GECODE_HAS_SET_VARS
+      sv.resize(home, 0);
+#endif
+      return;
+    }
+    std::map<int,int> iv_new;
+    std::map<int,int> bv_new;
+    std::map<int,int> sv_new;
+
+    if (optVar != -1) {
+      iv_new[optVar] = 0;
+      optVar = 0;
+    }
+
+    for (unsigned int i=0; i< _output->a.size(); i++) {
+      AST::Node* ai = _output->a[i];
+      if (ai->isArray()) {
+        AST::Array* aia = ai->getArray();
+        for (unsigned int j=0; j<aia->a.size(); j++) {
+          shrinkElement(aia->a[j],iv_new,bv_new,sv_new);
+        }
+      } else {
+        shrinkElement(ai,iv_new,bv_new,sv_new);
+      }
+    }
+    if (static_cast<int>(iv_new.size()) != iv.size()) {
+      IntVarArgs iva(iv_new.size());
+      for (map<int,int>::iterator i=iv_new.begin(); i != iv_new.end(); ++i) {
+        iva[(*i).second] = iv[(*i).first];
+      }
+      for (int i=iva.size(); i--;)
+        iv[i] = iva[i];
+      iv.resize(home, iva.size());
+    }
+
+    if (static_cast<int>(bv_new.size()) != bv.size()) {
+      BoolVarArgs bva(bv_new.size());
+      for (map<int,int>::iterator i=bv_new.begin(); i != bv_new.end(); ++i) {
+        bva[(*i).second] = bv[(*i).first];
+      }
+      for (int i=bva.size(); i--;)
+        bv[i] = bva[i];
+      bv.resize(home, bva.size());
+    }
+#ifdef GECODE_HAS_SET_VARS
+    if (static_cast<int>(sv_new.size()) != sv.size()) {
+      SetVarArgs sva(sv_new.size());
+      for (map<int,int>::iterator i=sv_new.begin(); i != sv_new.end(); ++i) {
+        sva[(*i).second] = sv[(*i).first];
+      }
+      for (int i=sva.size(); i--;)
+        sv[i] = sva[i];
+      sv.resize(home, sva.size());
+    }
+#endif
+  }
+
   Printer::~Printer(void) {
     delete _output;
   }
