@@ -11,8 +11,8 @@
  *     Mikael Lagerkvist, 2009
  *
  *  Last modified:
- *     $Date: 2009-10-21 09:09:01 +0200 (Wed, 21 Oct 2009) $ by $Author: tack $
- *     $Revision: 9978 $
+ *     $Date: 2010-04-07 13:30:58 +0200 (Wed, 07 Apr 2010) $ by $Author: tack $
+ *     $Revision: 10664 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -43,6 +43,7 @@
 #include <gecode/kernel.hh>
 #include <gecode/int.hh>
 #include <gecode/scheduling.hh>
+#include <gecode/graph.hh>
 #include <gecode/minimodel.hh>
 #ifdef GECODE_HAS_SET_VARS
 #include <gecode/set.hh>
@@ -134,7 +135,23 @@ namespace Gecode { namespace FlatZinc {
       return ia;
     }
 
-    inline IntSetArgs arg2intsetargs(AST::Node* arg, int offset = 0) {
+    inline IntSet arg2intset(FlatZincSpace& s, AST::Node* n) {
+      AST::SetLit* sl = n->getSet();
+      IntSet d;
+      if (sl->interval) {
+        d = IntSet(sl->min, sl->max);
+      } else {
+        Region re(s);
+        int* is = re.alloc<int>(static_cast<unsigned long int>(sl->s.size()));
+        for (int i=sl->s.size(); i--; )
+          is[i] = sl->s[i];
+        d = IntSet(is, sl->s.size());
+      }
+      return d;
+    }
+
+    inline IntSetArgs arg2intsetargs(FlatZincSpace& s,
+                                     AST::Node* arg, int offset = 0) {
       AST::Array* a = arg->getArray();
       if (a->a.size() == 0) {
         IntSetArgs emptyIa(0);
@@ -144,17 +161,7 @@ namespace Gecode { namespace FlatZinc {
       for (int i=offset; i--;)
         ia[i] = IntSet::empty;
       for (int i=a->a.size(); i--;) {
-        AST::SetLit* sl = a->a[i]->getSet();
-        if (sl->interval) {
-          ia[i+offset] = IntSet(sl->min, sl->max);
-        } else {
-          int* is =
-            heap.alloc<int>(static_cast<unsigned long int>(sl->s.size()));
-          for (int j=sl->s.size(); j--; )
-            is[j] = sl->s[j];
-          ia[i+offset] = IntSet(is, sl->s.size());
-          heap.free(is,static_cast<unsigned long int>(sl->s.size()));
-        }
+        ia[i+offset] = arg2intset(s, a->a[i]);
       }
       return ia;
     }
@@ -182,22 +189,27 @@ namespace Gecode { namespace FlatZinc {
     }
 
     inline BoolVarArgs arg2boolvarargs(FlatZincSpace& s, AST::Node* arg,
-                                       int offset = 0) {
+                                       int offset = 0, int siv=-1) {
       AST::Array* a = arg->getArray();
       if (a->a.size() == 0) {
         BoolVarArgs emptyIa(0);
         return emptyIa;
       }
-      BoolVarArgs ia(a->a.size()+offset);
+      BoolVarArgs ia(a->a.size()+offset-(siv==-1?0:1));
       for (int i=offset; i--;)
         ia[i] = BoolVar(s, 0, 0);
-      for (int i=a->a.size(); i--;) {
+      for (int i=0; i<static_cast<int>(a->a.size()); i++) {
+        if (i==siv)
+          continue;
         if (a->a[i]->isBool()) {
           bool value = a->a[i]->getBool();
           BoolVar iv(s, value, value);
-          ia[i+offset] = iv;
+          ia[offset++] = iv;
+        } else if (a->a[i]->isIntVar() &&
+                   s.aliasBool2Int(a->a[i]->getIntVar()) != -1) {
+          ia[offset++] = s.bv[s.aliasBool2Int(a->a[i]->getIntVar())];
         } else {
-          ia[i+offset] = s.bv[a->a[i]->getBoolVar()];
+          ia[offset++] = s.bv[a->a[i]->getBoolVar()];
         }
       }
       return ia;
@@ -207,18 +219,8 @@ namespace Gecode { namespace FlatZinc {
     SetVar getSetVar(FlatZincSpace& s, AST::Node* n) {
       SetVar x0;
       if (!n->isSetVar()) {
-        AST::SetLit* sl = n->getSet();
-        if (sl->interval) {
-          IntSet d(sl->min, sl->max);
-          x0 = SetVar(s, d, d);        
-        } else {
-          Region re(s);
-          int* is = re.alloc<int>(static_cast<unsigned long int>(sl->s.size()));
-          for (int i=sl->s.size(); i--; )
-            is[i] = sl->s[i];
-          IntSet d(is, sl->s.size());
-          x0 = SetVar(s, d, d);
-        }
+        IntSet d = arg2intset(s,n);
+        x0 = SetVar(s, d, d);        
       } else {
         x0 = s.sv[n->getSetVar()];
       }
@@ -263,6 +265,27 @@ namespace Gecode { namespace FlatZinc {
       return x0;
     }
 
+    bool isBoolArray(FlatZincSpace& s, AST::Node* b, int& singleInt) {
+      AST::Array* a = b->getArray();
+      singleInt = -1;
+      if (a->a.size() == 0)
+        return true;
+      for (int i=a->a.size(); i--;) {
+        if (a->a[i]->isBoolVar() || a->a[i]->isBool()) {
+        } else if (a->a[i]->isIntVar()) {
+          if (s.aliasBool2Int(a->a[i]->getIntVar()) == -1) {
+            if (singleInt != -1) {
+              return false;
+            }
+            singleInt = i;
+          }
+        } else {
+          return false;
+        }
+      }
+      return true;
+    }
+
     void p_distinct(FlatZincSpace& s, const ConExpr& ce, AST::Node* ann) {
       IntVarArgs va = arg2intvarargs(s, ce[0]);
       distinct(s, va, ann2icl(ann));    
@@ -277,6 +300,11 @@ namespace Gecode { namespace FlatZinc {
       distinct(s, oa, va, ann2icl(ann));
     }
 
+    void p_all_equal(FlatZincSpace& s, const ConExpr& ce, AST::Node* ann) {
+      IntVarArgs va = arg2intvarargs(s, ce[0]);
+      rel(s, va, IRT_EQ, ann2icl(ann));
+    }
+
     void p_int_CMP(FlatZincSpace& s, IntRelType irt, const ConExpr& ce, 
                    AST::Node* ann) {
       if (ce[0]->isIntVar()) {
@@ -357,8 +385,31 @@ namespace Gecode { namespace FlatZinc {
     void p_int_lin_CMP(FlatZincSpace& s, IntRelType irt, const ConExpr& ce,
                        AST::Node* ann) {
       IntArgs ia = arg2intargs(ce[0]);
-      IntVarArgs iv = arg2intvarargs(s, ce[1]);
-      linear(s, ia, iv, irt, ce[2]->getInt(), ann2icl(ann));
+      int singleIntVar;
+      if (isBoolArray(s,ce[1],singleIntVar)) {
+        if (singleIntVar != -1) {
+          if (std::abs(ia[singleIntVar]) == 1 && ce[2]->getInt() == 0) {
+            IntVar siv = getIntVar(s, ce[1]->getArray()->a[singleIntVar]);
+            BoolVarArgs iv = arg2boolvarargs(s, ce[1], 0, singleIntVar);
+            IntArgs ia_tmp(ia.size()-1);
+            int count = 0;
+            for (int i=0; i<ia.size(); i++) {
+              if (i != singleIntVar)
+                ia_tmp[count++] = ia[singleIntVar] == -1 ? ia[i] : -ia[i];
+            }
+            linear(s, ia_tmp, iv, irt, siv, ann2icl(ann));
+          } else {
+            IntVarArgs iv = arg2intvarargs(s, ce[1]);
+            linear(s, ia, iv, irt, ce[2]->getInt(), ann2icl(ann));
+          }
+        } else {
+          BoolVarArgs iv = arg2boolvarargs(s, ce[1]);
+          linear(s, ia, iv, irt, ce[2]->getInt(), ann2icl(ann));
+        }
+      } else {
+        IntVarArgs iv = arg2intvarargs(s, ce[1]);
+        linear(s, ia, iv, irt, ce[2]->getInt(), ann2icl(ann));
+      }
     }
     void p_int_lin_CMP_reif(FlatZincSpace& s, IntRelType irt,
                             const ConExpr& ce, AST::Node* ann) {
@@ -371,9 +422,35 @@ namespace Gecode { namespace FlatZinc {
         return;
       }
       IntArgs ia = arg2intargs(ce[0]);
-      IntVarArgs iv = arg2intvarargs(s, ce[1]);
-      linear(s, ia, iv, irt, ce[2]->getInt(), getBoolVar(s, ce[3]), 
-             ann2icl(ann));
+      int singleIntVar;
+      if (isBoolArray(s,ce[1],singleIntVar)) {
+        if (singleIntVar != -1) {
+          if (std::abs(ia[singleIntVar]) == 1 && ce[2]->getInt() == 0) {
+            IntVar siv = getIntVar(s, ce[1]->getArray()->a[singleIntVar]);
+            BoolVarArgs iv = arg2boolvarargs(s, ce[1], 0, singleIntVar);
+            IntArgs ia_tmp(ia.size()-1);
+            int count = 0;
+            for (int i=0; i<ia.size(); i++) {
+              if (i != singleIntVar)
+                ia_tmp[count++] = ia[singleIntVar] == -1 ? ia[i] : -ia[i];
+            }
+            linear(s, ia_tmp, iv, irt, siv, getBoolVar(s, ce[3]), 
+                   ann2icl(ann));
+          } else {
+            IntVarArgs iv = arg2intvarargs(s, ce[1]);
+            linear(s, ia, iv, irt, ce[2]->getInt(),
+                   getBoolVar(s, ce[3]), ann2icl(ann));
+          }
+        } else {
+          BoolVarArgs iv = arg2boolvarargs(s, ce[1]);
+          linear(s, ia, iv, irt, ce[2]->getInt(),
+                 getBoolVar(s, ce[3]), ann2icl(ann));
+        }
+      } else {
+        IntVarArgs iv = arg2intvarargs(s, ce[1]);
+        linear(s, ia, iv, irt, ce[2]->getInt(), getBoolVar(s, ce[3]), 
+               ann2icl(ann));
+      }
     }
     void p_int_lin_eq(FlatZincSpace& s, const ConExpr& ce, AST::Node* ann) {
       p_int_lin_CMP(s, IRT_EQ, ce, ann);
@@ -566,8 +643,13 @@ namespace Gecode { namespace FlatZinc {
           rel(s, getBoolVar(s, ce[0]), irt, ce[1]->getBool(), ann2icl(ann));
         }
       } else {
-        rel(s, getBoolVar(s, ce[1]), swap(irt), ce[0]->getBool(), 
-            ann2icl(ann));
+        if (ce[1]->isBoolVar()) {
+          rel(s, getBoolVar(s, ce[1]), swap(irt), ce[0]->getBool(), 
+              ann2icl(ann));
+        } else {
+          if (ce[0]->getBool() != ce[1]->getBool())
+            s.fail();
+        }
       }
     }
     void p_bool_CMP_reif(FlatZincSpace& s, IntRelType irt, const ConExpr& ce, 
@@ -723,9 +805,30 @@ namespace Gecode { namespace FlatZinc {
     void p_bool2int(FlatZincSpace& s, const ConExpr& ce, AST::Node* ann) {
       BoolVar x0 = getBoolVar(s, ce[0]);
       IntVar x1 = getIntVar(s, ce[1]);
+      if (ce[0]->isBoolVar() && ce[1]->isIntVar()) {
+        s.aliasBool2Int(ce[1]->getIntVar(), ce[0]->getBoolVar());
+      }
       channel(s, x0, x1, ann2icl(ann));
     }
 
+    void p_int_in(FlatZincSpace& s, const ConExpr& ce, AST::Node *) {
+      IntSet d = arg2intset(s,ce[1]);
+      if (ce[0]->isBoolVar()) {
+        IntSetRanges dr(d);
+        Iter::Ranges::Singleton sr(0,1);
+        Iter::Ranges::Inter<IntSetRanges,Iter::Ranges::Singleton> i(dr,sr);
+        IntSet d01(i);
+        if (d01.size() == 0) {
+          s.fail();
+        } else {
+          rel(s, getBoolVar(s, ce[0]), IRT_GQ, d01.min());
+          rel(s, getBoolVar(s, ce[0]), IRT_LQ, d01.max());
+        }
+      } else {
+        dom(s, getIntVar(s, ce[0]), d);
+      }
+    }
+
     /* constraints from the standard library */
   
     void p_abs(FlatZincSpace& s, const ConExpr& ce, AST::Node* ann) {
@@ -784,13 +887,32 @@ namespace Gecode { namespace FlatZinc {
       IntVarArgs iv0 = arg2intvarargs(s, ce[0]);
       IntVarArgs iv1 = arg2intvarargs(s, ce[1]);
       int cmin = ce[2]->getInt();
-      if (cmin == 0) {
+
+      int smallest = cmin;
+      int largest = iv1.size()-1;
+      for (int i=iv0.size(); i--;) {
+        smallest = std::min(smallest, iv0[i].min());
+        largest = std::max(largest, iv0[i].max());
+      }
+      
+
+      if (cmin == 0 && smallest == 0 && largest == iv1.size()-1) {
         count(s, iv0, iv1, ann2icl(ann));      
       } else {
-        IntArgs values(iv1.size());
-        for (int i=values.size(); i--;)
-          values[i] = i+cmin;
-        count(s, iv0, iv1, values, ann2icl(ann));
+        IntArgs values(largest - smallest + 1);
+        for (int i=largest-smallest+1; i--;)
+          values[i] = i+smallest;
+        IntVarArgs iv1tmp(largest-smallest+1);
+        int k = 0;
+        for (int i=cmin-smallest; i--;) {
+          iv1tmp[k++] = IntVar(s, 0, iv0.size());
+        }
+        for (int i=0; i<iv1.size(); i++)
+          iv1tmp[k++] = iv1[i];
+        for (int i=k; i<iv1tmp.size(); i++) {
+          iv1tmp[i] = IntVar(s, 0, iv0.size());
+        }
+        count(s, iv0, iv1tmp, values, ann2icl(ann));
       }
     }
 
@@ -892,6 +1014,18 @@ namespace Gecode { namespace FlatZinc {
       rel(s,x,IRT_LQ,ann2icl(ann));
     }
 
+    void
+    p_decreasing_int(FlatZincSpace& s, const ConExpr& ce, AST::Node* ann) {
+      IntVarArgs x = arg2intvarargs(s, ce[0]);
+      rel(s,x,IRT_GQ,ann2icl(ann));
+    }
+
+    void
+    p_decreasing_bool(FlatZincSpace& s, const ConExpr& ce, AST::Node* ann) {
+      BoolVarArgs x = arg2boolvarargs(s, ce[0]);
+      rel(s,x,IRT_GQ,ann2icl(ann));
+    }
+
     void
     p_table_int(FlatZincSpace& s, const ConExpr& ce, AST::Node* ann) {
       IntVarArgs x = arg2intvarargs(s, ce[0]);
@@ -964,11 +1098,66 @@ namespace Gecode { namespace FlatZinc {
       }
     }
 
+    void p_among_seq_int(FlatZincSpace& s, const ConExpr& ce,
+                         AST::Node* ann) {
+      IntVarArgs x = arg2intvarargs(s, ce[0]);
+      IntSet S = arg2intset(s, ce[1]);
+      int q = ce[2]->getInt();
+      int l = ce[3]->getInt();
+      int u = ce[4]->getInt();
+      sequence(s, x, S, q, l, u, ann2icl(ann));
+    }
+
+    void p_among_seq_bool(FlatZincSpace& s, const ConExpr& ce,
+                          AST::Node* ann) {
+      BoolVarArgs x = arg2boolvarargs(s, ce[0]);
+      bool val = ce[1]->getBool();
+      int q = ce[2]->getInt();
+      int l = ce[3]->getInt();
+      int u = ce[4]->getInt();
+      IntSet S(val, val);
+      sequence(s, x, S, q, l, u, ann2icl(ann));
+    }
+
+    void p_schedule_unary(FlatZincSpace& s, const ConExpr& ce, AST::Node*) {
+      IntVarArgs x = arg2intvarargs(s, ce[0]);
+      IntArgs p = arg2intargs(ce[1]);
+      unary(s, x, p);
+    }
+
+    void p_schedule_unary_optional(FlatZincSpace& s, const ConExpr& ce,
+                                   AST::Node*) {
+      IntVarArgs x = arg2intvarargs(s, ce[0]);
+      IntArgs p = arg2intargs(ce[1]);
+      BoolVarArgs m = arg2boolvarargs(s, ce[2]);
+      unary(s, x, p, m);
+    }
+
+    void p_circuit(FlatZincSpace& s, const ConExpr& ce, AST::Node *ann) {
+      IntVarArgs xv = arg2intvarargs(s, ce[0]);
+      circuit(s,xv,ann2icl(ann));
+    }
+    void p_circuit_cost_array(FlatZincSpace& s, const ConExpr& ce,
+                              AST::Node *ann) {
+      IntArgs c = arg2intargs(ce[0]);
+      IntVarArgs xv = arg2intvarargs(s, ce[1]);
+      IntVarArgs yv = arg2intvarargs(s, ce[2]);
+      IntVar z = getIntVar(s, ce[3]);
+      circuit(s,c,xv,yv,z,ann2icl(ann));
+    }
+    void p_circuit_cost(FlatZincSpace& s, const ConExpr& ce, AST::Node *ann) {
+      IntArgs c = arg2intargs(ce[0]);
+      IntVarArgs xv = arg2intvarargs(s, ce[1]);
+      IntVar z = getIntVar(s, ce[2]);
+      circuit(s,c,xv,z,ann2icl(ann));
+    }
+
     class IntPoster {
     public:
       IntPoster(void) {
         registry().add("all_different_int", &p_distinct);
         registry().add("all_different_offset", &p_distinctOffset);
+        registry().add("all_equal_int", &p_all_equal);
         registry().add("int_eq", &p_int_eq);
         registry().add("int_ne", &p_int_ne);
         registry().add("int_ge", &p_int_ge);
@@ -1025,8 +1214,11 @@ namespace Gecode { namespace FlatZinc {
         registry().add("bool_right_imp", &p_bool_r_imp);
         registry().add("bool_not", &p_bool_not);
         registry().add("array_int_element", &p_array_int_element);
+        registry().add("array_var_int_element", &p_array_int_element);
         registry().add("array_bool_element", &p_array_bool_element);
+        registry().add("array_var_bool_element", &p_array_bool_element);
         registry().add("bool2int", &p_bool2int);
+        registry().add("int_in", &p_int_in);
       
         registry().add("array_int_lt", &p_array_int_lt);
         registry().add("array_int_lq", &p_array_int_lq);
@@ -1041,9 +1233,13 @@ namespace Gecode { namespace FlatZinc {
         registry().add("inverse_offsets", &p_inverse_offsets);
         registry().add("increasing_int", &p_increasing_int);
         registry().add("increasing_bool", &p_increasing_bool);
+        registry().add("decreasing_int", &p_decreasing_int);
+        registry().add("decreasing_bool", &p_decreasing_bool);
         registry().add("table_int", &p_table_int);
         registry().add("table_bool", &p_table_bool);
         registry().add("cumulatives", &p_cumulatives);
+        registry().add("among_seq_int", &p_among_seq_int);
+        registry().add("among_seq_bool", &p_among_seq_bool);
 
         registry().add("bool_lin_eq", &p_bool_lin_eq);
         registry().add("bool_lin_ne", &p_bool_lin_ne);
@@ -1058,6 +1254,13 @@ namespace Gecode { namespace FlatZinc {
         registry().add("bool_lin_lt_reif", &p_bool_lin_lt_reif);
         registry().add("bool_lin_ge_reif", &p_bool_lin_ge_reif);
         registry().add("bool_lin_gt_reif", &p_bool_lin_gt_reif);
+        
+        registry().add("schedule_unary", &p_schedule_unary);
+        registry().add("schedule_unary_optional", &p_schedule_unary_optional);
+
+        registry().add("circuit", &p_circuit);
+        registry().add("circuit_cost_array", &p_circuit_cost_array);
+        registry().add("circuit_cost", &p_circuit_cost);
       }
     };
     IntPoster __int_poster;
@@ -1130,21 +1333,18 @@ namespace Gecode { namespace FlatZinc {
     }
     void p_set_in(FlatZincSpace& s, const ConExpr& ce, AST::Node *) {
       if (!ce[1]->isSetVar()) {
-        AST::SetLit* sl = ce[1]->getSet();
-        IntSet d;
-        if (sl->interval) {
-          d = IntSet(sl->min, sl->max);
-        } else {
-          Region re(s);
-          int* is = re.alloc<int>(static_cast<unsigned long int>(sl->s.size()));
-          for (int i=sl->s.size(); i--; )
-            is[i] = sl->s[i];
-          d = IntSet(is, sl->s.size());
-        }
+        IntSet d = arg2intset(s,ce[1]);
         if (ce[0]->isBoolVar()) {
-          assert(sl->interval);
-          rel(s, getBoolVar(s, ce[0]), IRT_GQ, sl->min);
-          rel(s, getBoolVar(s, ce[0]), IRT_LQ, sl->max);
+          IntSetRanges dr(d);
+          Iter::Ranges::Singleton sr(0,1);
+          Iter::Ranges::Inter<IntSetRanges,Iter::Ranges::Singleton> i(dr,sr);
+          IntSet d01(i);
+          if (d01.size() == 0) {
+            s.fail();
+          } else {
+            rel(s, getBoolVar(s, ce[0]), IRT_GQ, d01.min());
+            rel(s, getBoolVar(s, ce[0]), IRT_LQ, d01.max());
+          }
         } else {
           dom(s, getIntVar(s, ce[0]), d);
         }
@@ -1176,21 +1376,21 @@ namespace Gecode { namespace FlatZinc {
     }
     void p_set_in_reif(FlatZincSpace& s, const ConExpr& ce, AST::Node *) {
       if (!ce[1]->isSetVar()) {
-        AST::SetLit* sl = ce[1]->getSet();
-        IntSet d;
-        if (sl->interval) {
-          d = IntSet(sl->min, sl->max);
-        } else {
-          Region re(s);
-          int* is = re.alloc<int>(static_cast<unsigned long int>(sl->s.size()));
-          for (int i=sl->s.size(); i--; )
-            is[i] = sl->s[i];
-          d = IntSet(is, sl->s.size());
-        }
+        IntSet d = arg2intset(s,ce[1]);
         if (ce[0]->isBoolVar()) {
-          assert(sl->interval);
-          rel(s, getBoolVar(s, ce[0]), IRT_GQ, sl->min, getBoolVar(s, ce[2]));
-          rel(s, getBoolVar(s, ce[0]), IRT_LQ, sl->max, getBoolVar(s, ce[2]));
+          IntSetRanges dr(d);
+          Iter::Ranges::Singleton sr(0,1);
+          Iter::Ranges::Inter<IntSetRanges,Iter::Ranges::Singleton> i(dr,sr);
+          IntSet d01(i);
+          if (d01.size() == 0) {
+            post(s, getBoolVar(s, ce[2]) == 0);
+          } else if (d01.max() == 0) {
+            post(s, tt(eqv(getBoolVar(s, ce[2]), !getBoolVar(s, ce[0]))));
+          } else if (d01.min() == 1) {
+            post(s, getBoolVar(s, ce[2]) == getBoolVar(s, ce[0]));
+          } else {
+            post(s, getBoolVar(s, ce[2]) == 1);
+          }
         } else {
           dom(s, getIntVar(s, ce[0]), d, getBoolVar(s, ce[2]));
         }
@@ -1221,7 +1421,7 @@ namespace Gecode { namespace FlatZinc {
       IntVar selector = getIntVar(s, ce[0]);
       post(s, selector > 0);
       if (isConstant) {
-        IntSetArgs sv = arg2intsetargs(ce[1],1);
+        IntSetArgs sv = arg2intsetargs(s,ce[1],1);
         element(s, sv, selector, getSetVar(s, ce[2]));
       } else {
         SetVarArgs sv = arg2setvarargs(s, ce[1], 1);
@@ -1244,7 +1444,7 @@ namespace Gecode { namespace FlatZinc {
       SetVar selector = getSetVar(s, ce[0]);
       dom(s, selector, SRT_DISJ, 0);
       if (isConstant) {
-        IntSetArgs sv = arg2intsetargs(ce[1], 1);
+        IntSetArgs sv = arg2intsetargs(s,ce[1], 1);
         element(s, op, sv, selector, getSetVar(s, ce[2]), universe);
       } else {
         SetVarArgs sv = arg2setvarargs(s, ce[1], 1);
@@ -1265,17 +1465,7 @@ namespace Gecode { namespace FlatZinc {
     void p_array_set_element_intersect_in(FlatZincSpace& s,
                                               const ConExpr& ce,
                                               AST::Node* ann) {
-      AST::SetLit* sl = ce[3]->getSet();
-      IntSet d;
-      if (sl->interval) {
-        d = IntSet(sl->min, sl->max);
-      } else {
-        Region re(s);
-        int* is = re.alloc<int>(static_cast<unsigned long int>(sl->s.size()));
-        for (int i=sl->s.size(); i--; )
-          is[i] = sl->s[i];
-        d = IntSet(is, sl->s.size());
-      }
+      IntSet d = arg2intset(s, ce[3]);
       p_array_set_element_op(s, ce, ann, SOT_INTER, d);
     }
 
@@ -1307,6 +1497,7 @@ namespace Gecode { namespace FlatZinc {
         registry().add("set_ne", &p_set_ne);
         registry().add("set_union", &p_set_union);
         registry().add("array_set_element", &p_array_set_element);
+        registry().add("array_var_set_element", &p_array_set_element);
         registry().add("set_intersect", &p_set_intersect);
         registry().add("set_diff", &p_set_diff);
         registry().add("set_symdiff", &p_set_symdiff);
