@@ -7,8 +7,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2009-09-29 12:55:58 +0200 (Tue, 29 Sep 2009) $ by $Author: tack $
- *     $Revision: 9768 $
+ *     $Date: 2010-04-06 14:58:53 +0200 (Tue, 06 Apr 2010) $ by $Author: tack $
+ *     $Revision: 10649 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -82,16 +82,6 @@ namespace Gecode { namespace Gist {
                                  const Options& opt0)
   : opt(opt0), aboutGist(this) {
     c = new Gist(root,bab,this,opt);
-    {
-      unsigned int i = 0;
-      while (opt.inspect.solution(i)) {
-        c->addSolutionInspector(opt.inspect.solution(i++));
-      }
-      i = 0;
-      while (opt.inspect.click(i)) {
-        c->addDoubleClickInspector(opt.inspect.click(i++));
-      }
-    }
     setCentralWidget(c);
     setWindowTitle(tr("Gist"));
 
@@ -118,10 +108,30 @@ namespace Gecode { namespace Gist {
     connect(prefAction, SIGNAL(triggered()), this, SLOT(preferences()));
 
     QMenu* nodeMenu = menuBar->addMenu(tr("&Node"));
-    nodeMenu->addAction(c->inspect);
+    
+    inspectNodeMenu = new QMenu("Inspect");
+    inspectNodeMenu->addAction(c->inspect);
+    connect(inspectNodeMenu, SIGNAL(aboutToShow()),
+            this, SLOT(populateInspectors()));
+
+    inspectNodeBeforeFPMenu = new QMenu("Inspect before fixpoint");
+    inspectNodeBeforeFPMenu->addAction(c->inspectBeforeFP);
+    connect(inspectNodeBeforeFPMenu, SIGNAL(aboutToShow()),
+            this, SLOT(populateInspectors()));
+    populateInspectors();
+    
+    nodeMenu->addMenu(inspectNodeMenu);
+    nodeMenu->addMenu(inspectNodeBeforeFPMenu);
+    nodeMenu->addAction(c->compareNode);
+    nodeMenu->addAction(c->compareNodeBeforeFP);
     nodeMenu->addAction(c->setPath);
     nodeMenu->addAction(c->inspectPath);
     nodeMenu->addAction(c->showNodeStats);
+    bookmarksMenu = new QMenu("Bookmarks");
+    bookmarksMenu->addAction(c->bookmarkNode);
+    connect(bookmarksMenu, SIGNAL(aboutToShow()),
+            this, SLOT(populateBookmarks()));
+    nodeMenu->addMenu(bookmarksMenu);
     nodeMenu->addSeparator();
     nodeMenu->addAction(c->navUp);
     nodeMenu->addAction(c->navDown);
@@ -134,6 +144,8 @@ namespace Gecode { namespace Gist {
     nodeMenu->addAction(c->toggleHidden);
     nodeMenu->addAction(c->hideFailed);
     nodeMenu->addAction(c->unhideAll);
+    nodeMenu->addAction(c->toggleStop);
+    nodeMenu->addAction(c->unstopAll);
     nodeMenu->addSeparator();
     nodeMenu->addAction(c->zoomToFit);
     nodeMenu->addAction(c->center);
@@ -152,12 +164,20 @@ namespace Gecode { namespace Gist {
     QMenu* toolsMenu = menuBar->addMenu(tr("&Tools"));
     doubleClickInspectorsMenu = new QMenu("Double click Inspectors");
     connect(doubleClickInspectorsMenu, SIGNAL(aboutToShow()),
-            this, SLOT(populateInspectors()));
+            this, SLOT(populateInspectorSelection()));
     toolsMenu->addMenu(doubleClickInspectorsMenu);
     solutionInspectorsMenu = new QMenu("Solution inspectors");
     connect(solutionInspectorsMenu, SIGNAL(aboutToShow()),
-            this, SLOT(populateInspectors()));
+            this, SLOT(populateInspectorSelection()));
     toolsMenu->addMenu(solutionInspectorsMenu);
+    moveInspectorsMenu = new QMenu("Move inspectors");
+    connect(moveInspectorsMenu, SIGNAL(aboutToShow()),
+            this, SLOT(populateInspectorSelection()));
+    toolsMenu->addMenu(moveInspectorsMenu);
+    comparatorsMenu = new QMenu("Comparators");
+    connect(comparatorsMenu, SIGNAL(aboutToShow()),
+            this, SLOT(populateInspectorSelection()));
+    toolsMenu->addMenu(comparatorsMenu);
 
     QMenu* helpMenu = menuBar->addMenu(tr("&Help"));
     QAction* aboutAction = helpMenu->addAction(tr("About"));
@@ -199,7 +219,7 @@ namespace Gecode { namespace Gist {
     connect(c,SIGNAL(statusChanged(const Statistics&,bool)),
             this,SLOT(statusChanged(const Statistics&,bool)));
 
-    connect(c,SIGNAL(finished(void)),this,SLOT(close(void)));
+    connect(c,SIGNAL(searchFinished(void)),this,SLOT(close(void)));
 
     preferences(true);
     show();
@@ -257,12 +277,36 @@ namespace Gecode { namespace Gist {
   }
 
   void
-  GistMainWindow::populateInspectors(void) {
+  GistMainWindow::populateInspectorSelection(void) {
     doubleClickInspectorsMenu->clear();
     doubleClickInspectorsMenu->addActions(
       c->doubleClickInspectorGroup->actions());
     solutionInspectorsMenu->clear();
     solutionInspectorsMenu->addActions(c->solutionInspectorGroup->actions());
+    moveInspectorsMenu->clear();
+    moveInspectorsMenu->addActions(c->moveInspectorGroup->actions());
+    comparatorsMenu->clear();
+    comparatorsMenu->addActions(c->comparatorGroup->actions());
+  }
+
+  void
+  GistMainWindow::populateBookmarks(void) {
+    bookmarksMenu->clear();
+    bookmarksMenu->addAction(c->bookmarkNode);
+    bookmarksMenu->addSeparator();
+    bookmarksMenu->addActions(c->bookmarksGroup->actions());
+  }
+
+  void
+  GistMainWindow::populateInspectors(void) {
+    inspectNodeMenu->clear();
+    inspectNodeMenu->addAction(c->inspect);
+    inspectNodeMenu->addSeparator();
+    inspectNodeMenu->addActions(c->inspectGroup->actions());
+    inspectNodeBeforeFPMenu->clear();
+    inspectNodeBeforeFPMenu->addAction(c->inspectBeforeFP);
+    inspectNodeBeforeFPMenu->addSeparator();
+    inspectNodeBeforeFPMenu->addActions(c->inspectBeforeFPGroup->actions());
   }
 
 }}
