@@ -7,8 +7,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2009-05-14 19:49:13 +0200 (Thu, 14 May 2009) $ by $Author: tack $
- *     $Revision: 9119 $
+ *     $Date: 2010-04-07 14:24:53 +0200 (Wed, 07 Apr 2010) $ by $Author: tack $
+ *     $Revision: 10668 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -47,25 +47,32 @@ namespace Gecode { namespace Gist {
              const Options& opt) : QWidget(parent) {
     QGridLayout* layout = new QGridLayout(this);
 
-    QScrollArea* scrollArea = new QScrollArea(this);
+    QAbstractScrollArea* scrollArea = new QAbstractScrollArea(this);
 
     scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
     scrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
-    scrollArea->setAlignment(Qt::AlignHCenter);
     scrollArea->setAutoFillBackground(true);
     QPalette myPalette(scrollArea->palette());
     myPalette.setColor(QPalette::Window, Qt::white);
     scrollArea->setPalette(myPalette);
-    canvas = new TreeCanvas(root, bab, this,opt);
+    canvas = new TreeCanvas(root, bab, scrollArea->viewport(),opt);
     canvas->setPalette(myPalette);
     canvas->setObjectName("canvas");
 
-    scrollArea->setWidget(canvas);
+    connect(scrollArea->horizontalScrollBar(), SIGNAL(valueChanged(int)),
+            canvas, SLOT(scroll(void)));
+    connect(scrollArea->verticalScrollBar(), SIGNAL(valueChanged(int)),
+            canvas, SLOT(scroll(void)));
+
+    QVBoxLayout* sa_layout = new QVBoxLayout();
+    sa_layout->setContentsMargins(0,0,0,0);
+    sa_layout->addWidget(canvas);
+    scrollArea->viewport()->setLayout(sa_layout);
 
     connect(canvas, SIGNAL(solution(const Space*)),
             this, SIGNAL(solution(const Space*)));
 
-    connect(canvas, SIGNAL(finished(void)), this, SIGNAL(finished(void)));
+    connect(canvas, SIGNAL(searchFinished(void)), this, SIGNAL(searchFinished(void)));
 
     QPixmap myPic;
     myPic.loadFromData(zoomToFitIcon, sizeof(zoomToFitIcon));
@@ -74,13 +81,6 @@ namespace Gecode { namespace Gist {
     autoZoomButton->setCheckable(true);
     autoZoomButton->setIcon(myPic);
 
-    QSlider* scaleBar = new QSlider(Qt::Vertical, this);
-    canvas->scaleBar = scaleBar;
-    scaleBar->setObjectName("scaleBar");
-    scaleBar->setMinimum(LayoutConfig::minScale);
-    scaleBar->setMaximum(LayoutConfig::maxScale);
-    scaleBar->setValue(LayoutConfig::defScale);
-
     nodeStatInspector = new NodeStatInspector(this);
     connect(canvas, SIGNAL(statusChanged(VisualNode*,const Statistics&, bool)),
             nodeStatInspector, SLOT(node(VisualNode*,const Statistics&, bool)));
@@ -90,6 +90,11 @@ namespace Gecode { namespace Gist {
     connect(inspect, SIGNAL(triggered()), canvas,
                        SLOT(inspectCurrentNode()));
 
+    inspectBeforeFP = new QAction("Inspect before fixpoint", this);
+    inspectBeforeFP->setShortcut(QKeySequence("Ctrl+Return"));
+    connect(inspectBeforeFP, SIGNAL(triggered()), canvas,
+            SLOT(inspectBeforeFP(void)));
+
     stop = new QAction("Stop search", this);
     stop->setShortcut(QKeySequence("Esc"));
     connect(stop, SIGNAL(triggered()), canvas,
@@ -155,6 +160,14 @@ namespace Gecode { namespace Gist {
     unhideAll->setShortcut(QKeySequence("U"));
     connect(unhideAll, SIGNAL(triggered()), canvas, SLOT(unhideAll()));
 
+    toggleStop = new QAction("Stop/unstop", this);
+    toggleStop->setShortcut(QKeySequence("X"));
+    connect(toggleStop, SIGNAL(triggered()), canvas, SLOT(toggleStop()));
+
+    unstopAll = new QAction("Do not stop in subtree", this);
+    unstopAll->setShortcut(QKeySequence("Shift+X"));
+    connect(unstopAll, SIGNAL(triggered()), canvas, SLOT(unstopAll()));
+
     zoomToFit = new QAction("Zoom to fit", this);
     zoomToFit->setShortcut(QKeySequence("Z"));
     connect(zoomToFit, SIGNAL(triggered()), canvas, SLOT(zoomToFit()));
@@ -178,6 +191,40 @@ namespace Gecode { namespace Gist {
     connect(print, SIGNAL(triggered()), canvas,
             SLOT(print()));
 
+    bookmarkNode = new QAction("Add/remove bookmark", this);
+    bookmarkNode->setShortcut(QKeySequence("Shift+B"));
+    connect(bookmarkNode, SIGNAL(triggered()), canvas, SLOT(bookmarkNode()));
+
+    compareNode = new QAction("Compare", this);
+    compareNode->setShortcut(QKeySequence("V"));
+    connect(compareNode, SIGNAL(triggered()),
+            canvas, SLOT(startCompareNodes()));
+
+    compareNodeBeforeFP = new QAction("Compare before fixpoint", this);
+    compareNodeBeforeFP->setShortcut(QKeySequence("Ctrl+V"));
+    connect(compareNodeBeforeFP, SIGNAL(triggered()),
+            canvas, SLOT(startCompareNodesBeforeFP()));
+
+    connect(canvas, SIGNAL(addedBookmark(const QString&)),
+            this, SLOT(addBookmark(const QString&)));
+    connect(canvas, SIGNAL(removedBookmark(int)),
+            this, SLOT(removeBookmark(int)));
+
+    nullBookmark = new QAction("<none>",this);
+    nullBookmark->setCheckable(true);
+    nullBookmark->setChecked(false);
+    nullBookmark->setEnabled(false);
+    bookmarksGroup = new QActionGroup(this);
+    bookmarksGroup->setExclusive(false);
+    bookmarksGroup->addAction(nullBookmark);
+    connect(bookmarksGroup, SIGNAL(triggered(QAction*)),
+            this, SLOT(selectBookmark(QAction*)));
+
+    bookmarksMenu = new QMenu("Bookmarks");
+    connect(bookmarksMenu, SIGNAL(aboutToShow()),
+            this, SLOT(populateBookmarksMenu()));
+
+
     setPath = new QAction("Set path", this);
     setPath->setShortcut(QKeySequence("Shift+P"));
     connect(setPath, SIGNAL(triggered()), canvas, SLOT(setPath()));
@@ -192,6 +239,9 @@ namespace Gecode { namespace Gist {
             this, SLOT(showStats()));
 
     addAction(inspect);
+    addAction(inspectBeforeFP);
+    addAction(compareNode);
+    addAction(compareNodeBeforeFP);
     addAction(stop);
     addAction(reset);
     addAction(navUp);
@@ -207,6 +257,8 @@ namespace Gecode { namespace Gist {
     addAction(toggleHidden);
     addAction(hideFailed);
     addAction(unhideAll);
+    addAction(toggleStop);
+    addAction(unstopAll);
     addAction(zoomToFit);
     addAction(center);
     addAction(exportPDF);
@@ -237,14 +289,59 @@ namespace Gecode { namespace Gist {
     connect(doubleClickInspectorGroup, SIGNAL(triggered(QAction*)),
             this, SLOT(selectDoubleClickInspector(QAction*)));
 
+    nullMoveInspector = new QAction("<none>",this);
+    nullMoveInspector->setCheckable(true);
+    nullMoveInspector->setChecked(false);
+    nullMoveInspector->setEnabled(false);
+    moveInspectorGroup = new QActionGroup(this);
+    moveInspectorGroup->setExclusive(false);
+    moveInspectorGroup->addAction(nullMoveInspector);
+    connect(moveInspectorGroup, SIGNAL(triggered(QAction*)),
+            this, SLOT(selectMoveInspector(QAction*)));
+
+    nullComparator = new QAction("<none>",this);
+    nullComparator->setCheckable(true);
+    nullComparator->setChecked(false);
+    nullComparator->setEnabled(false);
+    comparatorGroup = new QActionGroup(this);
+    comparatorGroup->setExclusive(false);
+    comparatorGroup->addAction(nullComparator);
+    connect(comparatorGroup, SIGNAL(triggered(QAction*)),
+            this, SLOT(selectComparator(QAction*)));
+
     solutionInspectorMenu = new QMenu("Solution inspectors");
     solutionInspectorMenu->addActions(solutionInspectorGroup->actions());
     doubleClickInspectorMenu = new QMenu("Double click inspectors");
     doubleClickInspectorMenu->addActions(
       doubleClickInspectorGroup->actions());
+    moveInspectorMenu = new QMenu("Move inspectors");
+    moveInspectorMenu->addActions(moveInspectorGroup->actions());
+    comparatorMenu = new QMenu("Comparators");
+    comparatorMenu->addActions(comparatorGroup->actions());
+
+    inspectGroup = new QActionGroup(this);
+    connect(inspectGroup, SIGNAL(triggered(QAction*)),
+            this, SLOT(inspectWithAction(QAction*)));
+    inspectBeforeFPGroup = new QActionGroup(this);
+    connect(inspectBeforeFPGroup, SIGNAL(triggered(QAction*)),
+            this, SLOT(inspectBeforeFPWithAction(QAction*)));
+
+    inspectNodeMenu = new QMenu("Inspect");
+    inspectNodeMenu->addAction(inspect);
+    connect(inspectNodeMenu, SIGNAL(aboutToShow()),
+            this, SLOT(populateInspectors()));
+
+    inspectNodeBeforeFPMenu = new QMenu("Inspect before fixpoint");
+    inspectNodeBeforeFPMenu->addAction(inspectBeforeFP);
+    connect(inspectNodeBeforeFPMenu, SIGNAL(aboutToShow()),
+            this, SLOT(populateInspectors()));
+    populateInspectors();
 
     contextMenu = new QMenu(this);
-    contextMenu->addAction(inspect);
+    contextMenu->addMenu(inspectNodeMenu);
+    contextMenu->addMenu(inspectNodeBeforeFPMenu);
+    contextMenu->addAction(compareNode);
+    contextMenu->addAction(compareNodeBeforeFP);
     contextMenu->addAction(showNodeStats);
     contextMenu->addAction(center);
 
@@ -259,8 +356,12 @@ namespace Gecode { namespace Gist {
     contextMenu->addAction(hideFailed);
     contextMenu->addAction(unhideAll);
 
+    contextMenu->addAction(toggleStop);
+    contextMenu->addAction(unstopAll);
+
     contextMenu->addSeparator();
 
+    contextMenu->addMenu(bookmarksMenu);
     contextMenu->addAction(setPath);
     contextMenu->addAction(inspectPath);
 
@@ -268,10 +369,7 @@ namespace Gecode { namespace Gist {
 
     contextMenu->addMenu(doubleClickInspectorMenu);
     contextMenu->addMenu(solutionInspectorMenu);
-
-    connect(scaleBar, SIGNAL(valueChanged(int)), canvas, SLOT(scaleTree(int)));
-
-    connect(canvas, SIGNAL(scaleChanged(int)), scaleBar, SLOT(setValue(int)));
+    contextMenu->addMenu(moveInspectorMenu);
 
     connect(autoZoomButton, SIGNAL(toggled(bool)), canvas,
             SLOT(setAutoZoom(bool)));
@@ -279,11 +377,28 @@ namespace Gecode { namespace Gist {
     connect(canvas, SIGNAL(autoZoomChanged(bool)),
             autoZoomButton, SLOT(setChecked(bool)));
 
-    connect(&canvas->searcher, SIGNAL(scaleChanged(int)),
-            scaleBar, SLOT(setValue(int)));
+    {
+      unsigned int i = 0;
+      while (opt.inspect.solution(i)) {
+        addSolutionInspector(opt.inspect.solution(i++));
+      }
+      i = 0;
+      while (opt.inspect.click(i)) {
+        addDoubleClickInspector(opt.inspect.click(i++));
+      }
+      i = 0;
+      while (opt.inspect.move(i)) {
+        addMoveInspector(opt.inspect.move(i++));
+      }
+      i = 0;
+      while (opt.inspect.compare(i)) {
+        addComparator(opt.inspect.compare(i++));
+      }
+    }
+
 
     layout->addWidget(scrollArea, 0,0,-1,1);
-    layout->addWidget(scaleBar, 1,1, Qt::AlignHCenter);
+    layout->addWidget(canvas->scaleBar, 1,1, Qt::AlignHCenter);
     layout->addWidget(autoZoomButton, 0,1, Qt::AlignHCenter);
 
     setLayout(layout);
@@ -302,44 +417,125 @@ namespace Gecode { namespace Gist {
   }
 
   void
-  Gist::addInspector(Inspector* i0, bool solutionInspector) {
+  Gist::addInspector(Inspector* i0, QAction*& nas, QAction*& nad,
+                     QAction*&nam) {
     if (doubleClickInspectorGroup->
       actions().indexOf(nullDoubleClickInspector) != -1) {
       doubleClickInspectorGroup->removeAction(nullDoubleClickInspector);
       solutionInspectorGroup->removeAction(nullSolutionInspector);
+      moveInspectorGroup->removeAction(nullMoveInspector);
     }
     canvas->addSolutionInspector(i0);
     canvas->addDoubleClickInspector(i0);
-    QAction* nas = new QAction(i0->name().c_str(), this);
+    canvas->addMoveInspector(i0);
+
+    nas = new QAction(i0->name().c_str(), this);
     nas->setCheckable(true);
     solutionInspectorGroup->addAction(nas);
     solutionInspectorMenu->clear();
     solutionInspectorMenu->addActions(solutionInspectorGroup->actions());
 
-    QAction* nad = new QAction(i0->name().c_str(), this);
+    nad = new QAction(i0->name().c_str(), this);
     nad->setCheckable(true);
     doubleClickInspectorGroup->addAction(nad);
     doubleClickInspectorMenu->clear();
     doubleClickInspectorMenu->addActions(
       doubleClickInspectorGroup->actions());
 
-    if (solutionInspector) {
-      nas->setChecked(true);
-      selectSolutionInspector(nas);
-    } else {
-      nad->setChecked(true);
-      selectDoubleClickInspector(nad);
+    nam = new QAction(i0->name().c_str(), this);
+    nam->setCheckable(true);
+    moveInspectorGroup->addAction(nam);
+    moveInspectorMenu->clear();
+    moveInspectorMenu->addActions(
+      moveInspectorGroup->actions());
+    
+    QAction* ia = new QAction(i0->name().c_str(), this);
+    inspectGroup->addAction(ia);
+    QAction* ibfpa = new QAction(i0->name().c_str(), this);
+    inspectBeforeFPGroup->addAction(ibfpa);
+
+    if (inspectGroup->actions().size() < 10) {
+      ia->setShortcut(QKeySequence(
+        QString("").setNum(inspectGroup->actions().size())));
+      ibfpa->setShortcut(QKeySequence(QString("Ctrl+")+
+        QString("").setNum(inspectBeforeFPGroup->actions().size())));
     }
   }
 
   void
-  Gist::addSolutionInspector(Inspector* i) {
-    addInspector(i, true);
+  Gist::addSolutionInspector(Inspector* ins) {
+    QAction* nas;
+    QAction* nad;
+    QAction* nam;
+    if (doubleClickInspectorGroup->
+      actions().indexOf(nullDoubleClickInspector) == -1) {
+      QList<QAction*> is = solutionInspectorGroup->actions();
+      for (int i=0; i<is.size(); i++) {
+        canvas->activateSolutionInspector(i,false);
+        is[i]->setChecked(false);
+      }
+    }
+    addInspector(ins, nas,nad,nam);
+    nas->setChecked(true);
+    selectSolutionInspector(nas);
   }
 
   void
-  Gist::addDoubleClickInspector(Inspector* i) {
-    addInspector(i, false);
+  Gist::addDoubleClickInspector(Inspector* ins) {
+    QAction* nas;
+    QAction* nad;
+    QAction* nam;
+    if (doubleClickInspectorGroup->
+      actions().indexOf(nullDoubleClickInspector) == -1) {
+      QList<QAction*> is = doubleClickInspectorGroup->actions();
+      for (int i=0; i<is.size(); i++) {
+        canvas->activateDoubleClickInspector(i,false);
+        is[i]->setChecked(false);
+      }
+    }
+    addInspector(ins, nas,nad,nam);
+    nad->setChecked(true);
+    selectDoubleClickInspector(nad);
+  }
+
+  void
+  Gist::addMoveInspector(Inspector* ins) {
+    QAction* nas;
+    QAction* nad;
+    QAction* nam;
+    if (doubleClickInspectorGroup->
+      actions().indexOf(nullDoubleClickInspector) == -1) {
+      QList<QAction*> is = moveInspectorGroup->actions();
+      for (int i=0; i<is.size(); i++) {
+        canvas->activateMoveInspector(i,false);
+        is[i]->setChecked(false);
+      }
+    }
+    addInspector(ins, nas,nad,nam);
+    nam->setChecked(true);
+    selectMoveInspector(nam);
+  }
+
+  void
+  Gist::addComparator(Comparator* c) {
+    if (comparatorGroup->actions().indexOf(nullComparator) == -1) {
+      QList<QAction*> is = comparatorGroup->actions();
+      for (int i=0; i<is.size(); i++) {
+        canvas->activateComparator(i,false);
+        is[i]->setChecked(false);
+      }
+    } else {
+      comparatorGroup->removeAction(nullComparator);
+    }
+    canvas->addComparator(c);
+
+    QAction* ncs = new QAction(c->name().c_str(), this);
+    ncs->setCheckable(true);
+    comparatorGroup->addAction(ncs);
+    comparatorMenu->clear();
+    comparatorMenu->addActions(comparatorGroup->actions());
+    ncs->setChecked(true);
+    selectComparator(ncs);
   }
 
   Gist::~Gist(void) { delete canvas; }
@@ -354,6 +550,11 @@ namespace Gecode { namespace Gist {
                                 bool finished) {
     if (!finished) {
       inspect->setEnabled(false);
+      inspectGroup->setEnabled(false);
+      inspectBeforeFP->setEnabled(false);
+      inspectBeforeFPGroup->setEnabled(false);
+      compareNode->setEnabled(false);
+      compareNodeBeforeFP->setEnabled(false);
       stop->setEnabled(true);
       reset->setEnabled(false);
       navUp->setEnabled(false);
@@ -369,6 +570,10 @@ namespace Gecode { namespace Gist {
       toggleHidden->setEnabled(false);
       hideFailed->setEnabled(false);
       unhideAll->setEnabled(false);
+      
+      toggleStop->setEnabled(false);
+      unstopAll->setEnabled(false);
+      
       zoomToFit->setEnabled(false);
       center->setEnabled(false);
       exportPDF->setEnabled(false);
@@ -377,8 +582,9 @@ namespace Gecode { namespace Gist {
 
       setPath->setEnabled(false);
       inspectPath->setEnabled(false);
+      bookmarkNode->setEnabled(false);
+      bookmarksGroup->setEnabled(false);
     } else {
-      inspect->setEnabled(true);
       stop->setEnabled(false);
       reset->setEnabled(true);
 
@@ -394,15 +600,37 @@ namespace Gecode { namespace Gist {
         toggleHidden->setEnabled(true);
         hideFailed->setEnabled(true);
         unhideAll->setEnabled(true);
+        unstopAll->setEnabled(true);
       } else {
         navDown->setEnabled(false);
         toggleHidden->setEnabled(false);
         hideFailed->setEnabled(false);
         unhideAll->setEnabled(false);
+        unstopAll->setEnabled(false);
+      }
+      
+      toggleStop->setEnabled(n->getStatus() == STOP ||
+        n->getStatus() == UNSTOP);
+
+      inspect->setEnabled(true);
+      if (n->getStatus() == UNDETERMINED) {
+        inspectGroup->setEnabled(false);
+        inspectBeforeFP->setEnabled(false);
+        inspectBeforeFPGroup->setEnabled(false);
+        compareNode->setEnabled(false);
+        compareNodeBeforeFP->setEnabled(false);
+      } else {
+        inspectGroup->setEnabled(true);        
+        inspectBeforeFP->setEnabled(true);
+        inspectBeforeFPGroup->setEnabled(true);
+        compareNode->setEnabled(true);
+        compareNodeBeforeFP->setEnabled(true);
       }
 
       VisualNode* p = n->getParent();
       if (p == NULL) {
+        inspectBeforeFP->setEnabled(false);
+        inspectBeforeFPGroup->setEnabled(false);
         navRoot->setEnabled(false);
         navUp->setEnabled(false);
         navRight->setEnabled(false);
@@ -436,10 +664,24 @@ namespace Gecode { namespace Gist {
 
       setPath->setEnabled(true);
       inspectPath->setEnabled(true);
+
+      bookmarkNode->setEnabled(true);
+      bookmarksGroup->setEnabled(true);
     }
     emit statusChanged(stats,finished);
   }
 
+  void
+  Gist::inspectWithAction(QAction* a) {
+    canvas->inspectCurrentNode(true,inspectGroup->actions().indexOf(a));
+  }
+
+  void
+  Gist::inspectBeforeFPWithAction(QAction* a) {
+    canvas->inspectCurrentNode(false,
+      inspectBeforeFPGroup->actions().indexOf(a));
+  }
+
   bool
   Gist::finish(void) {
     return canvas->finish();
@@ -457,7 +699,64 @@ namespace Gecode { namespace Gist {
       solutionInspectorGroup->actions().indexOf(a),
       a->isChecked());
   }
+  void
+  Gist::selectMoveInspector(QAction* a) {
+    canvas->activateMoveInspector(
+      moveInspectorGroup->actions().indexOf(a),
+      a->isChecked());
+  }
+  void
+  Gist::selectComparator(QAction* a) {
+    canvas->activateComparator(comparatorGroup->actions().indexOf(a),
+      a->isChecked());
+  }
+  void
+  Gist::selectBookmark(QAction* a) {
+    int idx = bookmarksGroup->actions().indexOf(a);
+    canvas->setCurrentNode(canvas->bookmarks[idx]);
+    canvas->centerCurrentNode();
+  }
 
+  void
+  Gist::addBookmark(const QString& id) {
+    if (bookmarksGroup->actions().indexOf(nullBookmark) != -1) {
+      bookmarksGroup->removeAction(nullBookmark);
+    }
+
+    QAction* nb = new QAction(id, this);
+    nb->setCheckable(true);
+    bookmarksGroup->addAction(nb);
+  }
+
+  void
+  Gist::removeBookmark(int idx) {
+    QAction* a = bookmarksGroup->actions()[idx];
+    bookmarksGroup->removeAction(a);
+    if (bookmarksGroup->actions().size() == 0) {
+      bookmarksGroup->addAction(nullBookmark);
+    }
+  }
+  
+  void
+  Gist::populateBookmarksMenu(void) {
+    bookmarksMenu->clear();
+    bookmarksMenu->addAction(bookmarkNode);
+    bookmarksMenu->addSeparator();
+    bookmarksMenu->addActions(bookmarksGroup->actions());
+  }
+
+  void
+  Gist::populateInspectors(void) {
+    inspectNodeMenu->clear();
+    inspectNodeMenu->addAction(inspect);
+    inspectNodeMenu->addSeparator();
+    inspectNodeMenu->addActions(inspectGroup->actions());
+    inspectNodeBeforeFPMenu->clear();
+    inspectNodeBeforeFPMenu->addAction(inspectBeforeFP);
+    inspectNodeBeforeFPMenu->addSeparator();
+    inspectNodeBeforeFPMenu->addActions(inspectBeforeFPGroup->actions());
+  }
+  
   void
   Gist::setAutoHideFailed(bool b) { canvas->setAutoHideFailed(b); }
   void
