@@ -7,8 +7,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2009-05-15 00:32:07 +0200 (Fri, 15 May 2009) $ by $Author: tack $
- *     $Revision: 9124 $
+ *     $Date: 2010-04-08 11:25:15 +0200 (Thu, 08 Apr 2010) $ by $Author: tack $
+ *     $Revision: 10682 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -58,14 +58,11 @@ namespace Gecode { namespace Gist {
     , mutex(QMutex::Recursive)
     , layoutMutex(QMutex::Recursive)
     , finishedFlag(false)
+    , compareNodes(false), compareNodesBeforeFP(false)
     , autoHideFailed(true), autoZoom(false)
-    , refresh(500), smoothScrollAndZoom(false), nextPit(0)
-    , targetZoom(LayoutConfig::defScale)
-    , metaZoomCurrent(static_cast<double>(LayoutConfig::defScale))
-    , zoomTimerId(0)
-    , targetScrollX(0), targetScrollY(0)
-    , metaScrollXCurrent(0.0), metaScrollYCurrent(0.0)
-    , scrollTimerId(0)
+    , refresh(500), smoothScrollAndZoom(false)
+    , zoomTimeLine(500)
+    , scrollTimeLine(1000), targetX(0), sourceX(0), targetY(0), sourceY(0)
     , targetW(0), targetH(0), targetScale(0)
     , layoutDoneTimerId(0) {
       QMutexLocker locker(&mutex);
@@ -97,7 +94,26 @@ namespace Gecode { namespace Gist {
               this, SLOT(inspectSolution(const Space*)),
               Qt::BlockingQueuedConnection);
 
-      connect(&searcher, SIGNAL(finished(void)), this, SIGNAL(finished(void)));
+      connect(&searcher, SIGNAL(searchFinished(void)), this, SIGNAL(searchFinished(void)));
+
+      connect(&scrollTimeLine, SIGNAL(frameChanged(int)),
+              this, SLOT(scroll(int)));
+      scrollTimeLine.setCurveShape(QTimeLine::EaseInOutCurve);
+
+      scaleBar = new QSlider(Qt::Vertical, this);
+      scaleBar->setObjectName("scaleBar");
+      scaleBar->setMinimum(LayoutConfig::minScale);
+      scaleBar->setMaximum(LayoutConfig::maxScale);
+      scaleBar->setValue(LayoutConfig::defScale);
+      connect(scaleBar, SIGNAL(valueChanged(int)),
+              this, SLOT(scaleTree(int)));
+      connect(this, SIGNAL(scaleChanged(int)), scaleBar, SLOT(setValue(int)));
+      connect(&searcher, SIGNAL(scaleChanged(int)),
+              scaleBar, SLOT(setValue(int)));
+
+      connect(&zoomTimeLine, SIGNAL(frameChanged(int)),
+              scaleBar, SLOT(setValue(int)));
+      zoomTimeLine.setCurveShape(QTimeLine::EaseInOutCurve);
 
       qRegisterMetaType<Statistics>("Statistics");
       update();
@@ -112,6 +128,7 @@ namespace Gecode { namespace Gist {
 
   void
   TreeCanvas::activateDoubleClickInspector(int i, bool active) {
+    assert(i < doubleClickInspectors.size());
     doubleClickInspectors[i].second = active;
   }
 
@@ -122,12 +139,48 @@ namespace Gecode { namespace Gist {
 
   void
   TreeCanvas::activateSolutionInspector(int i, bool active) {
+    assert(i < solutionInspectors.size());
     solutionInspectors[i].second = active;
   }
 
   void
-  TreeCanvas::scaleTree(int scale0) {
+  TreeCanvas::addMoveInspector(Inspector* i) {
+    moveInspectors.append(QPair<Inspector*,bool>(i,false));
+  }
+
+  void
+  TreeCanvas::activateMoveInspector(int i, bool active) {
+    assert(i < moveInspectors.size());
+    moveInspectors[i].second = active;
+  }
+
+  void
+  TreeCanvas::addComparator(Comparator* c) {
+    comparators.append(QPair<Comparator*,bool>(c,false));
+  }
+
+  void
+  TreeCanvas::activateComparator(int i, bool active) {
+    assert(i < comparators.size());
+    comparators[i].second = active;
+  }
+
+  void
+  TreeCanvas::scaleTree(int scale0, int zoomx, int zoomy) {
     QMutexLocker locker(&layoutMutex);
+
+    QSize viewport_size = size();
+    QAbstractScrollArea* sa =
+      static_cast<QAbstractScrollArea*>(parentWidget()->parentWidget());
+
+    if (zoomx==-1)
+      zoomx = viewport_size.width()/2;
+    if (zoomy==-1)
+      zoomy = viewport_size.height()/2;
+
+    int xoff = (sa->horizontalScrollBar()->value()+zoomx)/scale;
+    int yoff = (sa->verticalScrollBar()->value()+zoomy)/scale;
+
     BoundingBox bb;
     scale0 = std::min(std::max(scale0, LayoutConfig::minScale),
                       LayoutConfig::maxScale);
@@ -138,7 +191,20 @@ namespace Gecode { namespace Gist {
     int h =
       static_cast<int>(2*Layout::extent+
         root->getShape()->depth()*Layout::dist_y*scale);
-    resize(w,h);
+
+    sa->horizontalScrollBar()->setRange(0,w-viewport_size.width());
+    sa->verticalScrollBar()->setRange(0,h-viewport_size.height());
+    sa->horizontalScrollBar()->setPageStep(viewport_size.width());
+    sa->verticalScrollBar()->setPageStep(viewport_size.height());
+    sa->horizontalScrollBar()->setSingleStep(Layout::extent);
+    sa->verticalScrollBar()->setSingleStep(Layout::extent);
+
+    xoff *= scale;
+    yoff *= scale;
+
+    sa->horizontalScrollBar()->setValue(xoff-zoomx);
+    sa->verticalScrollBar()->setValue(yoff-zoomy);
+
     emit scaleChanged(scale0);
     QWidget::update();
   }
@@ -156,7 +222,16 @@ namespace Gecode { namespace Gist {
         static_cast<int>(2*Layout::extent+
           root->getShape()->depth()*Layout::dist_y*scale);
       xtrans = -bb.left+(Layout::extent / 2);
-      resize(w,h);
+      
+      QSize viewport_size = size();
+      QAbstractScrollArea* sa =
+        static_cast<QAbstractScrollArea*>(parentWidget()->parentWidget());
+      sa->horizontalScrollBar()->setRange(0,w-viewport_size.width());
+      sa->verticalScrollBar()->setRange(0,h-viewport_size.height());
+      sa->horizontalScrollBar()->setPageStep(viewport_size.width());
+      sa->verticalScrollBar()->setPageStep(viewport_size.height());
+      sa->horizontalScrollBar()->setSingleStep(Layout::extent);
+      sa->verticalScrollBar()->setSingleStep(Layout::extent);
     }
     if (autoZoom)
       zoomToFit();
@@ -164,6 +239,11 @@ namespace Gecode { namespace Gist {
     QWidget::update();
   }
 
+  void
+  TreeCanvas::scroll(void) {
+    QWidget::update();
+  }
+
   void
   TreeCanvas::layoutDone(int w, int h, int scale0) {
     targetW = w; targetH = h; targetScale = scale0;
@@ -247,11 +327,16 @@ namespace Gecode { namespace Gist {
     emit update(w,h,scale0);
   }
 
+  /// A stack item for depth first search
   class SearchItem {
   public:
+    /// The node
     VisualNode* n;
+    /// The currently explored child
     int i;
+    /// The number of children
     int noOfChildren;
+    /// Constructor
     SearchItem(VisualNode* n0, int noOfChildren0)
       : n(n0), i(-1), noOfChildren(noOfChildren0) {}
   };
@@ -267,7 +352,7 @@ namespace Gecode { namespace Gist {
       unsigned int kids = 
         node->getNumberOfChildNodes(*t->na, t->curBest, t->stats,
                                     t->c_d, t->a_d);
-      if (kids == 0) {
+      if (kids == 0 || node->getStatus() == STOP) {
         t->mutex.unlock();
         updateCanvas();
         emit statusChanged(true);
@@ -309,7 +394,10 @@ namespace Gecode { namespace Gist {
                   break;
               }
             } else {
-              stck.push(SearchItem(n,kids));
+              if ( n->getStatus() != STOP )
+                stck.push(SearchItem(n,kids));
+              else if (!a)
+                break;
               t->stats.maxDepth =
                 std::max(static_cast<long unsigned int>(t->stats.maxDepth), 
                          static_cast<long unsigned int>(depth+stck.size()));
@@ -321,15 +409,15 @@ namespace Gecode { namespace Gist {
       t->stopSearchFlag = false;
       t->mutex.unlock();
       if (sol != NULL) {
-        t->setCurrentNode(sol);
+        t->setCurrentNode(sol,false);
       } else {
-        t->setCurrentNode(node);
+        t->setCurrentNode(node,false);
       }
     }
     updateCanvas();
     emit statusChanged(true);
     if (t->finishedFlag)
-      emit finished();
+      emit searchFinished();
   }
 
   void
@@ -372,47 +460,39 @@ namespace Gecode { namespace Gist {
     emit statusChanged(currentNode, stats, true);
   }
 
+  void
+  TreeCanvas::toggleStop(void) {
+    QMutexLocker locker(&mutex);
+    currentNode->toggleStop();
+    update();
+    centerCurrentNode();
+    emit statusChanged(currentNode, stats, true);
+  }
+
+  void
+  TreeCanvas::unstopAll(void) {
+    QMutexLocker locker(&mutex);
+    QMutexLocker layoutLocker(&layoutMutex);
+    currentNode->unstopAll();
+    update();
+    centerCurrentNode();
+    emit statusChanged(currentNode, stats, true);    
+  }
+
   void
   TreeCanvas::timerEvent(QTimerEvent* e) {
-    if (e->timerId() == zoomTimerId) {
-      double offset = static_cast<double>(targetZoom - metaZoomCurrent) / 6.0;
-      metaZoomCurrent += offset;
-      scaleBar->setValue(static_cast<int>(metaZoomCurrent));
-      if (static_cast<int>(metaZoomCurrent+.5) == targetZoom) {
-        killTimer(zoomTimerId);
-        zoomTimerId = 0;
-      }
-    } else if (e->timerId() == scrollTimerId) {
-      QScrollArea* sa =
-        static_cast<QScrollArea*>(parentWidget()->parentWidget());
-
-      double xoffset =
-        static_cast<double>(targetScrollX - metaScrollXCurrent) / 6.0;
-      metaScrollXCurrent += xoffset;
-      sa->horizontalScrollBar()
-        ->setValue(static_cast<int>(metaScrollXCurrent));
-      double yoffset =
-        static_cast<double>(targetScrollY - metaScrollYCurrent) / 6.0;
-      metaScrollYCurrent += yoffset;
-      sa->verticalScrollBar()
-        ->setValue(static_cast<int>(metaScrollYCurrent));
-
-      if (static_cast<int>(metaScrollXCurrent+.5) == targetScrollX &&
-          static_cast<int>(metaScrollYCurrent+.5) == targetScrollY) {
-        killTimer(scrollTimerId);
-        scrollTimerId = 0;
-      }
-    } else if (e->timerId() == layoutDoneTimerId) {
+    if (e->timerId() == layoutDoneTimerId) {
       if (!smoothScrollAndZoom) {
         scaleTree(targetScale);
       } else {
-        metaZoomCurrent = static_cast<int>(scale*100);
-        targetZoom = targetScale;
+        zoomTimeLine.stop();
+        int zoomCurrent = static_cast<int>(scale*100);
+        int targetZoom = targetScale;
         targetZoom = std::min(std::max(targetZoom, LayoutConfig::minScale),
                               LayoutConfig::maxAutoZoomScale);
-        zoomTimerId = startTimer(15);
+        zoomTimeLine.setFrameRange(zoomCurrent,targetZoom);
+        zoomTimeLine.start();
       }
-      resize(targetW,targetH);
       QWidget::update();
       killTimer(layoutDoneTimerId);
       layoutDoneTimerId = 0;
@@ -443,11 +523,13 @@ namespace Gecode { namespace Gist {
         if (!smoothScrollAndZoom) {
           scaleTree(scale0);
         } else {
-          metaZoomCurrent = static_cast<int>(scale*100);
-          targetZoom = scale0;
+          zoomTimeLine.stop();
+          int zoomCurrent = static_cast<int>(scale*100);
+          int targetZoom = scale0;
           targetZoom = std::min(std::max(targetZoom, LayoutConfig::minScale),
                                 LayoutConfig::maxAutoZoomScale);
-          zoomTimerId = startTimer(15);
+          zoomTimeLine.setFrameRange(zoomCurrent,targetZoom);
+          zoomTimeLine.start();
         }
       }
     }
@@ -468,29 +550,47 @@ namespace Gecode { namespace Gist {
 
     x = static_cast<int>((xtrans+x)*scale); y = static_cast<int>(y*scale);
 
-    QScrollArea* sa =
-      static_cast<QScrollArea*>(parentWidget()->parentWidget());
+    QAbstractScrollArea* sa =
+      static_cast<QAbstractScrollArea*>(parentWidget()->parentWidget());
 
+    x -= sa->viewport()->width() / 2;
+    y -= sa->viewport()->height() / 2;
+
+    sourceX = sa->horizontalScrollBar()->value();
+    targetX = std::max(sa->horizontalScrollBar()->minimum(), x);
+    targetX = std::min(sa->horizontalScrollBar()->maximum(),
+                       targetX);
+    sourceY = sa->verticalScrollBar()->value();
+    targetY = std::max(sa->verticalScrollBar()->minimum(), y);
+    targetY = std::min(sa->verticalScrollBar()->maximum(),
+                       targetY);
     if (!smoothScrollAndZoom) {
-      sa->ensureVisible(x,y);
+      sa->horizontalScrollBar()->setValue(targetX);
+      sa->verticalScrollBar()->setValue(targetY);
     } else {
-      x -= sa->viewport()->width() / 2;
-      y -= sa->viewport()->height() / 2;
-
-      metaScrollXCurrent = sa->horizontalScrollBar()->value();
-      metaScrollYCurrent = sa->verticalScrollBar()->value();
-      targetScrollX = std::max(sa->horizontalScrollBar()->minimum(), x);
-      targetScrollX = std::min(sa->horizontalScrollBar()->maximum(),
-                               targetScrollX);
-      targetScrollY = std::max(sa->verticalScrollBar()->minimum(), y);
-      targetScrollY = std::min(sa->verticalScrollBar()->maximum(),
-                               targetScrollY);
-      scrollTimerId = startTimer(15);
+      scrollTimeLine.stop();
+      scrollTimeLine.setFrameRange(0,100);
+      scrollTimeLine.setDuration(std::max(200,
+        std::min(1000,
+        std::min(std::abs(sourceX-targetX),
+                 std::abs(sourceY-targetY)))));
+      scrollTimeLine.start();
     }
   }
 
   void
-  TreeCanvas::inspectCurrentNode(void) {
+  TreeCanvas::scroll(int i) {
+    QAbstractScrollArea* sa =
+      static_cast<QAbstractScrollArea*>(parentWidget()->parentWidget());
+    double p = static_cast<double>(i)/100.0;
+    double xdiff = static_cast<double>(targetX-sourceX)*p;
+    double ydiff = static_cast<double>(targetY-sourceY)*p;
+    sa->horizontalScrollBar()->setValue(sourceX+static_cast<int>(xdiff));
+    sa->verticalScrollBar()->setValue(sourceY+static_cast<int>(ydiff));
+  }
+
+  void
+  TreeCanvas::inspectCurrentNode(bool fix, int inspectorNo) {
     QMutexLocker locker(&mutex);
 
     if (currentNode->isHidden()) {
@@ -516,11 +616,17 @@ namespace Gecode { namespace Gist {
             currentNode->purge();
           }
           emit statusChanged(currentNode,stats,true);
+          Space* curSpace = currentNode->getSpace(curBest,c_d,a_d);
+          for (int i=0; i<moveInspectors.size(); i++) {
+            if (moveInspectors[i].second) {
+              moveInspectors[i].first->inspect(*curSpace);
+            }
+          }
         }
         break;
     case FAILED:
-    case STEP:
-    case SPECIAL:
+    case STOP:
+    case UNSTOP:
     case BRANCH:
     case SOLVED:
       {
@@ -535,24 +641,46 @@ namespace Gecode { namespace Gist {
         // std::cout << "Size / node: " << (pnv.getCursor().s)/nodes
         //           << std::endl;
 
-        if (currentNode->isRoot() && currentNode->getStatus() == FAILED)
-          break;
-        Space* curSpace = currentNode->getSpace(curBest,c_d,a_d);
-        if (currentNode->getStatus() == SOLVED &&
-            curSpace->status() != SS_SOLVED) {
-          // in the presence of weakly monotonic propagators, we may have to
-          // use search to find the solution here
-          Space* dfsSpace = Gecode::dfs(curSpace);
-          delete curSpace;
-          curSpace = dfsSpace;
-        }
-        saveCurrentNode();
-
-        for (int i=0; i<doubleClickInspectors.size(); i++) {
-          if (doubleClickInspectors[i].second) {
-            doubleClickInspectors[i].first->inspect(*curSpace);
+        Space* curSpace;
+        
+        if (fix) {
+          if (currentNode->isRoot() && currentNode->getStatus() == FAILED)
+            break;
+          curSpace = currentNode->getSpace(curBest,c_d,a_d);
+          if (currentNode->getStatus() == SOLVED &&
+              curSpace->status() != SS_SOLVED) {
+            // in the presence of weakly monotonic propagators, we may have to
+            // use search to find the solution here
+            Space* dfsSpace = Gecode::dfs(curSpace);
+            delete curSpace;
+            curSpace = dfsSpace;
+          }          
+        } else {
+          if (currentNode->isRoot())
+            break;
+          VisualNode* p = currentNode->getParent();
+          curSpace = p->getSpace(curBest,c_d,a_d);
+          switch (curSpace->status()) {
+          case SS_SOLVED:
+          case SS_FAILED:
+            break;
+          case SS_BRANCH:
+            curSpace->commit(*p->getChoice(), currentNode->getAlternative());
+            break;
+          default:
+            GECODE_NEVER;
           }
         }
+
+        if (inspectorNo==-1) {
+          for (int i=0; i<doubleClickInspectors.size(); i++) {
+            if (doubleClickInspectors[i].second) {
+              doubleClickInspectors[i].first->inspect(*curSpace);
+            }
+          }
+        } else {
+          doubleClickInspectors[inspectorNo].first->inspect(*curSpace);          
+        }
         delete curSpace;
       }
       break;
@@ -562,6 +690,11 @@ namespace Gecode { namespace Gist {
     update();
     centerCurrentNode();
   }
+  
+  void
+  TreeCanvas::inspectBeforeFP(void) {
+    inspectCurrentNode(false);
+  }
 
   void
   TreeCanvas::inspectSolution(const Space* s) {
@@ -573,6 +706,13 @@ namespace Gecode { namespace Gist {
         solutionInspectors[i].first->inspect(*c);
       }
     }
+    for (int i=0; i<moveInspectors.size(); i++) {
+      if (moveInspectors[i].second) {
+        if (c == NULL)
+          c = s->clone();
+        moveInspectors[i].first->inspect(*c);
+      }
+    }
     delete c;
   }
 
@@ -598,16 +738,42 @@ namespace Gecode { namespace Gist {
     root->setMarked(true);
     currentNode = root;
     pathHead = root;
-    nodeMap.clear();
-    nextPit = 0;
     scale = 1.0;
     stats = Statistics();
+    for (int i=bookmarks.size(); i--;)
+      emit removedBookmark(i);
+    bookmarks.clear();
     root->layout();
 
     emit statusChanged(currentNode, stats, true);
     update();
   }
 
+  void
+  TreeCanvas::bookmarkNode(void) {
+    QMutexLocker locker(&mutex);
+    if (!currentNode->isBookmarked()) {
+      bool ok;
+      QString text =
+        QInputDialog::getText(this, "Add bookmark", "Name:", 
+                              QLineEdit::Normal,"",&ok);
+      if (ok) {
+        currentNode->setBookmarked(true);
+        bookmarks.append(currentNode);
+        if (text == "")
+          text = QString("Node ")+QString().setNum(bookmarks.size());
+        emit addedBookmark(text);
+      }
+    } else {
+      currentNode->setBookmarked(false);
+      int idx = bookmarks.indexOf(currentNode);
+      bookmarks.remove(idx);
+      emit removedBookmark(idx);
+    }
+    currentNode->dirtyUp();
+    update();
+  }
+  
   void
   TreeCanvas::setPath(void) {
     QMutexLocker locker(&mutex);
@@ -638,6 +804,22 @@ namespace Gecode { namespace Gist {
     update();
   }
 
+  void
+  TreeCanvas::startCompareNodes(void) {
+    QMutexLocker locker(&mutex);
+    compareNodes = true;
+    compareNodesBeforeFP = false;
+    setCursor(QCursor(Qt::CrossCursor));
+  }
+
+  void
+  TreeCanvas::startCompareNodesBeforeFP(void) {
+    QMutexLocker locker(&mutex);
+    compareNodes = true;
+    compareNodesBeforeFP = true;
+    setCursor(QCursor(Qt::CrossCursor));
+  }
+
   void
   TreeCanvas::emitStatusChanged(void) {
     emit statusChanged(currentNode, stats, true);
@@ -661,10 +843,8 @@ namespace Gecode { namespace Gist {
     QMutexLocker locker(&mutex);
     if (!currentNode->isHidden()) {
       switch (currentNode->getStatus()) {
-      case STEP:
-      case SPECIAL:
-        if (currentNode->getNumberOfChildren() < 1)
-          break;
+      case STOP:
+      case UNSTOP:
       case BRANCH:
           {
             int alt = std::max(0, currentNode->getPathAlternative());
@@ -733,24 +913,6 @@ namespace Gecode { namespace Gist {
     navNextSol(true);
   }
 
-  void
-  TreeCanvas::markCurrentNode(int pit) {
-    QMutexLocker locker(&mutex);
-    if(nodeMap.size() > pit && nodeMap[pit] != NULL) {
-      setCurrentNode(nodeMap[pit]);
-      centerCurrentNode();
-      emit pointInTimeChanged(pit);
-    }
-  }
-
-  void
-  TreeCanvas::saveCurrentNode(void) {
-    QMutexLocker locker(&mutex);
-    assert(nextPit == nodeMap.size());
-    nodeMap << currentNode;
-    nextPit++;
-  }
-
   void
   TreeCanvas::exportNodePDF(VisualNode* n) {
 #if QT_VERSION >= 0x040400
@@ -790,6 +952,8 @@ namespace Gecode { namespace Gist {
       while (v.next()) {}
       currentNode->setMarked(true);
     }
+#else
+    (void) n;
 #endif
   }
 
@@ -872,9 +1036,20 @@ namespace Gecode { namespace Gist {
     default:
       return NULL;
     }
+    QAbstractScrollArea* sa =
+      static_cast<QAbstractScrollArea*>(parentWidget()->parentWidget());
+    int xoff = sa->horizontalScrollBar()->value()/scale;
+    int yoff = sa->verticalScrollBar()->value()/scale;
+
+    BoundingBox bb = root->getBoundingBox();
+    int w =
+      static_cast<int>((bb.right-bb.left+Layout::extent)*scale);
+    if (w < sa->viewport()->width())
+      xoff -= (sa->viewport()->width()-w)/2;
+    
     VisualNode* n;
-    n = root->findNode(static_cast<int>(x/scale-xtrans),
-                       static_cast<int>((y-30)/scale));
+    n = root->findNode(static_cast<int>(x/scale-xtrans+xoff),
+                       static_cast<int>((y-30)/scale+yoff));
     return n;
   }
 
@@ -884,7 +1059,7 @@ namespace Gecode { namespace Gist {
       if (event->type() == QEvent::ToolTip) {
         VisualNode* n = eventNode(event);
         if (n != NULL && !n->isHidden() &&
-            (n->getStatus() == BRANCH)) {
+            (n->getStatus() == BRANCH || n->getStatus() == STOP)) {
           QHelpEvent* he = static_cast<QHelpEvent*>(event);
           QToolTip::showText(he->globalPos(),
                              QString(n->toolTip(curBest,c_d,a_d).c_str()));
@@ -909,13 +1084,23 @@ namespace Gecode { namespace Gist {
     QPainter painter(this);
     painter.setRenderHint(QPainter::Antialiasing);
 
+    QAbstractScrollArea* sa =
+      static_cast<QAbstractScrollArea*>(parentWidget()->parentWidget());
+    int xoff = sa->horizontalScrollBar()->value()/scale;
+    int yoff = sa->verticalScrollBar()->value()/scale;
+
     BoundingBox bb = root->getBoundingBox();
+    int w =
+      static_cast<int>((bb.right-bb.left+Layout::extent)*scale);
+    if (w < sa->viewport()->width())
+      xoff -= (sa->viewport()->width()-w)/2;
+
     QRect origClip = event->rect();
     painter.translate(0, 30);
     painter.scale(scale,scale);
-    painter.translate(xtrans, 0);
-    QRect clip(static_cast<int>(origClip.x()/scale-xtrans),
-               static_cast<int>(origClip.y()/scale),
+    painter.translate(xtrans-xoff, -yoff);
+    QRect clip(static_cast<int>(origClip.x()/scale-xtrans+xoff),
+               static_cast<int>(origClip.y()/scale+yoff),
                static_cast<int>(origClip.width()/scale),
                static_cast<int>(origClip.height()/scale));
     DrawingCursor dc(root, curBest, painter, clip, showCopies);
@@ -967,6 +1152,32 @@ namespace Gecode { namespace Gist {
     event->ignore();
   }
 
+  void
+  TreeCanvas::resizeEvent(QResizeEvent* e) {
+    QAbstractScrollArea* sa =
+      static_cast<QAbstractScrollArea*>(parentWidget()->parentWidget());
+
+    int w = sa->horizontalScrollBar()->maximum()+e->oldSize().width();
+    int h = sa->verticalScrollBar()->maximum()+e->oldSize().height();
+
+    sa->horizontalScrollBar()->setRange(0,w-e->size().width());
+    sa->verticalScrollBar()->setRange(0,h-e->size().height());
+    sa->horizontalScrollBar()->setPageStep(e->size().width());
+    sa->verticalScrollBar()->setPageStep(e->size().height());
+  }
+
+  void
+  TreeCanvas::wheelEvent(QWheelEvent* event) {
+    if (event->modifiers() & Qt::ShiftModifier) {
+      event->accept();
+      if (event->orientation() == Qt::Vertical && !autoZoom)
+        scaleTree(scale*100+ceil(static_cast<double>(event->delta())/4.0),
+                  event->x(), event->y());
+    } else {
+      event->ignore();
+    }
+  }
+
   bool
   TreeCanvas::finish(void) {
     if (finishedFlag)
@@ -977,18 +1188,36 @@ namespace Gecode { namespace Gist {
       doubleClickInspectors[i].first->finalize();
     for (int i=0; i<solutionInspectors.size(); i++)
       solutionInspectors[i].first->finalize();
+    for (int i=0; i<moveInspectors.size(); i++)
+      moveInspectors[i].first->finalize();
+    for (int i=0; i<comparators.size(); i++)
+      comparators[i].first->finalize();
     return !searcher.isRunning();
   }
 
   void
-  TreeCanvas::setCurrentNode(VisualNode* n) {
+  TreeCanvas::setCurrentNode(VisualNode* n, bool update) {
     QMutexLocker locker(&mutex);
+    if (update && n != NULL && n != currentNode &&
+        n->getStatus() != UNDETERMINED && !n->isHidden()) {
+      Space* curSpace = NULL;
+      for (int i=0; i<moveInspectors.size(); i++) {
+        if (moveInspectors[i].second) {
+          if (curSpace == NULL)
+            curSpace = n->getSpace(curBest,c_d,a_d);
+          moveInspectors[i].first->inspect(*curSpace);
+        }
+      }
+    }
     if (n != NULL) {
+      compareNodes = false;
+      setCursor(QCursor(Qt::ArrowCursor));
       currentNode->setMarked(false);
       currentNode = n;
       currentNode->setMarked(true);
       emit statusChanged(currentNode,stats,true);
-      QWidget::update();
+      if (update)
+        QWidget::update();
     }
   }
 
@@ -997,7 +1226,44 @@ namespace Gecode { namespace Gist {
     if (mutex.tryLock()) {
       if (event->button() == Qt::LeftButton) {
         VisualNode* n = eventNode(event);
-        setCurrentNode(n);
+        if (compareNodes) {
+          if (n != NULL && n->getStatus() != UNDETERMINED &&
+              currentNode != NULL &&
+              currentNode->getStatus() != UNDETERMINED) {
+            Space* curSpace = NULL;
+            Space* compareSpace = NULL;
+            for (int i=0; i<comparators.size(); i++) {
+              if (comparators[i].second) {
+                if (curSpace == NULL) {
+                  curSpace = currentNode->getSpace(curBest,c_d,a_d);
+
+                  if (!compareNodesBeforeFP || n->isRoot()) {
+                    compareSpace = n->getSpace(curBest,c_d,a_d);
+                  } else {
+                    VisualNode* p = n->getParent();
+                    compareSpace = p->getSpace(curBest,c_d,a_d);
+                    switch (compareSpace->status()) {
+                    case SS_SOLVED:
+                    case SS_FAILED:
+                      break;
+                    case SS_BRANCH:
+                      compareSpace->commit(*p->getChoice(), 
+                                           n->getAlternative());
+                      break;
+                    default:
+                      GECODE_NEVER;
+                    }
+                  }
+                }
+                comparators[i].first->compare(*curSpace,*compareSpace);
+              }
+            }
+          }
+        } else {
+          setCurrentNode(n);
+        }
+        compareNodes = false;
+        setCursor(QCursor(Qt::ArrowCursor));
         if (n != NULL) {
           event->accept();
           mutex.unlock();
