@@ -7,8 +7,8 @@
  *     Christian Schulte, 2008
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
+ *     $Revision: 10684 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -38,7 +38,7 @@
 namespace Gecode { namespace Int { namespace Branch {
 
   /**
-   * \brief Choice storing position and values
+   * \brief %Choice storing position and values
    *
    * The maximal number of alternatives is defined by \a alt.
    */
@@ -124,9 +124,16 @@ namespace Gecode { namespace Int { namespace Branch {
   forceinline
   ViewValuesBrancher<ViewSel,View>::
   ViewValuesBrancher(Home home, ViewArray<typename ViewSel::View>& x,
-                      ViewSel& vi_s)
+                     ViewSel& vi_s)
     : ViewBrancher<ViewSel>(home,x,vi_s) {}
 
+  template<class ViewSel, class View>
+  void
+  ViewValuesBrancher<ViewSel,View>::
+  post(Home home, ViewArray<typename ViewSel::View>& x, ViewSel& vi_s) {
+    (void) new (home) ViewValuesBrancher<ViewSel,View>(home,x,vi_s);
+  }
+
   template<class ViewSel, class View>
   forceinline
   ViewValuesBrancher<ViewSel,View>::
