@@ -11,8 +11,8 @@
  *     Mikael Lagerkvist, 2006
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -220,7 +220,7 @@ namespace Gecode { namespace Int { namespace Channel {
                            (home,n,y,x,n_na,ya,xa)));
           assert(ya.empty());
         } while (!xa.empty() || !ya.empty());
-        return ES_NOFIX_PARTIAL(*this,View::med(ME_INT_DOM));
+        return home.ES_NOFIX_PARTIAL(*this,View::med(ME_INT_DOM));
       } else {
         do {
           // Propagate assigned views for x
@@ -231,7 +231,7 @@ namespace Gecode { namespace Int { namespace Channel {
                            (home,n,y,x,n_na,ya,xa)));
           assert(ya.empty());
         } while (!xa.empty());
-        return ES_FIX_PARTIAL(*this,View::med(ME_INT_DOM));
+        return home.ES_FIX_PARTIAL(*this,View::med(ME_INT_DOM));
       }
     }
 
@@ -293,9 +293,9 @@ namespace Gecode { namespace Int { namespace Channel {
       for (int i=2*n; i--; )
         if (!xy[i].view.assigned())
           return ES_NOFIX;
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     } else {
-      return (n_na == 0) ? ES_SUBSUMED(*this,home) : ES_FIX;
+      return (n_na == 0) ? home.ES_SUBSUMED(*this) : ES_FIX;
     }
   }
 
