@@ -9,8 +9,8 @@
  *     Gabor Szokoli, 2003
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-03 17:40:32 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10365 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -51,13 +51,13 @@ namespace Gecode {
     ViewArray<IntView> xv(home,x);
     switch (icl) {
     case ICL_BND:
-      GECODE_ES_FAIL(home,Distinct::Bnd<IntView>::post(home,xv));
+      GECODE_ES_FAIL(Distinct::Bnd<IntView>::post(home,xv));
       break;
     case ICL_DOM:
-      GECODE_ES_FAIL(home,Distinct::Dom<IntView>::post(home,xv));
+      GECODE_ES_FAIL(Distinct::Dom<IntView>::post(home,xv));
       break;
     default:
-      GECODE_ES_FAIL(home,Distinct::Val<IntView>::post(home,xv));
+      GECODE_ES_FAIL(Distinct::Val<IntView>::post(home,xv));
     }
   }
 
@@ -82,13 +82,13 @@ namespace Gecode {
     }
     switch (icl) {
     case ICL_BND:
-      GECODE_ES_FAIL(home,Distinct::Bnd<OffsetView>::post(home,cx));
+      GECODE_ES_FAIL(Distinct::Bnd<OffsetView>::post(home,cx));
       break;
     case ICL_DOM:
-      GECODE_ES_FAIL(home,Distinct::Dom<OffsetView>::post(home,cx));
+      GECODE_ES_FAIL(Distinct::Dom<OffsetView>::post(home,cx));
       break;
     default:
-      GECODE_ES_FAIL(home,Distinct::Val<OffsetView>::post(home,cx));
+      GECODE_ES_FAIL(Distinct::Val<OffsetView>::post(home,cx));
     }
   }
 
