@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-14 10:56:06 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9902 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -136,10 +136,8 @@ namespace Gecode { namespace Int { namespace Element {
   forceinline size_t
   Int<V0,V1,Idx,Val>::dispose(Space& home) {
     home.ignore(*this,AP_DISPOSE);
-    if (!home.failed()) {
-      x0.cancel(home,*this,PC_INT_DOM);
-      x1.cancel(home,*this,PC_INT_DOM);
-    }
+    x0.cancel(home,*this,PC_INT_DOM);
+    x1.cancel(home,*this,PC_INT_DOM);
     c.~IntSharedArray();
     (void) Propagator::dispose(home);
     return sizeof(*this);
@@ -261,11 +259,11 @@ namespace Gecode { namespace Int { namespace Element {
       IterVal v(iv);
       if (shared(x0,x1)) {
         GECODE_ME_CHECK(x1.inter_v(home,v,false));
-        return assigned ? ES_SUBSUMED(*this,home) : ES_NOFIX;
+        return assigned ? home.ES_SUBSUMED(*this) : ES_NOFIX;
       } else {
         GECODE_ME_CHECK(x1.narrow_v(home,v,false));
         return (x0.assigned() || x1.assigned()) ?
-          ES_SUBSUMED(*this,home) : ES_FIX;
+          home.ES_SUBSUMED(*this) : ES_FIX;
       }
     }
   }
