@@ -11,8 +11,8 @@
  *     Christian Schulte, 2008
  *
  *  Last modified:
- *     $Date: 2009-10-14 10:57:22 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9903 $
+ *     $Date: 2010-02-02 14:05:18 +0100 (Tue, 02 Feb 2010) $ by $Author: schulte $
+ *     $Revision: 10259 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -144,20 +144,19 @@ namespace Gecode { namespace Int { namespace Extensional {
 
 
   template<class View, bool subscribe>
-  size_t
+  forceinline size_t
   Base<View,subscribe>::dispose(Space& home) {
     home.ignore(*this,AP_DISPOSE);
     (void) Propagator::dispose(home);
-    if (!home.failed()) {
-      if (subscribe)
-        x.cancel(home,*this,PC_INT_DOM);
-      // take care of last_data
-      int literals = ts()->domsize*x.size();
-      home.rfree(last_data, sizeof(Tuple*)*literals);
-    }
+    if (subscribe)
+      x.cancel(home,*this,PC_INT_DOM);
+    // take care of last_data
+    int literals = ts()->domsize*x.size();
+    home.rfree(last_data, sizeof(Tuple*)*literals);
     (void) tupleSet.~TupleSet();
     return sizeof(*this);
   }
+
 }}}
 
 // STATISTICS: int-prop
