@@ -11,8 +11,8 @@
  *     Christian Schulte, 2008
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-10 11:36:44 +0100 (Wed, 10 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10387 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -352,6 +352,25 @@ namespace Gecode { namespace Int { namespace Extensional {
     return new (home) Incremental<View>(home,share,*this);
   }
 
+  template<class View>
+  forceinline size_t
+  Incremental<View>::dispose(Space& home) {
+    if (!home.failed()) {
+      int literals = ts()->domsize*x.size();
+      for (int i = literals; i--; )
+        if (support_data[i]) {
+          SupportEntry* lastse = support_data[i];
+          while (lastse->next() != NULL)
+            lastse = lastse->next();
+          support_data[i]->dispose(home, lastse);
+        }
+      home.rfree(support_data, sizeof(SupportEntry*)*literals);
+    }
+    ac.dispose(home);
+    (void) Base<View,false>::dispose(home);
+    return sizeof(*this);
+  }
+
   template<class View>
   ExecStatus
   Incremental<View>::propagate(Space& home, const ModEventDelta&) {
@@ -371,7 +390,7 @@ namespace Gecode { namespace Int { namespace Extensional {
         // Work is still relevant
         if (dom[i].get(n-ts()->min)) {
           GECODE_ME_CHECK(x[i].nq(home,n));
-          dom[i].set(n-ts()->min,false);
+          dom[i].clear(n-ts()->min);
         }
       }
       while (!w_support.empty()) {
@@ -385,7 +404,7 @@ namespace Gecode { namespace Int { namespace Extensional {
     if (unassigned != 0)
       return ES_FIX;
 
-    return ES_SUBSUMED(*this, home);
+    return home.ES_SUBSUMED(*this);
   }
 
 
@@ -418,9 +437,9 @@ namespace Gecode { namespace Int { namespace Extensional {
       // propagator is not subsumed since unassigned!=0
       if (((w_support.empty() && w_remove.empty()) || scheduled) &&
           (unassigned != 0))
-        return ES_SUBSUMED_FIX(a,home,ac);
+        return home.ES_FIX_DISPOSE(ac,a);
       else
-        return ES_SUBSUMED_NOFIX(a,home,ac);
+        return home.ES_NOFIX_DISPOSE(ac,a);
     } else if ((w_support.empty() && w_remove.empty()) || scheduled) {
       // nothing to do or already scheduled
       return ES_FIX;
@@ -429,25 +448,6 @@ namespace Gecode { namespace Int { namespace Extensional {
   }
 
 
-  template<class View>
-  size_t
-  Incremental<View>::dispose(Space& home) {
-    if (!home.failed()) {
-      int literals = ts()->domsize*x.size();
-      for (int i = literals; i--; )
-        if (support_data[i]) {
-          SupportEntry* lastse = support_data[i];
-          while (lastse->next() != NULL)
-            lastse = lastse->next();
-          support_data[i]->dispose(home, lastse);
-        }
-      home.rfree(support_data, sizeof(SupportEntry*)*literals);
-    }
-    ac.dispose(home);
-    (void) Base<View,false>::dispose(home);
-    return sizeof(*this);
-  }
-
 }}}
 
 // STATISTICS: int-prop
