@@ -7,8 +7,8 @@
  *     Mikael Lagerkvist, 2007
  *
  *  Last modified:
- *     $Date: 2009-05-25 02:20:46 +0200 (Mon, 25 May 2009) $ by $Author: tack $
- *     $Revision: 9176 $
+ *     $Date: 2010-04-01 14:13:29 +0200 (Thu, 01 Apr 2010) $ by $Author: tack $
+ *     $Revision: 10640 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -201,7 +201,7 @@ namespace Gecode {
 
     // Last data
     d->last = heap.alloc<Tuple*>(domsize*arity);
-    for (int i = domsize+arity; i--; ) {
+    for (int i = domsize*arity; i--; ) {
       d->last[i] = d->tuple_data + (last[i]-tuple_data);
     }
 
