@@ -13,8 +13,8 @@
  *     Guido Tack, 2009
  *
  *  Last modified:
- *     $Date: 2009-10-05 20:36:54 +0200 (Mon, 05 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9838 $
+ *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
+ *     $Revision: 10684 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -131,7 +131,7 @@ namespace Gecode { namespace Int { namespace GCC {
     //@}
   };
 
-  /// %Variable Node
+  /// %Variable node
   class VarNode : public Node {
   protected:
     /// Stores the matching edge on this node in the UBC
@@ -1310,7 +1310,7 @@ namespace Gecode { namespace Int { namespace GCC {
     // start repair
     while (!re.empty()) {
       Node* n = re.pop();
-      if (!n->removed())
+      if (!n->removed()) {
         if (!n->type()) {
           VarNode* vrn = static_cast<VarNode*>(n);
           if (!vrn->matched(UBC) && !augmenting_path<UBC>(home,vrn))
@@ -1321,6 +1321,7 @@ namespace Gecode { namespace Int { namespace GCC {
             if (!augmenting_path<LBC>(home,vln))
               return ES_FAILED;
         }
+      }
     }
 
     return ES_OK;
