@@ -13,8 +13,8 @@
  *     Guido Tack, 2009
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -88,7 +88,7 @@ namespace Gecode { namespace Int { namespace GCC {
   }
 
   template<class Card>
-  size_t
+  forceinline size_t
   Dom<Card>::dispose(Space& home) {
     x.cancel(home,*this, PC_INT_DOM);
     k.cancel(home,*this, PC_INT_DOM);
@@ -139,7 +139,7 @@ namespace Gecode { namespace Int { namespace GCC {
         if (Card::propagate)
           GECODE_ME_CHECK(k[i].eq(home, count[i]));
       }
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
 
     // before propagation performs inferences on cardinality variables:
@@ -160,7 +160,7 @@ namespace Gecode { namespace Int { namespace GCC {
       for (int j = k.size(); j--; )
         if ((k[j].min() > k[j].counter()) || (k[j].max() < k[j].counter()))
           return ES_FAILED;
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     } else if ((x.size() == 1) && (x[0].assigned())) {
       int idx;
       if (!lookupValue(k,x[0].val(),idx))
@@ -169,7 +169,7 @@ namespace Gecode { namespace Int { namespace GCC {
       for (int j = k.size(); j--; )
         if ((k[j].min() > k[j].counter()) || (k[j].max() < k[j].counter()))
           return ES_FAILED;
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
 
     if (vvg == NULL) {
@@ -228,7 +228,7 @@ namespace Gecode { namespace Int { namespace GCC {
             if ((k[j].min() > k[j].counter()) || 
                 (k[j].max() < k[j].counter()))
               return ES_FAILED;
-          return ES_SUBSUMED(*this,home);
+          return home.ES_SUBSUMED(*this);
         } else if ((x.size() == 1) && x[0].assigned()) {
           int idx;
           if (!lookupValue(k,x[0].val(),idx))
@@ -239,7 +239,7 @@ namespace Gecode { namespace Int { namespace GCC {
             if ((k[j].min() > k[j].counter()) || 
                 (k[j].max() < k[j].counter()))
               return ES_FAILED;
-          return ES_SUBSUMED(*this,home);
+          return home.ES_SUBSUMED(*this);
         }
       }
     }
@@ -272,7 +272,7 @@ namespace Gecode { namespace Int { namespace GCC {
         if (Card::propagate)
           GECODE_ME_CHECK(k[i].eq(home,count[i]));
       }
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
 
     if (Card::propagate) {
