@@ -7,8 +7,8 @@
  *     Christian Schulte, 2005
  *
  *  Last modified:
- *     $Date: 2009-08-24 16:20:28 +0200 (Mon, 24 Aug 2009) $ by $Author: schulte $
- *     $Revision: 9618 $
+ *     $Date: 2010-03-25 14:23:47 +0100 (Thu, 25 Mar 2010) $ by $Author: tack $
+ *     $Revision: 10571 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -61,6 +61,24 @@ namespace Gecode { namespace Int {
         throw OutOfLimits(l);
     }
 
+    inline void
+    Limits::nonnegative(int n, const char* l) {
+      if ((n < 0) || (n > max))
+        throw OutOfLimits(l);
+    }
+
+    inline void
+    Limits::nonnegative(double n, const char* l) {
+      if ((n < 0.0) || (n > max))
+        throw OutOfLimits(l);
+    }
+
+    inline void
+    Limits::double_check(double n, const char* l) {
+      if ((n < double_min) || (n > double_max))
+        throw OutOfLimits(l);
+    }
+
 }}
 
 // STATISTICS: int-var
