@@ -7,8 +7,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2009-11-04 17:06:58 +0100 (Wed, 04 Nov 2009) $ by $Author: tack $
- *     $Revision: 10046 $
+ *     $Date: 2010-03-03 17:40:32 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10365 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -43,11 +43,6 @@
 
 namespace Gecode { namespace Int { namespace Linear {
 
-  /// Largest double that can exactly be represented
-  const double double_max = 9007199254740991.0;
-  /// Smallest double that can exactly be represented
-  const double double_min = -9007199254740991.0;
-
   /// Eliminate assigned views
   inline void
   eliminate(Term<IntView>* t, int &n, double& d) {
@@ -56,7 +51,7 @@ namespace Gecode { namespace Int { namespace Linear {
         d -= t[i].a * static_cast<double>(t[i].x.val());
         t[i]=t[--n];
       }
-    if ((d < double_min) || (d > double_max))
+    if ((d < Limits::double_min) || (d > Limits::double_max))
       throw OutOfLimits("Int::linear");
   }
 
@@ -100,27 +95,31 @@ namespace Gecode { namespace Int { namespace Linear {
     sl -= d;
     su -= d;
 
-    if ((sl < double_min) || (su > double_max))
+    if ((sl < Limits::double_min) || (su > Limits::double_max))
       throw OutOfLimits("Int::linear");
 
     bool is_ip = (sl >= Limits::min) && (su <= Limits::max);
 
     for (int i = n_p; i--; ) {
-      if (sl - t_p[i].a * static_cast<double>(t_p[i].x.min()) < double_min)
+      if (sl - t_p[i].a * static_cast<double>(t_p[i].x.min()) 
+          < Limits::double_min)
         throw OutOfLimits("Int::linear");
       if (sl - t_p[i].a * static_cast<double>(t_p[i].x.min()) < Limits::min)
         is_ip = false;
-      if (su - t_p[i].a * static_cast<double>(t_p[i].x.max()) > double_max)
+      if (su - t_p[i].a * static_cast<double>(t_p[i].x.max()) 
+          > Limits::double_max)
         throw OutOfLimits("Int::linear");
       if (su - t_p[i].a * static_cast<double>(t_p[i].x.max()) > Limits::max)
         is_ip = false;
     }
     for (int i = n_n; i--; ) {
-      if (sl + t_n[i].a * static_cast<double>(t_n[i].x.min()) < double_min)
+      if (sl + t_n[i].a * static_cast<double>(t_n[i].x.min()) 
+          < Limits::double_min)
         throw OutOfLimits("Int::linear");
       if (sl + t_n[i].a * static_cast<double>(t_n[i].x.min()) < Limits::min)
         is_ip = false;
-      if (su + t_n[i].a * static_cast<double>(t_n[i].x.max()) > double_max)
+      if (su + t_n[i].a * static_cast<double>(t_n[i].x.max()) 
+          > Limits::double_max)
         throw OutOfLimits("Int::linear");
       if (su + t_n[i].a * static_cast<double>(t_n[i].x.max()) > Limits::max)
         is_ip = false;
@@ -138,13 +137,13 @@ namespace Gecode { namespace Int { namespace Linear {
             ViewArray<View>& x, ViewArray<View>& y, IntRelType r, Val c) {
     switch (r) {
     case IRT_EQ:
-      GECODE_ES_FAIL(home,(Eq<Val,View,View >::post(home,x,y,c)));
+      GECODE_ES_FAIL((Eq<Val,View,View >::post(home,x,y,c)));
       break;
     case IRT_NQ:
-      GECODE_ES_FAIL(home,(Nq<Val,View,View >::post(home,x,y,c)));
+      GECODE_ES_FAIL((Nq<Val,View,View >::post(home,x,y,c)));
       break;
     case IRT_LQ:
-      GECODE_ES_FAIL(home,(Lq<Val,View,View >::post(home,x,y,c)));
+      GECODE_ES_FAIL((Lq<Val,View,View >::post(home,x,y,c)));
       break;
     default: GECODE_NEVER;
     }
@@ -155,15 +154,15 @@ namespace Gecode { namespace Int { namespace Linear {
 #define GECODE_INT_PL_BIN(CLASS)                                             \
   switch (n_p) {                                                             \
   case 2:                                                                    \
-    GECODE_ES_FAIL(home,(CLASS<int,IntView,IntView>::post                    \
+    GECODE_ES_FAIL((CLASS<int,IntView,IntView>::post                    \
                          (home,t_p[0].x,t_p[1].x,c)));                       \
     break;                                                                   \
   case 1:                                                                    \
-    GECODE_ES_FAIL(home,(CLASS<int,IntView,MinusView>::post                  \
+    GECODE_ES_FAIL((CLASS<int,IntView,MinusView>::post                  \
                          (home,t_p[0].x,MinusView(t_n[0].x),c)));            \
     break;                                                                   \
   case 0:                                                                    \
-    GECODE_ES_FAIL(home,(CLASS<int,MinusView,MinusView>::post                \
+    GECODE_ES_FAIL((CLASS<int,MinusView,MinusView>::post                \
                          (home,MinusView(t_n[0].x),MinusView(t_n[1].x),c))); \
     break;                                                                   \
   default: GECODE_NEVER;                                                     \
@@ -173,21 +172,21 @@ namespace Gecode { namespace Int { namespace Linear {
 #define GECODE_INT_PL_TER(CLASS)                                        \
   switch (n_p) {                                                        \
   case 3:                                                               \
-    GECODE_ES_FAIL(home,(CLASS<int,IntView,IntView,IntView>::post       \
+    GECODE_ES_FAIL((CLASS<int,IntView,IntView,IntView>::post       \
                          (home,t_p[0].x,t_p[1].x,t_p[2].x,c)));         \
     break;                                                              \
   case 2:                                                               \
-    GECODE_ES_FAIL(home,(CLASS<int,IntView,IntView,MinusView>::post     \
+    GECODE_ES_FAIL((CLASS<int,IntView,IntView,MinusView>::post     \
                          (home,t_p[0].x,t_p[1].x,                       \
                           MinusView(t_n[0].x),c)));                     \
     break;                                                              \
   case 1:                                                               \
-    GECODE_ES_FAIL(home,(CLASS<int,IntView,MinusView,MinusView>::post   \
+    GECODE_ES_FAIL((CLASS<int,IntView,MinusView,MinusView>::post   \
                          (home,t_p[0].x,                                \
                           MinusView(t_n[0].x),MinusView(t_n[1].x),c))); \
     break;                                                              \
   case 0:                                                               \
-    GECODE_ES_FAIL(home,(CLASS<int,MinusView,MinusView,MinusView>::post \
+    GECODE_ES_FAIL((CLASS<int,MinusView,MinusView,MinusView>::post \
                          (home,MinusView(t_n[0].x),                     \
                           MinusView(t_n[1].x),MinusView(t_n[2].x),c))); \
     break;                                                              \
@@ -224,17 +223,17 @@ namespace Gecode { namespace Int { namespace Linear {
       if (n_p == 1) {
         DoubleScaleView y(t_p[0].a,t_p[0].x);
         switch (r) {
-        case IRT_EQ: GECODE_ME_FAIL(home,y.eq(home,d)); break;
-        case IRT_NQ: GECODE_ME_FAIL(home,y.nq(home,d)); break;
-        case IRT_LQ: GECODE_ME_FAIL(home,y.lq(home,d)); break;
+        case IRT_EQ: GECODE_ME_FAIL(y.eq(home,d)); break;
+        case IRT_NQ: GECODE_ME_FAIL(y.nq(home,d)); break;
+        case IRT_LQ: GECODE_ME_FAIL(y.lq(home,d)); break;
         default: GECODE_NEVER;
         }
       } else {
         DoubleScaleView y(t_n[0].a,t_n[0].x);
         switch (r) {
-        case IRT_EQ: GECODE_ME_FAIL(home,y.eq(home,-d)); break;
-        case IRT_NQ: GECODE_ME_FAIL(home,y.nq(home,-d)); break;
-        case IRT_LQ: GECODE_ME_FAIL(home,y.gq(home,-d)); break;
+        case IRT_EQ: GECODE_ME_FAIL(y.eq(home,-d)); break;
+        case IRT_NQ: GECODE_ME_FAIL(y.nq(home,-d)); break;
+        case IRT_LQ: GECODE_ME_FAIL(y.gq(home,-d)); break;
         default: GECODE_NEVER;
         }
       }
@@ -279,7 +278,7 @@ namespace Gecode { namespace Int { namespace Linear {
       for (int i = n_n; i--; )
         y[i].init(t_n[i].a,t_n[i].x);
       if ((icl == ICL_DOM) && (r == IRT_EQ)) {
-        GECODE_ES_FAIL(home,(DomEq<int,IntScaleView>::post(home,x,y,c)));
+        GECODE_ES_FAIL((DomEq<int,IntScaleView>::post(home,x,y,c)));
       } else {
         post_nary<int,IntScaleView>(home,x,y,r,c);
       }
@@ -292,7 +291,7 @@ namespace Gecode { namespace Int { namespace Linear {
       for (int i = n_n; i--; )
         y[i].init(t_n[i].a,t_n[i].x);
       if ((icl == ICL_DOM) && (r == IRT_EQ)) {
-        GECODE_ES_FAIL(home,(DomEq<double,DoubleScaleView>::post(home,x,y,d)));
+        GECODE_ES_FAIL((DomEq<double,DoubleScaleView>::post(home,x,y,d)));
       } else {
         post_nary<double,DoubleScaleView>(home,x,y,r,d);
       }
@@ -314,17 +313,17 @@ namespace Gecode { namespace Int { namespace Linear {
             IntRelType r, Val c, BoolView b) {
     switch (r) {
     case IRT_EQ:
-      GECODE_ES_FAIL(home,(ReEq<Val,View,View,BoolView>::post(home,x,y,c,b)));
+      GECODE_ES_FAIL((ReEq<Val,View,View,BoolView>::post(home,x,y,c,b)));
       break;
     case IRT_NQ:
       {
         NegBoolView n(b);
-        GECODE_ES_FAIL(home,(ReEq<Val,View,View,NegBoolView>::post
+        GECODE_ES_FAIL((ReEq<Val,View,View,NegBoolView>::post
                              (home,x,y,c,n)));
       }
       break;
     case IRT_LQ:
-      GECODE_ES_FAIL(home,(ReLq<Val,View,View>::post(home,x,y,c,b)));
+      GECODE_ES_FAIL((ReLq<Val,View,View>::post(home,x,y,c,b)));
       break;
     default: GECODE_NEVER;
     }
@@ -368,10 +367,10 @@ namespace Gecode { namespace Int { namespace Linear {
         switch (r) {
         case IRT_EQ:
           if (n_p == 1) {
-            GECODE_ES_FAIL(home,(Rel::ReEqBndInt<IntView,BoolView>::post
+            GECODE_ES_FAIL((Rel::ReEqBndInt<IntView,BoolView>::post
                                  (home,t_p[0].x,c,b)));
           } else {
-            GECODE_ES_FAIL(home,(Rel::ReEqBndInt<IntView,BoolView>::post
+            GECODE_ES_FAIL((Rel::ReEqBndInt<IntView,BoolView>::post
                                  (home,t_n[0].x,-c,b)));
           }
           break;
@@ -379,21 +378,21 @@ namespace Gecode { namespace Int { namespace Linear {
           {
             NegBoolView nb(b);
             if (n_p == 1) {
-              GECODE_ES_FAIL(home,(Rel::ReEqBndInt<IntView,NegBoolView>::post
+              GECODE_ES_FAIL((Rel::ReEqBndInt<IntView,NegBoolView>::post
                                    (home,t_p[0].x,c,nb)));
             } else {
-              GECODE_ES_FAIL(home,(Rel::ReEqBndInt<IntView,NegBoolView>::post
+              GECODE_ES_FAIL((Rel::ReEqBndInt<IntView,NegBoolView>::post
                                    (home,t_n[0].x,-c,nb)));
             }
           }
           break;
         case IRT_LQ:
           if (n_p == 1) {
-            GECODE_ES_FAIL(home,(Rel::ReLqInt<IntView,BoolView>::post
+            GECODE_ES_FAIL((Rel::ReLqInt<IntView,BoolView>::post
                                  (home,t_p[0].x,c,b)));
           } else {
             NegBoolView nb(b);
-            GECODE_ES_FAIL(home,(Rel::ReLqInt<IntView,NegBoolView>::post
+            GECODE_ES_FAIL((Rel::ReLqInt<IntView,NegBoolView>::post
                                  (home,t_n[0].x,-c-1,nb)));
           }
           break;
@@ -404,15 +403,15 @@ namespace Gecode { namespace Int { namespace Linear {
         case IRT_EQ:
           switch (n_p) {
           case 2:
-            GECODE_ES_FAIL(home,(ReEqBin<int,IntView,IntView,BoolView>::post
+            GECODE_ES_FAIL((ReEqBin<int,IntView,IntView,BoolView>::post
                                  (home,t_p[0].x,t_p[1].x,c,b)));
             break;
           case 1:
-            GECODE_ES_FAIL(home,(ReEqBin<int,IntView,MinusView,BoolView>::post
+            GECODE_ES_FAIL((ReEqBin<int,IntView,MinusView,BoolView>::post
                                  (home,t_p[0].x,MinusView(t_n[0].x),c,b)));
             break;
           case 0:
-            GECODE_ES_FAIL(home,(ReEqBin<int,IntView,IntView,BoolView>::post
+            GECODE_ES_FAIL((ReEqBin<int,IntView,IntView,BoolView>::post
                                  (home,t_n[0].x,t_n[1].x,-c,b)));
             break;
           default: GECODE_NEVER;
@@ -423,18 +422,18 @@ namespace Gecode { namespace Int { namespace Linear {
             NegBoolView nb(b);
             switch (n_p) {
             case 2:
-              GECODE_ES_FAIL(home,
+              GECODE_ES_FAIL(
                              (ReEqBin<int,IntView,IntView,NegBoolView>::post
                               (home,t_p[0].x,t_p[1].x,c,nb)));
               break;
             case 1:
-              GECODE_ES_FAIL(home,
+              GECODE_ES_FAIL(
                              (ReEqBin<int,IntView,MinusView,NegBoolView>::post
                               (home,t_p[0].x,MinusView(t_n[0].x),c,
                                NegBoolView(b))));
               break;
             case 0:
-              GECODE_ES_FAIL(home,
+              GECODE_ES_FAIL(
                              (ReEqBin<int,IntView,IntView,NegBoolView>::post
                               (home,t_p[0].x,t_p[1].x,-c,NegBoolView(b))));
               break;
@@ -445,15 +444,15 @@ namespace Gecode { namespace Int { namespace Linear {
         case IRT_LQ:
           switch (n_p) {
           case 2:
-            GECODE_ES_FAIL(home,(ReLqBin<int,IntView,IntView>::post
+            GECODE_ES_FAIL((ReLqBin<int,IntView,IntView>::post
                                  (home,t_p[0].x,t_p[1].x,c,b)));
             break;
           case 1:
-            GECODE_ES_FAIL(home,(ReLqBin<int,IntView,MinusView>::post
+            GECODE_ES_FAIL((ReLqBin<int,IntView,MinusView>::post
                                  (home,t_p[0].x,MinusView(t_n[0].x),c,b)));
             break;
           case 0:
-            GECODE_ES_FAIL(home,(ReLqBin<int,MinusView,MinusView>::post
+            GECODE_ES_FAIL((ReLqBin<int,MinusView,MinusView>::post
                                  (home,MinusView(t_n[0].x),
                                   MinusView(t_n[1].x),c,b)));
             break;
