@@ -7,8 +7,8 @@
  *     Christian Schulte, 2007
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-03 17:40:32 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10365 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -135,13 +135,13 @@ namespace Gecode {
   void
   unshare(Home home, IntVarArgs& x, IntConLevel icl) {
     if (home.failed()) return;
-    GECODE_ES_FAIL(home,Int::Unshare::unshare<IntVar>(home,x,icl));
+    GECODE_ES_FAIL(Int::Unshare::unshare<IntVar>(home,x,icl));
   }
 
   void
   unshare(Home home, BoolVarArgs& x, IntConLevel) {
     if (home.failed()) return;
-    GECODE_ES_FAIL(home,Int::Unshare::unshare<BoolVar>(home,x,ICL_DEF));
+    GECODE_ES_FAIL(Int::Unshare::unshare<BoolVar>(home,x,ICL_DEF));
   }
 
 }
