@@ -7,8 +7,8 @@
  *     Christian Schulte, 2003
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2009-11-23 15:38:32 +0100 (Mon, 23 Nov 2009) $ by $Author: schulte $
+ *     $Revision: 10098 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -244,8 +244,10 @@ namespace Gecode {
      *
      */
     forceinline void
-    ZeroIntView::subscribe(Space& home, Propagator& p, PropCond,bool) {
-      schedule(home,p,ME_INT_VAL);
+    ZeroIntView::subscribe(Space& home, Propagator& p, PropCond,
+                           bool process) {
+      if (process)
+        schedule(home,p,ME_INT_VAL);
     }
     forceinline void
     ZeroIntView::cancel(Space&,Propagator&,PropCond) {}
