@@ -6,9 +6,12 @@
  *  Copyright:
  *     LOGIS, s.r.o., 2009
  *
+ *  Bugfixes provided by:
+ *     Gustavo Gutierrez
+ *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
+ *     $Revision: 10684 $
  *
  *  Permission is hereby granted, free of charge, to any person obtaining
  *  a copy of this software and associated documentation files (the
@@ -145,7 +148,7 @@ typedef std::set<int, std::less<int>, Gecode::region_allocator<int> > SR;
 
 
   /**
-   * \brief Space allocator - specialization for \c void.
+   * \brief %Space allocator - specialization for \c void.
    *
    * The specialization is needed as the default instantiation fails 
    * for \c void.
@@ -155,6 +158,7 @@ typedef std::set<int, std::less<int>, Gecode::region_allocator<int> > SR;
     typedef void*       pointer;
     typedef const void* const_pointer;
     typedef void        value_type;
+    /// Rebinding helper (returns the type of a similar allocator for type \a U)
     template<class U> struct rebind {
       typedef space_allocator<U> other;
     };
@@ -204,6 +208,14 @@ typedef std::set<int, std::less<int>, Gecode::region_allocator<int> > SR;
      * @param al The allocator to copy.
      */
     space_allocator(space_allocator const& al) throw() : space(al.space) {}
+    /**
+     * \brief Assignment operator
+     * @param al The allocator to assign.
+     */
+    space_allocator& operator =(space_allocator const& al) {
+      assert(&space == &al.space);
+      return *this;
+    }
     /**
      * \brief Copy from other instantiation
      * @param al The source allocator.
@@ -297,7 +309,7 @@ typedef std::set<int, std::less<int>, Gecode::region_allocator<int> > SR;
   template<class T> struct region_allocator;
 
   /**
-   * \brief Region allocator - specialization for \c void.
+   * \brief %Region allocator - specialization for \c void.
    *
    * The specialization is needed as the default instantiation fails 
    * for \c void.
@@ -307,6 +319,7 @@ typedef std::set<int, std::less<int>, Gecode::region_allocator<int> > SR;
     typedef void* pointer;
     typedef const void* const_pointer;
     typedef void value_type;
+    /// Rebinding helper (returns the type of a similar allocator for type \a U)
     template<class U> struct rebind {
       typedef region_allocator<U> other;
     };
