@@ -9,8 +9,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2009-09-30 12:12:35 +0200 (Wed, 30 Sep 2009) $ by $Author: tack $
- *     $Revision: 9779 $
+ *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
+ *     $Revision: 10684 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -230,9 +230,9 @@ namespace Gecode {
 
     /// \name Moving elements
     //@{
-    /// Move assigned view from position 0 to position \a i (shift elements to the left)
+    /// Move view from position 0 to position \a i (shift elements to the left)
     void move_fst(int i);
-    /// Move assigned view from position \c size()-1 to position \a i (truncate array by one)
+    /// Move view from position \c size()-1 to position \a i (truncate array by one)
     void move_lst(int i);
     /** \brief Move view from position 0 to position \a i (shift elements to the left)
      *
@@ -262,9 +262,9 @@ namespace Gecode {
 
     /// \name Dropping elements
     //@{
-    /// Drop assigned views from positions 0 to \a i-1 from array
+    /// Drop views from positions 0 to \a i-1 from array
     void drop_fst(int i);
-    /// Drop assigned views from positions \a i+1 to \c size()-1 from array
+    /// Drop views from positions \a i+1 to \c size()-1 from array
     void drop_lst(int i);
     /** \brief Drop views from positions 0 to \a i-1 from array
      *
@@ -542,7 +542,7 @@ namespace Gecode {
 
 
 
-  /** \brief Traits of arrays in Gecode
+  /** \brief Traits of arrays in %Gecode
    *
    * This class collects the traits of an array in Gecode.
    * The traits used are the following.
@@ -616,9 +616,11 @@ namespace Gecode {
   forceinline void
   VarArray<Var>::resize(Space& home, int m) {
     int newsize;
+    int newn;
     if (m<n) {
       // Shrink array and leave capacity at m+1, forcing heap allocation
       newsize = m+1;
+      newn = m;
     } else if (m<capacity) {
       // As m>=n<capacity, the array is heap allocated, just resize
       n = m;
@@ -626,12 +628,13 @@ namespace Gecode {
     } else {
       // Resize, so that newsize != m forcing heap allocation
       newsize = std::max(m+1, (3*capacity)/2);
+      newn = n;
     }
 
     if (n == capacity) {
       // Array was space allocated, copy to heap with new size
       Var* oldx = x;
-      x = heap.copy<Var>(heap.alloc<Var>(newsize), x, n);
+      x = heap.copy<Var>(heap.alloc<Var>(newsize), x, newn);
       home.rfree(oldx, capacity);
     } else {
       // Array was heap allocated, just reallocate with new size
@@ -757,23 +760,18 @@ namespace Gecode {
   template<class View>
   forceinline void
   ViewArray<View>::move_fst(int i) {
-    // move x[0] to x[i]
-    assert(x[i].assigned());
     x[i]=x[0]; x++; n--;
   }
 
   template<class View>
   forceinline void
   ViewArray<View>::move_lst(int i) {
-    // move x[n-1] to x[i]
-    assert(x[i].assigned());
     n--; x[i]=x[n];
   }
 
   template<class View>
   forceinline void
   ViewArray<View>::drop_fst(int i) {
-    // Drop elements from 0..i-1
     assert(i>=0);
     x += i; n -= i;
   }
@@ -781,7 +779,6 @@ namespace Gecode {
   template<class View>
   forceinline void
   ViewArray<View>::drop_lst(int i) {
-    // Drop elements from i+1..n-1
     assert(i<n);
     n = i+1;
   }
