@@ -7,8 +7,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2009-11-03 17:47:56 +0100 (Tue, 03 Nov 2009) $ by $Author: schulte $
- *     $Revision: 10035 $
+ *     $Date: 2010-03-26 15:22:07 +0100 (Fri, 26 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10576 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -400,7 +400,7 @@ namespace Gecode {
     for (int i=0; i<AllVarConf::idx_c; i++)
       pc.c.vars_u[i] = NULL;
     pc.c.vars_noidx = NULL;
-    pc.c.copied = NULL;
+    pc.c.shared = NULL;
     // Copy all propagators
     {
       ActorLink* p = &pl;
@@ -507,7 +507,7 @@ namespace Gecode {
     }
 
     // Reset links for copied objects
-    for (CopiedHandle::Object* s = c->pc.c.copied; s != NULL; s = s->next)
+    for (SharedHandle::Object* s = c->pc.c.shared; s != NULL; s = s->next)
       s->fwd = NULL;
 
     // Initialize propagator queue
