@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-02-03 11:13:34 +0100 (Wed, 03 Feb 2010) $ by $Author: schulte $
+ *     $Revision: 10262 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -45,19 +45,6 @@ namespace Gecode {
    * Operations for nodes
    *
    */
-  forceinline void*
-  BoolExpr::Node::operator new(size_t size) {
-    return heap.ralloc(size);
-  }
-
-  forceinline void
-  BoolExpr::Node::operator delete(void* p, size_t) {
-    heap.rfree(p);
-  }
-
-  forceinline
-  BoolExpr::Node::Node(void) : use(1) {}
-
   bool
   BoolExpr::Node::decrement(void) {
     if (--use == 0) {
@@ -70,59 +57,6 @@ namespace Gecode {
     return false;
   }
 
-  BoolExpr::BoolExpr(const BoolVar& x) : n(new Node) {
-    n->same = 1;
-    n->t    = NT_VAR;
-    n->l    = NULL;
-    n->r    = NULL;
-    n->x    = x;
-  }
-
-  BoolExpr::BoolExpr(const BoolExpr& l, NodeType t, const BoolExpr& r)
-    : n(new Node) {
-    unsigned int ls = ((l.n->t == t) || (l.n->t == NT_VAR)) ? l.n->same : 1;
-    unsigned int rs = ((r.n->t == t) || (r.n->t == NT_VAR)) ? r.n->same : 1;
-    n->same = ls+rs;
-    n->t    = t;
-    n->l    = l.n;
-    n->l->use++;
-    n->r    = r.n;
-    n->r->use++;
-  }
-
-  BoolExpr::BoolExpr(const BoolExpr& l, NodeType t) {
-    (void) t;
-    assert(t == NT_NOT);
-    if (l.n->t == NT_NOT) {
-      n = l.n->l;
-      n->use++;
-    } else {
-      n = new Node;
-      n->same = 1;
-      n->t    = NT_NOT;
-      n->l    = l.n;
-      n->l->use++;
-      n->r    = NULL;
-    }
-  }
-
-  BoolExpr::BoolExpr(const LinRel<IntVar>& rl)
-    : n(new Node) {
-    n->same   = 1;
-    n->t      = NT_RLIN_INT;
-    n->l      = NULL;
-    n->r      = NULL;
-    n->rl_int = rl;
-  }
-
-  BoolExpr::BoolExpr(const LinRel<BoolVar>& rl)
-    : n(new Node) {
-    n->same    = 1;
-    n->t       = NT_RLIN_BOOL;
-    n->l       = NULL;
-    n->r       = NULL;
-    n->rl_bool = rl;
-  }
 
   const BoolExpr&
   BoolExpr::operator =(const BoolExpr& e) {
@@ -165,11 +99,8 @@ namespace Gecode {
       assert(u.a.neg);
       rel(home, u.a.x->x, IRT_NQ, b);
       break;
-    case NT_RLIN_INT:
-      u.a.x->rl_int.post(home, b, !u.a.neg, icl);
-      break;
-    case NT_RLIN_BOOL:
-      u.a.x->rl_bool.post(home, b, !u.a.neg, icl);
+    case NT_RLIN:
+      u.a.x->rl.post(home, b, !u.a.neg, icl);
       break;
     case NT_AND:
       {
@@ -227,17 +158,10 @@ namespace Gecode {
           bp[ip++]=u.a.x->x;
         }
         break;
-      case NT_RLIN_INT:
+      case NT_RLIN:
         {
           BoolVar b(home,0,1);
-          u.a.x->rl_int.post(home, b, !u.a.neg, icl);
-          bp[ip++]=b;
-        }
-        break;
-      case NT_RLIN_BOOL:
-        {
-          BoolVar b(home,0,1);
-          u.a.x->rl_bool.post(home, b, !u.a.neg, icl);
+          u.a.x->rl.post(home, b, !u.a.neg, icl);
           bp[ip++]=b;
         }
         break;
@@ -258,11 +182,8 @@ namespace Gecode {
       case NT_VAR:
         rel(home, u.a.x->x, IRT_EQ, u.a.neg ? 0 : 1);
         break;
-      case NT_RLIN_INT:
-        u.a.x->rl_int.post(home, !u.a.neg, icl);
-        break;
-      case NT_RLIN_BOOL:
-        u.a.x->rl_bool.post(home, !u.a.neg, icl);
+      case NT_RLIN:
+        u.a.x->rl.post(home, !u.a.neg, icl);
         break;
       case NT_AND:
         u.b.l->post(home, true, icl);
@@ -287,11 +208,8 @@ namespace Gecode {
       case NT_VAR:
         rel(home, u.a.x->x, IRT_EQ, u.a.neg ? 1 : 0);
         break;
-      case NT_RLIN_INT:
-        u.a.x->rl_int.post(home, u.a.neg, icl);
-        break;
-      case NT_RLIN_BOOL:
-        u.a.x->rl_bool.post(home, u.a.neg, icl);
+      case NT_RLIN:
+        u.a.x->rl.post(home, u.a.neg, icl);
         break;
       case NT_AND:
         {
@@ -317,7 +235,7 @@ namespace Gecode {
   BoolExpr::NNF*
   BoolExpr::NNF::nnf(Region& r, Node* n, bool neg) {
     switch (n->t) {
-    case NT_VAR: case NT_RLIN_INT: case NT_RLIN_BOOL:
+    case NT_VAR: case NT_RLIN:
       {
         NNF* x = new (r) NNF;
         x->t = n->t; x->u.a.neg = neg; x->u.a.x = n;
@@ -369,6 +287,51 @@ namespace Gecode {
     return NULL;
   }
 
+
+  BoolExpr
+  operator &&(const BoolExpr& l, const BoolExpr& r) {
+    return BoolExpr(l,BoolExpr::NT_AND,r);
+  }
+  BoolExpr
+  operator ||(const BoolExpr& l, const BoolExpr& r) {
+    return BoolExpr(l,BoolExpr::NT_OR,r);
+  }
+  BoolExpr
+  operator ^(const BoolExpr& l, const BoolExpr& r) {
+    return BoolExpr(BoolExpr(l,BoolExpr::NT_EQV,r),BoolExpr::NT_NOT);
+  }
+
+  BoolExpr
+  operator ~(const LinRel& rl) {
+    return BoolExpr(rl);
+  }
+  BoolExpr
+  operator !(const BoolExpr& e) {
+    return BoolExpr(e,BoolExpr::NT_NOT);
+  }
+
+  BoolExpr
+  eqv(const BoolExpr& l, const BoolExpr& r) {
+    return BoolExpr(l, BoolExpr::NT_EQV, r);
+  }
+  BoolExpr
+  imp(const BoolExpr& l, const BoolExpr& r) {
+    return BoolExpr(BoolExpr(l,BoolExpr::NT_NOT),
+                    BoolExpr::NT_OR,r);
+  }
+
+  /*
+   * Posting Boolean expressions
+   *
+   */
+  BoolVar
+  post(Home home, const BoolExpr& e, IntConLevel icl) {
+    if (!home.failed())
+      return e.post(home,icl);
+    BoolVar x(home,0,1);
+    return x;
+  }
+
 }
 
 // STATISTICS: minimodel-any
