@@ -7,8 +7,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-02-03 11:13:34 +0100 (Wed, 03 Feb 2010) $ by $Author: schulte $
+ *     $Revision: 10262 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -41,12 +41,72 @@ namespace Gecode {
    * Operations for expressions
    *
    */
+  forceinline
+  BoolExpr::Node::Node(void) : use(1) {}
+
+  forceinline void*
+  BoolExpr::Node::operator new(size_t size) {
+    return heap.ralloc(size);
+  }
+  forceinline void
+  BoolExpr::Node::operator delete(void* p, size_t) {
+    heap.rfree(p);
+  }
 
   forceinline
   BoolExpr::BoolExpr(const BoolExpr& e) : n(e.n) {
     n->use++;
   }
 
+  forceinline
+  BoolExpr::BoolExpr(const BoolVar& x) : n(new Node) {
+    n->same = 1;
+    n->t    = NT_VAR;
+    n->l    = NULL;
+    n->r    = NULL;
+    n->x    = x;
+  }
+
+  forceinline
+  BoolExpr::BoolExpr(const BoolExpr& l, NodeType t, const BoolExpr& r)
+    : n(new Node) {
+    unsigned int ls = ((l.n->t == t) || (l.n->t == NT_VAR)) ? l.n->same : 1;
+    unsigned int rs = ((r.n->t == t) || (r.n->t == NT_VAR)) ? r.n->same : 1;
+    n->same = ls+rs;
+    n->t    = t;
+    n->l    = l.n;
+    n->l->use++;
+    n->r    = r.n;
+    n->r->use++;
+  }
+
+  forceinline
+  BoolExpr::BoolExpr(const BoolExpr& l, NodeType t) {
+    (void) t;
+    assert(t == NT_NOT);
+    if (l.n->t == NT_NOT) {
+      n = l.n->l;
+      n->use++;
+    } else {
+      n = new Node;
+      n->same = 1;
+      n->t    = NT_NOT;
+      n->l    = l.n;
+      n->l->use++;
+      n->r    = NULL;
+    }
+  }
+
+  forceinline
+  BoolExpr::BoolExpr(const LinRel& rl)
+    : n(new Node) {
+    n->same = 1;
+    n->t    = NT_RLIN;
+    n->l    = NULL;
+    n->r    = NULL;
+    n->rl   = rl;
+  }
+
   forceinline BoolVar
   BoolExpr::post(Home home, IntConLevel icl) const {
     Region r(home);
@@ -59,57 +119,6 @@ namespace Gecode {
     return NNF::nnf(r,n,false)->post(home,t,icl);
   }
 
-
-  inline BoolExpr
-  operator &&(const BoolExpr& l, const BoolExpr& r) {
-    return BoolExpr(l,BoolExpr::NT_AND,r);
-  }
-
-  inline BoolExpr
-  operator ||(const BoolExpr& l, const BoolExpr& r) {
-    return BoolExpr(l,BoolExpr::NT_OR,r);
-  }
-
-  inline BoolExpr
-  operator ^(const BoolExpr& l, const BoolExpr& r) {
-    return BoolExpr(BoolExpr(l,BoolExpr::NT_EQV,r),BoolExpr::NT_NOT);
-  }
-
-  template<class Var>
-  inline BoolExpr
-  operator ~(const LinRel<Var>& rl) {
-    return BoolExpr(rl);
-  }
-
-  inline BoolExpr
-  operator !(const BoolExpr& e) {
-    return BoolExpr(e,BoolExpr::NT_NOT);
-  }
-
-
-  inline BoolExpr
-  eqv(const BoolExpr& l, const BoolExpr& r) {
-    return BoolExpr(l, BoolExpr::NT_EQV, r);
-  }
-
-  inline BoolExpr
-  imp(const BoolExpr& l, const BoolExpr& r) {
-    return BoolExpr(BoolExpr(l,BoolExpr::NT_NOT),
-                    BoolExpr::NT_OR,r);
-  }
-
-
-  inline BoolVar
-  post(Home home, const BoolExpr& e, IntConLevel icl) {
-    return e.post(home,icl);
-  }
-
-  inline BoolVar
-  post(Home, const BoolVar& b, IntConLevel) {
-    return b;
-  }
-
-
 }
 
 // STATISTICS: minimodel-any
