@@ -7,8 +7,8 @@
  *     Christian Schulte, 2005
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-02-03 11:13:34 +0100 (Wed, 03 Feb 2010) $ by $Author: schulte $
+ *     $Revision: 10262 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -50,29 +50,6 @@ namespace Gecode {
     e.post(home,t,icl);
   }
 
-  /*
-   * Construction of linear relations
-   *
-   */
-  inline BoolRel
-  tt(const BoolExpr& e) {
-    return BoolRel(e,true);
-  }
-  inline BoolRel
-  ff(const BoolExpr& e) {
-    return BoolRel(e,false);
-  }
-
-  /*
-   * Posting
-   *
-   */
-  inline void
-  post(Home home, const BoolRel& r, IntConLevel icl) {
-    if (home.failed()) return;
-    r.post(home,icl);
-  }
-
 }
 
 // STATISTICS: minimodel-any
