@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
+ *     $Revision: 10684 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -43,6 +43,7 @@ namespace Gecode {
 
   namespace Int { namespace Element {
     template<>
+    /// VarArg type for constant %Set views
     class ViewToVarArg<Gecode::Set::ConstantView> {
     public:
       typedef IntSetArgs argtype;
@@ -61,14 +62,14 @@ namespace Gecode {
       {
         Set::Element::ElementDisjoint<SetView,SetView>::IdxViewArray
           iv(home, x);
-        GECODE_ES_FAIL(home,(Element::ElementDisjoint<SetView,SetView>::
+        GECODE_ES_FAIL((Element::ElementDisjoint<SetView,SetView>::
                         post(home,iv,y)));
       }
       // fall through
     case SOT_UNION:
       {
         Set::Element::ElementUnion<SetView,SetView>::IdxViewArray iv(home, x);
-        GECODE_ES_FAIL(home,
+        GECODE_ES_FAIL(
                        (Element::ElementUnion<SetView,SetView>::
                         post(home,z,iv,y)));
       }
@@ -77,7 +78,7 @@ namespace Gecode {
       {
         Set::Element::ElementIntersection<SetView,SetView>::IdxViewArray
           iv(home, x);
-        GECODE_ES_FAIL(home,
+        GECODE_ES_FAIL(
                        (Element::ElementIntersection<SetView,SetView>::
                         post(home,z,iv,y,universe)));
       }
@@ -103,7 +104,7 @@ namespace Gecode {
         for (int i=x.size(); i--;) {
           iv[i].idx = i; iv[i].view = ConstantView(home, x[i]);
         }
-        GECODE_ES_FAIL(home,(Element::ElementDisjoint<ConstantView,SetView>::
+        GECODE_ES_FAIL((Element::ElementDisjoint<ConstantView,SetView>::
                         post(home,iv,y)));
       }
       // fall through
@@ -112,7 +113,7 @@ namespace Gecode {
         SharedArray<IntSet> s(x.size());
         for (int i=s.size(); i--;)
           new (&s[i]) IntSet(x[i]);
-        GECODE_ES_FAIL(home,
+        GECODE_ES_FAIL(
                        (Element::ElementUnionConst<SetView,SetView>::
                         post(home,z,s,y)));
       }
@@ -124,7 +125,7 @@ namespace Gecode {
         for (int i=x.size(); i--;) {
           iv[i].idx = i; iv[i].view = ConstantView(home, x[i]);
         }
-        GECODE_ES_FAIL(home,
+        GECODE_ES_FAIL(
                        (Element::ElementIntersection<ConstantView,SetView>::
                         post(home,z,iv,y,universe)));
       }
@@ -148,7 +149,7 @@ namespace Gecode {
 
     Int::IntView yv(y);
     SingletonView single(yv);
-    GECODE_ES_FAIL(home,(Element::ElementUnion<SetView,
+    GECODE_ES_FAIL((Element::ElementUnion<SetView,
                          SingletonView>::post(home, z, iv, single)));
   }
 
@@ -166,7 +167,7 @@ namespace Gecode {
 
     Int::IntView yv(y);
     SingletonView single(yv);
-    GECODE_ES_FAIL(home,(Element::ElementUnionConst<SetView,
+    GECODE_ES_FAIL((Element::ElementUnionConst<SetView,
                          SingletonView>::post(home, z, x, single)));
   }
 
