@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-14 12:19:49 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9909 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -73,7 +73,7 @@ namespace Gecode { namespace Set { namespace Element {
   }
 
   template<class SView, class RView>
-  size_t
+  forceinline size_t
   ElementIntersection<SView,RView>::dispose(Space& home) {
     home.ignore(*this,AP_DISPOSE);
     if (!home.failed()) {
@@ -220,7 +220,7 @@ namespace Gecode { namespace Set { namespace Element {
         }
         for (int i=n; i--;)
           before[i].dispose(home);
-        return ES_SUBSUMED(*this,home);
+        return home.ES_SUBSUMED(*this);
       }
 
       {
@@ -287,7 +287,7 @@ namespace Gecode { namespace Set { namespace Element {
         GECODE_REWRITE(*this,(Rel::Eq<RView,SView>::post(home(*this),x0,iv[0].view)));
       } else {
         GECODE_ME_CHECK(x0.cardMax(home, 0));
-        return ES_SUBSUMED(*this,home);
+        return home.ES_SUBSUMED(*this);
       }
     }
 
@@ -299,7 +299,7 @@ namespace Gecode { namespace Set { namespace Element {
       }
     }
     if (x0.assigned() && x1.assigned() && allAssigned) {
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
 
     return ES_FIX;
