@@ -7,8 +7,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-10 11:36:44 +0100 (Wed, 10 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10387 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -127,9 +127,8 @@ namespace Gecode { namespace Set { namespace Int {
   }
 
   template<class View>
-  size_t
+  forceinline size_t
   ChannelBool<View>::dispose(Space& home) {
-    assert(!home.failed());
     co.dispose(home);
     (void) Super::dispose(home);
     return sizeof(*this);
@@ -188,7 +187,7 @@ namespace Gecode { namespace Set { namespace Int {
 
     new (&delta) SetDelta();
 
-    return y.assigned() ? ES_SUBSUMED(*this,home) : ES_FIX;
+    return y.assigned() ? home.ES_SUBSUMED(*this) : ES_FIX;
   }
 
   template<class View>
@@ -213,7 +212,7 @@ namespace Gecode { namespace Set { namespace Int {
         SetDelta dummy;
         ones.include(home, index, index, dummy);
       }
-      return ES_SUBSUMED_NOFIX(a, home, co);
+      return home.ES_NOFIX_DISPOSE( co, a);
     }
 
     if ((a.index() == -1) && Rel::testSetEventLB(me)) {
@@ -273,7 +272,7 @@ namespace Gecode { namespace Set { namespace Int {
     }
 
     if (y.assigned())
-      return ES_SUBSUMED_NOFIX(a, home, co);
+      return home.ES_NOFIX_DISPOSE( co, a);
     else
       return ES_NOFIX;
   }
