@@ -11,8 +11,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-04-02 13:18:34 +0200 (Fri, 02 Apr 2010) $ by $Author: tack $
+ *     $Revision: 10644 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -92,9 +92,8 @@ namespace Gecode { namespace Set { namespace Int {
   }
 
   template<class View>
-  size_t
+  forceinline size_t
   ChannelInt<View>::dispose(Space& home) {
-    assert(!home.failed());
     xs.cancel(home,*this, Gecode::Int::PC_INT_DOM);
     ys.cancel(home,*this, PC_SET_ANY);
     (void) Propagator::dispose(home);
@@ -141,11 +140,14 @@ namespace Gecode { namespace Set { namespace Int {
           }
           min = xsv.max() + 1;
         }
+        for (int i=min; i<ys.size(); i++) {
+          GECODE_ME_CHECK(ys[i].exclude(home, v));
+        }
 
       }
     }
 
-    return (assigned==xs.size()) ? ES_SUBSUMED(*this,home) : ES_NOFIX;
+    return (assigned==xs.size()) ? home.ES_SUBSUMED(*this) : ES_NOFIX;
   }
 
 }}}
