@@ -11,8 +11,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -88,9 +88,8 @@ namespace Gecode { namespace Set { namespace Int {
   }
 
   template<class View>
-  size_t
+  forceinline size_t
   Match<View>::dispose(Space& home) {
-    assert(!home.failed());
     x0.cancel(home,*this, PC_SET_ANY);
     xs.cancel(home,*this, Gecode::Int::PC_INT_BND);
     (void) Propagator::dispose(home);
@@ -192,7 +191,7 @@ namespace Gecode { namespace Set { namespace Int {
     for (int i=xs_size; i--; )
       if (!xs[i].assigned())
         return ES_FIX;
-    return ES_SUBSUMED(*this,home);
+    return home.ES_SUBSUMED(*this);
   }
 
 }}}
