@@ -11,8 +11,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -192,9 +192,8 @@ namespace Gecode { namespace Set { namespace Int {
   }
 
   template<class View>
-  size_t
+  forceinline size_t
   Weights<View>::dispose(Space& home) {
-    assert(!home.failed());
     x.cancel(home,*this, PC_SET_ANY);
     y.cancel(home,*this, Gecode::Int::PC_INT_BND);
     (void) Propagator::dispose(home);
@@ -339,7 +338,7 @@ namespace Gecode { namespace Set { namespace Int {
       int w =
         weightI<GlbRanges<View> >(elements, weights, glb);
       GECODE_ME_CHECK(y.eq(home, w));
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
 
     return me_modified(me) ? ES_NOFIX : ES_FIX;
