@@ -13,8 +13,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -153,7 +153,7 @@ namespace Gecode { namespace Set { namespace RelOp {
       BndSetRanges all2(unionOfDets);
       GECODE_ME_CHECK( y.includeI(home,all2) );
       unionOfDets.dispose(home);
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
 
     return shared ? ES_NOFIX : ES_FIX;
