@@ -7,8 +7,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2009-11-23 15:38:32 +0100 (Mon, 23 Nov 2009) $ by $Author: schulte $
+ *     $Revision: 10098 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -243,8 +243,10 @@ namespace Gecode { namespace Set {
   }
 
   forceinline void
-  ConstantView::subscribe(Space& home, Propagator& p, PropCond,bool) {
-    schedule(home,p,ME_SET_VAL);
+  ConstantView::subscribe(Space& home, Propagator& p, PropCond,
+                          bool process) {
+    if (process)
+      schedule(home,p,ME_SET_VAL);
   }
   forceinline void
   ConstantView::cancel(Space&,Propagator&,PropCond) {}
@@ -427,8 +429,10 @@ namespace Gecode { namespace Set {
   }
 
   forceinline void
-  EmptyView::subscribe(Space& home, Propagator& p, PropCond,bool) {
-    schedule(home,p,ME_SET_VAL);
+  EmptyView::subscribe(Space& home, Propagator& p, PropCond,
+                       bool process) {
+    if (process)
+      schedule(home,p,ME_SET_VAL);
   }
   forceinline void
   EmptyView::cancel(Space&,Propagator&,PropCond) {}
@@ -598,8 +602,10 @@ namespace Gecode { namespace Set {
     return SetVarImp::med(me);
   }
   forceinline void
-  UniverseView::subscribe(Space& home, Propagator& p, PropCond,bool) {
-    schedule(home,p,ME_SET_VAL);
+  UniverseView::subscribe(Space& home, Propagator& p, PropCond,
+                          bool process) {
+    if (process)
+      schedule(home,p,ME_SET_VAL);
   }
   forceinline void
   UniverseView::cancel(Space&,Propagator&,PropCond) {}
