@@ -7,8 +7,8 @@
  *     Christian Schulte, 2008
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
+ *     $Revision: 10684 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -41,7 +41,7 @@
 
 namespace Test { namespace Int {
 
-  /// Tests for minimal modelling constraints (linear)
+  /// %Tests for minimal modelling constraints (linear)
    namespace MiniModelLin {
 
      /// Linear opcode
@@ -90,11 +90,11 @@ namespace Test { namespace Int {
      }
 
      /**
-      * \defgroup TaskTestIntMiniModelLin Minimal modelling constraints (linear constraints)
+      * \defgroup TaskTestIntMiniModelLin Minimal modeling constraints (linear constraints)
       * \ingroup TaskTestInt
       */
      //@{
-     /// Test linear expressions over integer variables
+     /// %Test linear expressions over integer variables
      class LinExprInt : public Test {
      protected:
        /// Linear instruction sequence
@@ -103,21 +103,74 @@ namespace Test { namespace Int {
        /// Create and register test
        LinExprInt(const LinInstr* lis0, const std::string& s)
          : Test("MiniModel::LinExpr::Int::"+s,4,-3,3), lis(lis0) {}
-       /// Test whether \a x is solution
+       /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          int reg[3] = {x[0],x[1],x[2]};
-         //         std::cout << "eval: " << eval(lis, reg) << std::endl;
          return eval(lis, reg) == x[3];
        }
        /// Post constraint on \a x
        virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
          using namespace Gecode;
-         Gecode::LinExpr<IntVar> reg[3] = {x[0],x[1],x[2]};
+         Gecode::LinExpr reg[3] = {x[0],x[1],x[2]};
          rel(home, x[3], IRT_EQ, Gecode::post(home, eval(lis,reg)));
        }
      };
 
-     /// Test linear relations over integer variables
+     /// %Test linear expressions over Boolean variables
+     class LinExprBool : public Test {
+     protected:
+       /// Linear instruction sequence
+       const LinInstr* lis;
+     public:
+       /// Create and register test
+       LinExprBool(const LinInstr* lis0, const std::string& s)
+         : Test("MiniModel::LinExpr::Bool::"+s,4,-3,3), lis(lis0) {}
+       /// %Test whether \a x is solution
+       virtual bool solution(const Assignment& x) const {
+         for (int i=3; i--; )
+           if ((x[i] < 0) || (x[i] > 1))
+             return false;
+         int reg[3] = {x[0],x[1],x[2]};
+         return eval(lis, reg) == x[3];
+       }
+       /// Post constraint on \a x
+       virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
+         using namespace Gecode;
+         Gecode::LinExpr reg[3] = {
+           channel(home,x[0]),channel(home,x[1]),channel(home,x[2])
+         };
+         rel(home, x[3], IRT_EQ, Gecode::post(home, eval(lis,reg)));
+       }
+     };
+
+     /// %Test linear expressions over integer and Boolean variables
+     class LinExprMixed : public Test {
+     protected:
+       /// Linear instruction sequence
+       const LinInstr* lis;
+     public:
+       /// Create and register test
+       LinExprMixed(const LinInstr* lis0, const std::string& s)
+         : Test("MiniModel::LinExpr::Mixed::"+s,4,-3,3), lis(lis0) {}
+       /// %Test whether \a x is solution
+       virtual bool solution(const Assignment& x) const {
+         if ((x[2] < 0) || (x[2] > 1))
+           return false;
+         int reg[3] = {x[0],x[1],x[2]};
+         return eval(lis, reg) == x[3];
+       }
+       /// Post constraint on \a x
+       virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
+         using namespace Gecode;
+         Gecode::LinExpr reg[3] = {
+           x[0],x[1],channel(home,x[2])
+         };
+         rel(home, x[3], IRT_EQ, Gecode::post(home, eval(lis,reg)));
+       }
+     };
+
+
+     /// %Test linear relations over integer variables
      class LinRelInt : public Test {
      protected:
        /// Linear instruction sequence for left hand side
@@ -132,7 +185,7 @@ namespace Test { namespace Int {
                  Gecode::IntRelType irt0, const std::string& s)
          : Test("MiniModel::LinRel::Int::"+s+"::"+str(irt0),3,-3,3,true),
            l_lis(l_lis0), r_lis(r_lis0), irt(irt0) {}
-       /// Test whether \a x is solution
+       /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          int l_reg[3] = {x[0],x[1],x[2]};
          int r_reg[3] = {x[0],x[1],x[2]};
@@ -141,8 +194,199 @@ namespace Test { namespace Int {
        /// Post constraint on \a x
        virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
          using namespace Gecode;
-         Gecode::LinExpr<IntVar> l_reg[3] = {x[0],x[1],x[2]};
-         Gecode::LinExpr<IntVar> r_reg[3] = {x[0],x[1],x[2]};
+         Gecode::LinExpr l_reg[3] = {x[0],x[1],x[2]};
+         Gecode::LinExpr r_reg[3] = {x[0],x[1],x[2]};
+         switch (irt) {
+         case IRT_EQ:
+           {
+             IntVar x = Gecode::post(home,eval(l_lis,l_reg));
+             IntVar y = Gecode::post(home,eval(r_lis,r_reg));
+             IntArgs a(2, 1,-1);
+             IntVarArgs xy(2); xy[0]=x; xy[1]=y;
+             Gecode::post(home, tt(0 == sum(a,xy)));
+           }
+           break;
+         case IRT_NQ:
+           Gecode::post(home, eval(l_lis,l_reg) - eval(r_lis,r_reg) != 0);
+           break;
+         case IRT_LQ:
+           Gecode::post(home, ff(eval(l_lis,l_reg) > eval(r_lis,r_reg)));
+           break;
+         case IRT_LE:
+           Gecode::post(home, tt(eval(l_lis,l_reg) < eval(r_lis,r_reg)));
+           break;
+         case IRT_GQ:
+           Gecode::post(home, eval(l_lis,l_reg) >= eval(r_lis,r_reg));
+           break;
+         case IRT_GR:
+           Gecode::post(home, ff(eval(l_lis,l_reg) <= eval(r_lis,r_reg)));
+           break;
+         default: GECODE_NEVER;
+         }
+       }
+       /// Post constraint on \a x for \a b
+       virtual void post(Gecode::Space& home, Gecode::IntVarArray& x,
+                         Gecode::BoolVar b) {
+         using namespace Gecode;
+         Gecode::LinExpr l_reg[3] = {x[0],x[1],x[2]};
+         Gecode::LinExpr r_reg[3] = {x[0],x[1],x[2]};
+         switch (irt) {
+         case IRT_EQ:
+           rel(home, Gecode::post(home,
+                                  ~(eval(l_lis,l_reg)==eval(r_lis,r_reg))),
+               IRT_EQ, b);
+           break;
+         case IRT_NQ:
+           Gecode::post(home,
+                        tt(eqv(~(eval(l_lis,l_reg)!=eval(r_lis,r_reg)),b)));
+           break;
+         case IRT_LQ:
+           Gecode::post(home,
+                        ff(~(eval(l_lis,l_reg)<=eval(r_lis,r_reg))^b));
+           break;
+         case IRT_LE:
+           rel(home, Gecode::post(home,
+                                  ~(eval(l_lis,l_reg)<eval(r_lis,r_reg))),
+               IRT_EQ, b);
+           break;
+         case IRT_GQ:
+           Gecode::post(home,
+                        tt(eqv(~(eval(l_lis,l_reg)>=eval(r_lis,r_reg)),b)));
+           break;
+         case IRT_GR:
+           Gecode::post(home,
+                        ff(~(eval(l_lis,l_reg)>eval(r_lis,r_reg))^b));
+           break;
+         default: GECODE_NEVER;
+         }
+       }
+     };
+
+     /// %Test linear relations over Boolean variables
+     class LinRelBool : public Test {
+     protected:
+       /// Linear instruction sequence for left hand side
+       const LinInstr* l_lis;
+       /// Linear instruction sequence for right hand side
+       const LinInstr* r_lis;
+       /// Integer relation type to propagate
+       Gecode::IntRelType irt;
+     public:
+       /// Create and register test
+       LinRelBool(const LinInstr* l_lis0, const LinInstr* r_lis0,
+                  Gecode::IntRelType irt0, const std::string& s)
+         : Test("MiniModel::LinRel::Bool::"+s+"::"+str(irt0),3,0,1,true),
+           l_lis(l_lis0), r_lis(r_lis0), irt(irt0) {}
+       /// %Test whether \a x is solution
+       virtual bool solution(const Assignment& x) const {
+         int l_reg[3] = {x[0],x[1],x[2]};
+         int r_reg[3] = {x[0],x[1],x[2]};
+         return cmp(eval(l_lis,l_reg),irt,eval(r_lis,r_reg));
+       }
+       /// Post constraint on \a x
+       virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
+         using namespace Gecode;
+         BoolVarArgs y(3);
+         y[0] = channel(home,x[0]); y[1] = channel(home,x[1]);
+         y[2] = channel(home,x[2]);
+         Gecode::LinExpr l_reg[3] = {y[0],y[1],y[2]};
+         Gecode::LinExpr r_reg[3] = {y[0],y[1],y[2]};
+         switch (irt) {
+         case IRT_EQ:
+           {
+             IntVar x = Gecode::post(home,eval(l_lis,l_reg));
+             IntVar y = Gecode::post(home,eval(r_lis,r_reg));
+             IntArgs a(2, -2,2);
+             IntVarArgs xy(2); xy[0]=x; xy[1]=y;
+             Gecode::post(home, tt(0 == sum(a,xy)));
+           }
+           break;
+         case IRT_NQ:
+           Gecode::post(home, eval(l_lis,l_reg) - eval(r_lis,r_reg) != 0);
+           break;
+         case IRT_LQ:
+           Gecode::post(home, ff(eval(l_lis,l_reg) > eval(r_lis,r_reg)));
+           break;
+         case IRT_LE:
+           Gecode::post(home, tt(eval(l_lis,l_reg) < eval(r_lis,r_reg)));
+           break;
+         case IRT_GQ:
+           Gecode::post(home, eval(l_lis,l_reg) >= eval(r_lis,r_reg));
+           break;
+         case IRT_GR:
+           Gecode::post(home, ff(eval(l_lis,l_reg) <= eval(r_lis,r_reg)));
+           break;
+         default: GECODE_NEVER;
+         }
+       }
+       /// Post constraint on \a x for \a b
+       virtual void post(Gecode::Space& home, Gecode::IntVarArray& x,
+                         Gecode::BoolVar b) {
+         using namespace Gecode;
+         BoolVarArgs y(3);
+         y[0] = channel(home,x[0]); y[1] = channel(home,x[1]);
+         y[2] = channel(home,x[2]);
+         Gecode::LinExpr l_reg[3] = {y[0],y[1],y[2]};
+         Gecode::LinExpr r_reg[3] = {y[0],y[1],y[2]};
+         switch (irt) {
+         case IRT_EQ:
+           rel(home, Gecode::post(home,
+                                  ~(eval(l_lis,l_reg)==eval(r_lis,r_reg))),
+               IRT_EQ, b);
+           break;
+         case IRT_NQ:
+           Gecode::post(home,
+                        tt(eqv(~(eval(l_lis,l_reg)!=eval(r_lis,r_reg)),b)));
+           break;
+         case IRT_LQ:
+           Gecode::post(home,
+                        ff(~(eval(l_lis,l_reg)<=eval(r_lis,r_reg))^b));
+           break;
+         case IRT_LE:
+           rel(home, Gecode::post(home,
+                                  ~(eval(l_lis,l_reg)<eval(r_lis,r_reg))),
+               IRT_EQ, b);
+           break;
+         case IRT_GQ:
+           Gecode::post(home,
+                        tt(eqv(~(eval(l_lis,l_reg)>=eval(r_lis,r_reg)),b)));
+           break;
+         case IRT_GR:
+           Gecode::post(home,
+                        ff(~(eval(l_lis,l_reg)>eval(r_lis,r_reg))^b));
+           break;
+         default: GECODE_NEVER;
+         }
+       }
+     };
+
+     /// %Test linear relations over integer and Boolean variables
+     class LinRelMixed : public Test {
+     protected:
+       /// Linear instruction sequence for left hand side
+       const LinInstr* l_lis;
+       /// Linear instruction sequence for right hand side
+       const LinInstr* r_lis;
+       /// Integer relation type to propagate
+       Gecode::IntRelType irt;
+     public:
+       /// Create and register test
+       LinRelMixed(const LinInstr* l_lis0, const LinInstr* r_lis0,
+                   Gecode::IntRelType irt0, const std::string& s)
+         : Test("MiniModel::LinRel::Mixed::"+s+"::"+str(irt0),6,0,1,true),
+           l_lis(l_lis0), r_lis(r_lis0), irt(irt0) {}
+       /// %Test whether \a x is solution
+       virtual bool solution(const Assignment& x) const {
+         int l_reg[3] = {x[0],x[1],x[2]};
+         int r_reg[3] = {x[3],x[4],x[5]};
+         return cmp(eval(l_lis,l_reg),irt,eval(r_lis,r_reg));
+       }
+       /// Post constraint on \a x
+       virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
+         using namespace Gecode;
+         Gecode::LinExpr l_reg[3] = {channel(home,x[0]),x[1],x[2]};
+         Gecode::LinExpr r_reg[3] = {channel(home,x[3]),x[4],
+                                     channel(home,x[5])};
          switch (irt) {
          case IRT_EQ:
            Gecode::post(home, tt(0 == eval(l_lis,l_reg) - eval(r_lis,r_reg)));
@@ -165,12 +409,13 @@ namespace Test { namespace Int {
          default: GECODE_NEVER;
          }
        }
-       /// Post constraint on \a x for \a bb
+       /// Post constraint on \a x for \a b
        virtual void post(Gecode::Space& home, Gecode::IntVarArray& x,
                          Gecode::BoolVar b) {
          using namespace Gecode;
-         Gecode::LinExpr<IntVar> l_reg[3] = {x[0],x[1],x[2]};
-         Gecode::LinExpr<IntVar> r_reg[3] = {x[0],x[1],x[2]};
+         Gecode::LinExpr l_reg[3] = {channel(home,x[0]),x[1],x[2]};
+         Gecode::LinExpr r_reg[3] = {channel(home,x[3]),x[4],
+                                     channel(home,x[5])};
          switch (irt) {
          case IRT_EQ:
            rel(home, Gecode::post(home,
@@ -178,12 +423,14 @@ namespace Test { namespace Int {
                IRT_EQ, b);
            break;
          case IRT_NQ:
-           Gecode::post(home,
-                        tt(eqv(~(eval(l_lis,l_reg)!=eval(r_lis,r_reg)),b)));
+           rel(home, Gecode::post(home,
+                                  ~(eval(l_lis,l_reg)!=eval(r_lis,r_reg))),
+               IRT_EQ, b);
            break;
          case IRT_LQ:
-           Gecode::post(home,
-                        ff(~(eval(l_lis,l_reg)<=eval(r_lis,r_reg))^b));
+           rel(home, Gecode::post(home,
+                                  ~(eval(l_lis,l_reg)<=eval(r_lis,r_reg))),
+               IRT_EQ, b);
            break;
          case IRT_LE:
            rel(home, Gecode::post(home,
@@ -191,131 +438,14 @@ namespace Test { namespace Int {
                IRT_EQ, b);
            break;
          case IRT_GQ:
-           Gecode::post(home,
-                        tt(eqv(~(eval(l_lis,l_reg)>=eval(r_lis,r_reg)),b)));
-           break;
-         case IRT_GR:
-           Gecode::post(home,
-                        ff(~(eval(l_lis,l_reg)>eval(r_lis,r_reg))^b));
-           break;
-         default: GECODE_NEVER;
-         }
-       }
-     };
-
-     /// Test linear expressions over Boolean variables
-     class LinExprBool : public Test {
-     protected:
-       /// Linear instruction sequence
-       const LinInstr* lis;
-     public:
-       /// Create and register test
-       LinExprBool(const LinInstr* lis0, const std::string& s)
-         : Test("MiniModel::LinExpr::Bool::"+s,4,-3,3), lis(lis0) {}
-       /// Test whether \a x is solution
-       virtual bool solution(const Assignment& x) const {
-         for (int i=3; i--; )
-           if ((x[i] < 0) || (x[i] > 1))
-             return false;
-         int reg[3] = {x[0],x[1],x[2]};
-         return eval(lis, reg) == x[3];
-       }
-       /// Post constraint on \a x
-       virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
-         using namespace Gecode;
-         Gecode::LinExpr<BoolVar> reg[3] = {
-           channel(home,x[0]),channel(home,x[1]),channel(home,x[2])
-         };
-         rel(home, x[3], IRT_EQ, Gecode::post(home, eval(lis,reg)));
-       }
-     };
-
-     /// Test linear relations over Boolean variables
-     class LinRelBool : public Test {
-     protected:
-       /// Linear instruction sequence for left hand side
-       const LinInstr* l_lis;
-       /// Linear instruction sequence for right hand side
-       const LinInstr* r_lis;
-       /// Integer relation type to propagate
-       Gecode::IntRelType irt;
-     public:
-       /// Create and register test
-       LinRelBool(const LinInstr* l_lis0, const LinInstr* r_lis0,
-                  Gecode::IntRelType irt0, const std::string& s)
-         : Test("MiniModel::LinRel::Bool::"+s+"::"+str(irt0),3,0,1,true),
-           l_lis(l_lis0), r_lis(r_lis0), irt(irt0) {}
-       /// Test whether \a x is solution
-       virtual bool solution(const Assignment& x) const {
-         int l_reg[3] = {x[0],x[1],x[2]};
-         int r_reg[3] = {x[0],x[1],x[2]};
-         return cmp(eval(l_lis,l_reg),irt,eval(r_lis,r_reg));
-       }
-       /// Post constraint on \a x
-       virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
-         using namespace Gecode;
-         BoolVarArgs y(3);
-         y[0] = channel(home,x[0]); y[1] = channel(home,x[1]);
-         y[2] = channel(home,x[2]);
-         Gecode::LinExpr<BoolVar> l_reg[3] = {y[0],y[1],y[2]};
-         Gecode::LinExpr<BoolVar> r_reg[3] = {y[0],y[1],y[2]};
-         switch (irt) {
-         case IRT_EQ:
-           Gecode::post(home, tt(eval(l_lis,l_reg) - eval(r_lis,r_reg) == 0));
-           break;
-         case IRT_NQ:
-           Gecode::post(home, eval(l_lis,l_reg) - eval(r_lis,r_reg) != 0);
-           break;
-         case IRT_LQ:
-           Gecode::post(home, ff(eval(l_lis,l_reg) > eval(r_lis,r_reg)));
-           break;
-         case IRT_LE:
-           Gecode::post(home, tt(eval(l_lis,l_reg) < eval(r_lis,r_reg)));
-           break;
-         case IRT_GQ:
-           Gecode::post(home, eval(l_lis,l_reg) >= eval(r_lis,r_reg));
-           break;
-         case IRT_GR:
-           Gecode::post(home, ff(eval(l_lis,l_reg) <= eval(r_lis,r_reg)));
-           break;
-         default: GECODE_NEVER;
-         }
-       }
-       /// Post constraint on \a x for \a bb
-       virtual void post(Gecode::Space& home, Gecode::IntVarArray& x,
-                         Gecode::BoolVar b) {
-         using namespace Gecode;
-         BoolVarArgs y(3);
-         y[0] = channel(home,x[0]); y[1] = channel(home,x[1]);
-         y[2] = channel(home,x[2]);
-         Gecode::LinExpr<BoolVar> l_reg[3] = {y[0],y[1],y[2]};
-         Gecode::LinExpr<BoolVar> r_reg[3] = {y[0],y[1],y[2]};
-         switch (irt) {
-         case IRT_EQ:
            rel(home, Gecode::post(home,
-                                  ~(eval(l_lis,l_reg)==eval(r_lis,r_reg))),
+                                  ~(eval(l_lis,l_reg)>=eval(r_lis,r_reg))),
                IRT_EQ, b);
            break;
-         case IRT_NQ:
-           Gecode::post(home,
-                        tt(eqv(~(eval(l_lis,l_reg)!=eval(r_lis,r_reg)),b)));
-           break;
-         case IRT_LQ:
-           Gecode::post(home,
-                        ff(~(eval(l_lis,l_reg)<=eval(r_lis,r_reg))^b));
-           break;
-         case IRT_LE:
-           rel(home, Gecode::post(home,
-                                  ~(eval(l_lis,l_reg)<eval(r_lis,r_reg))),
-               IRT_EQ, b);
-           break;
-         case IRT_GQ:
-           Gecode::post(home,
-                        tt(eqv(~(eval(l_lis,l_reg)>=eval(r_lis,r_reg)),b)));
-           break;
          case IRT_GR:
-           Gecode::post(home,
-                        ff(~(eval(l_lis,l_reg)>eval(r_lis,r_reg))^b));
+           rel(home, Gecode::post(home,
+                                  ~(eval(l_lis,l_reg)>eval(r_lis,r_reg))),
+               IRT_EQ, b);
            break;
          default: GECODE_NEVER;
          }
@@ -2008,6 +2138,7 @@ namespace Test { namespace Int {
            }
            (void) new LinExprInt(li[i],s);
            (void) new LinExprBool(li[i],s);
+           (void) new LinExprMixed(li[i],s);
          }
          IntRelTypes irts;
          for (int i=0; i<n/2; i++) {
@@ -2019,6 +2150,7 @@ namespace Test { namespace Int {
            }
            (void) new LinRelInt(li[2*i],li[2*i+1],irts.irt(),s);
            (void) new LinRelBool(li[2*i],li[2*i+1],irts.irt(),s);
+           (void) new LinRelMixed(li[2*i],li[2*i+1],irts.irt(),s);
            ++irts;
            if (!irts())
              irts.reset();
